# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/resource_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0spaceone/api/inventory/v1/resource_history.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"F\n\x18ResourceHistoryReference\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x15\n\rexternal_link\x18\x02 \x01(\t\"?\n\x16ResourceHistoryRequest\x12\x12\n\nhistory_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"P\n\x19GetResourceHistoryRequest\x12\x12\n\nhistory_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x9b\x03\n\x14ResourceHistoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nhistory_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x13\n\x0bregion_code\x18\n \x01(\t\x12\x12\n\nip_address\x18\x0b \x01(\t\x12\x19\n\x11resource_group_id\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x18\n\x10project_group_id\x18\x17 \x01(\t\x12\x11\n\tdomain_id\x18\x18 \x01(\t\x12\x18\n\x10\x63loud_service_id\x18\x19 \x01(\t\x12\x14\n\x0c\x63reated_date\x18\x1a \x01(\t\"\x81\x05\n\x13ResourceHistoryInfo\x12\x12\n\nhistory_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x15\n\rinstance_type\x18\x05 \x01(\t\x12\x15\n\rinstance_size\x18\x06 \x01(\x02\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12%\n\x04\x64\x61ta\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x46\n\treference\x18\r \x01(\x0b\x32\x33.spaceone.api.inventory.v1.ResourceHistoryReference\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0f\x63ollection_info\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cip_addresses\x18\x11 \x03(\t\x12\x13\n\x0bregion_code\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\x12\x12\n\ndeleted_at\x18! \x01(\t\x12\x18\n\x10\x63loud_service_id\x18\" \x01(\t\x12\x14\n\x0c\x63reated_date\x18# \x01(\t\"m\n\x15ResourceHistoriesInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.inventory.v1.ResourceHistoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"~\n\x18ResourceHistoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\"\x93\x01\n\x1bResourceHistoryCompareQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\"H\n\x1fResourceHistoryBatchCreateQuery\x12\x12\n\nbatch_date\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa6\x06\n\x0fResourceHistory\x12\xa0\x01\n\x03get\x12\x34.spaceone.api.inventory.v1.GetResourceHistoryRequest\x1a..spaceone.api.inventory.v1.ResourceHistoryInfo\"3\x82\xd3\xe4\x93\x02-\x12+/inventory/v1/resource-history/{history_id}\x12\xbe\x01\n\x04list\x12/.spaceone.api.inventory.v1.ResourceHistoryQuery\x1a\x30.spaceone.api.inventory.v1.ResourceHistoriesInfo\"S\x82\xd3\xe4\x93\x02M\x12 /inventory/v1/resource-historiesZ)\"\'/inventory/v1/resource-histories/search\x12\x83\x01\n\x04stat\x12\x33.spaceone.api.inventory.v1.ResourceHistoryStatQuery\x1a\x17.google.protobuf.Struct\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/resource-histories/stat\x12\x8c\x01\n\x07\x63ompare\x12\x36.spaceone.api.inventory.v1.ResourceHistoryCompareQuery\x1a\x17.google.protobuf.Struct\"0\x82\xd3\xe4\x93\x02*\"(/inventory/v1/resource-histories/compare\x12\x99\x01\n\x0c\x62\x61tch_create\x12:.spaceone.api.inventory.v1.ResourceHistoryBatchCreateQuery\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/\"-/inventory/v1/resource-histories/batch_createb\x06proto3')



_RESOURCEHISTORYREFERENCE = DESCRIPTOR.message_types_by_name['ResourceHistoryReference']
_RESOURCEHISTORYREQUEST = DESCRIPTOR.message_types_by_name['ResourceHistoryRequest']
_GETRESOURCEHISTORYREQUEST = DESCRIPTOR.message_types_by_name['GetResourceHistoryRequest']
_RESOURCEHISTORYQUERY = DESCRIPTOR.message_types_by_name['ResourceHistoryQuery']
_RESOURCEHISTORYINFO = DESCRIPTOR.message_types_by_name['ResourceHistoryInfo']
_RESOURCEHISTORIESINFO = DESCRIPTOR.message_types_by_name['ResourceHistoriesInfo']
_RESOURCEHISTORYSTATQUERY = DESCRIPTOR.message_types_by_name['ResourceHistoryStatQuery']
_RESOURCEHISTORYCOMPAREQUERY = DESCRIPTOR.message_types_by_name['ResourceHistoryCompareQuery']
_RESOURCEHISTORYBATCHCREATEQUERY = DESCRIPTOR.message_types_by_name['ResourceHistoryBatchCreateQuery']
ResourceHistoryReference = _reflection.GeneratedProtocolMessageType('ResourceHistoryReference', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYREFERENCE,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryReference)
  })
_sym_db.RegisterMessage(ResourceHistoryReference)

ResourceHistoryRequest = _reflection.GeneratedProtocolMessageType('ResourceHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryRequest)
  })
_sym_db.RegisterMessage(ResourceHistoryRequest)

GetResourceHistoryRequest = _reflection.GeneratedProtocolMessageType('GetResourceHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCEHISTORYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetResourceHistoryRequest)
  })
_sym_db.RegisterMessage(GetResourceHistoryRequest)

ResourceHistoryQuery = _reflection.GeneratedProtocolMessageType('ResourceHistoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryQuery)
  })
_sym_db.RegisterMessage(ResourceHistoryQuery)

ResourceHistoryInfo = _reflection.GeneratedProtocolMessageType('ResourceHistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryInfo)
  })
_sym_db.RegisterMessage(ResourceHistoryInfo)

ResourceHistoriesInfo = _reflection.GeneratedProtocolMessageType('ResourceHistoriesInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORIESINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoriesInfo)
  })
_sym_db.RegisterMessage(ResourceHistoriesInfo)

ResourceHistoryStatQuery = _reflection.GeneratedProtocolMessageType('ResourceHistoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryStatQuery)
  })
_sym_db.RegisterMessage(ResourceHistoryStatQuery)

ResourceHistoryCompareQuery = _reflection.GeneratedProtocolMessageType('ResourceHistoryCompareQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYCOMPAREQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryCompareQuery)
  })
_sym_db.RegisterMessage(ResourceHistoryCompareQuery)

ResourceHistoryBatchCreateQuery = _reflection.GeneratedProtocolMessageType('ResourceHistoryBatchCreateQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYBATCHCREATEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryBatchCreateQuery)
  })
_sym_db.RegisterMessage(ResourceHistoryBatchCreateQuery)

_RESOURCEHISTORY = DESCRIPTOR.services_by_name['ResourceHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCEHISTORY.methods_by_name['get']._options = None
  _RESOURCEHISTORY.methods_by_name['get']._serialized_options = b'\202\323\344\223\002-\022+/inventory/v1/resource-history/{history_id}'
  _RESOURCEHISTORY.methods_by_name['list']._options = None
  _RESOURCEHISTORY.methods_by_name['list']._serialized_options = b'\202\323\344\223\002M\022 /inventory/v1/resource-historiesZ)\"\'/inventory/v1/resource-histories/search'
  _RESOURCEHISTORY.methods_by_name['stat']._options = None
  _RESOURCEHISTORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/resource-histories/stat'
  _RESOURCEHISTORY.methods_by_name['compare']._options = None
  _RESOURCEHISTORY.methods_by_name['compare']._serialized_options = b'\202\323\344\223\002*\"(/inventory/v1/resource-histories/compare'
  _RESOURCEHISTORY.methods_by_name['batch_create']._options = None
  _RESOURCEHISTORY.methods_by_name['batch_create']._serialized_options = b'\202\323\344\223\002/\"-/inventory/v1/resource-histories/batch_create'
  _RESOURCEHISTORYREFERENCE._serialized_start=202
  _RESOURCEHISTORYREFERENCE._serialized_end=272
  _RESOURCEHISTORYREQUEST._serialized_start=274
  _RESOURCEHISTORYREQUEST._serialized_end=337
  _GETRESOURCEHISTORYREQUEST._serialized_start=339
  _GETRESOURCEHISTORYREQUEST._serialized_end=419
  _RESOURCEHISTORYQUERY._serialized_start=422
  _RESOURCEHISTORYQUERY._serialized_end=833
  _RESOURCEHISTORYINFO._serialized_start=836
  _RESOURCEHISTORYINFO._serialized_end=1477
  _RESOURCEHISTORIESINFO._serialized_start=1479
  _RESOURCEHISTORIESINFO._serialized_end=1588
  _RESOURCEHISTORYSTATQUERY._serialized_start=1590
  _RESOURCEHISTORYSTATQUERY._serialized_end=1716
  _RESOURCEHISTORYCOMPAREQUERY._serialized_start=1719
  _RESOURCEHISTORYCOMPAREQUERY._serialized_end=1866
  _RESOURCEHISTORYBATCHCREATEQUERY._serialized_start=1868
  _RESOURCEHISTORYBATCHCREATEQUERY._serialized_end=1940
  _RESOURCEHISTORY._serialized_start=1943
  _RESOURCEHISTORY._serialized_end=2749
# @@protoc_insertion_point(module_scope)
