# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.cost_analysis.v1 import job_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spaceone/api/cost_analysis/v1/data_source.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a\'spaceone/api/cost_analysis/v1/job.proto\"\xd2\x02\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x11\n\tsecret_id\x18\x07 \x01(\t\x12K\n\x0cupgrade_mode\x18\x08 \x01(\x0e\x32\x35.spaceone.api.cost_analysis.v1.PluginInfo.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"\xf8\x02\n\x19RegisterDataSourceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x61\n\x10\x64\x61ta_source_type\x18\x02 \x01(\x0e\x32G.spaceone.api.cost_analysis.v1.RegisterDataSourceRequest.DataSourceType\x12\x10\n\x08provider\x18\x03 \x01(\t\x12)\n\x08template\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12>\n\x0bplugin_info\x18\x05 \x01(\x0b\x32).spaceone.api.cost_analysis.v1.PluginInfo\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"3\n\x0e\x44\x61taSourceType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\xa4\x01\n\x17UpdateDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x08template\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x94\x02\n\x1dUpdateDataSourcePluginRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12^\n\x0cupgrade_mode\x18\x04 \x01(\x0e\x32H.spaceone.api.cost_analysis.v1.UpdateDataSourcePluginRequest.UpgradeMode\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"k\n\x15SyncDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\x18\n\x10no_preload_cache\x18\x03 \x01(\x08\x12\x11\n\tdomain_id\x18\x0b \x01(\t\">\n\x11\x44\x61taSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"O\n\x14GetDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xa5\x02\n\x0f\x44\x61taSourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x16\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12W\n\x10\x64\x61ta_source_type\x18\x05 \x01(\x0e\x32=.spaceone.api.cost_analysis.v1.DataSourceQuery.DataSourceType\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"3\n\x0e\x44\x61taSourceType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\xe3\x04\n\x0e\x44\x61taSourceInfo\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x42\n\x05state\x18\x03 \x01(\x0e\x32\x33.spaceone.api.cost_analysis.v1.DataSourceInfo.State\x12V\n\x10\x64\x61ta_source_type\x18\x04 \x01(\x0e\x32<.spaceone.api.cost_analysis.v1.DataSourceInfo.DataSourceType\x12\x10\n\x08provider\x18\x05 \x01(\t\x12>\n\x0bplugin_info\x18\x06 \x01(\x0b\x32).spaceone.api.cost_analysis.v1.PluginInfo\x12)\n\x08template\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rcost_tag_keys\x18\t \x03(\t\x12!\n\x19\x63ost_additional_info_keys\x18\n \x03(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x1c\n\x14last_synchronized_at\x18\x16 \x01(\t\"2\n\x05State\x12\x0e\n\nSTATE_NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"8\n\x0e\x44\x61taSourceType\x12\r\n\tTYPE_NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"f\n\x0f\x44\x61taSourcesInfo\x12>\n\x07results\x18\x01 \x03(\x0b\x32-.spaceone.api.cost_analysis.v1.DataSourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"^\n\x13\x44\x61taSourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa2\x0e\n\nDataSource\x12\x9b\x01\n\x08register\x12\x38.spaceone.api.cost_analysis.v1.RegisterDataSourceRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\"&\x82\xd3\xe4\x93\x02 \"\x1e/cost-analysis/v1/data-sources\x12\xa7\x01\n\x06update\x12\x36.spaceone.api.cost_analysis.v1.UpdateDataSourceRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./cost-analysis/v1/data-source/{data_source_id}\x12\xbb\x01\n\rupdate_plugin\x12<.spaceone.api.cost_analysis.v1.UpdateDataSourcePluginRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\"=\x82\xd3\xe4\x93\x02\x37\x1a\x35/cost-analysis/v1/data-source/{data_source_id}/plugin\x12\x9f\x01\n\rverify_plugin\x12\x30.spaceone.api.cost_analysis.v1.DataSourceRequest\x1a\x16.google.protobuf.Empty\"D\x82\xd3\xe4\x93\x02>\"</cost-analysis/v1/data-source/{data_source_id}/plugin/verify\x12\xa8\x01\n\x06\x65nable\x12\x30.spaceone.api.cost_analysis.v1.DataSourceRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\"=\x82\xd3\xe4\x93\x02\x37\x1a\x35/cost-analysis/v1/data-source/{data_source_id}/enable\x12\xaa\x01\n\x07\x64isable\x12\x30.spaceone.api.cost_analysis.v1.DataSourceRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\">\x82\xd3\xe4\x93\x02\x38\x1a\x36/cost-analysis/v1/data-source/{data_source_id}/disable\x12\x8e\x01\n\nderegister\x12\x30.spaceone.api.cost_analysis.v1.DataSourceRequest\x1a\x16.google.protobuf.Empty\"6\x82\xd3\xe4\x93\x02\x30*./cost-analysis/v1/data-source/{data_source_id}\x12\xa1\x01\n\x04sync\x12\x34.spaceone.api.cost_analysis.v1.SyncDataSourceRequest\x1a&.spaceone.api.cost_analysis.v1.JobInfo\";\x82\xd3\xe4\x93\x02\x35\"3/cost-analysis/v1/data-source/{data_source_id}/sync\x12\xa1\x01\n\x03get\x12\x33.spaceone.api.cost_analysis.v1.GetDataSourceRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\"6\x82\xd3\xe4\x93\x02\x30\x12./cost-analysis/v1/data-source/{data_source_id}\x12\xb7\x01\n\x04list\x12..spaceone.api.cost_analysis.v1.DataSourceQuery\x1a..spaceone.api.cost_analysis.v1.DataSourcesInfo\"O\x82\xd3\xe4\x93\x02I\x12\x1e/cost-analysis/v1/data-sourcesZ\'\"%/cost-analysis/v1/data-sources/search\x12\x80\x01\n\x04stat\x12\x32.spaceone.api.cost_analysis.v1.DataSourceStatQuery\x1a\x17.google.protobuf.Struct\"+\x82\xd3\xe4\x93\x02%\"#/cost-analysis/v1/data-sources/statb\x06proto3')



_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_REGISTERDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['RegisterDataSourceRequest']
_UPDATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourceRequest']
_UPDATEDATASOURCEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourcePluginRequest']
_SYNCDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['SyncDataSourceRequest']
_DATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DataSourceRequest']
_GETDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetDataSourceRequest']
_DATASOURCEQUERY = DESCRIPTOR.message_types_by_name['DataSourceQuery']
_DATASOURCEINFO = DESCRIPTOR.message_types_by_name['DataSourceInfo']
_DATASOURCESINFO = DESCRIPTOR.message_types_by_name['DataSourcesInfo']
_DATASOURCESTATQUERY = DESCRIPTOR.message_types_by_name['DataSourceStatQuery']
_PLUGININFO_UPGRADEMODE = _PLUGININFO.enum_types_by_name['UpgradeMode']
_REGISTERDATASOURCEREQUEST_DATASOURCETYPE = _REGISTERDATASOURCEREQUEST.enum_types_by_name['DataSourceType']
_UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE = _UPDATEDATASOURCEPLUGINREQUEST.enum_types_by_name['UpgradeMode']
_DATASOURCEQUERY_DATASOURCETYPE = _DATASOURCEQUERY.enum_types_by_name['DataSourceType']
_DATASOURCEINFO_STATE = _DATASOURCEINFO.enum_types_by_name['State']
_DATASOURCEINFO_DATASOURCETYPE = _DATASOURCEINFO.enum_types_by_name['DataSourceType']
PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

RegisterDataSourceRequest = _reflection.GeneratedProtocolMessageType('RegisterDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.RegisterDataSourceRequest)
  })
_sym_db.RegisterMessage(RegisterDataSourceRequest)

UpdateDataSourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateDataSourceRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRequest)

UpdateDataSourcePluginRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourcePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEPLUGINREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateDataSourcePluginRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourcePluginRequest)

SyncDataSourceRequest = _reflection.GeneratedProtocolMessageType('SyncDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNCDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SyncDataSourceRequest)
  })
_sym_db.RegisterMessage(SyncDataSourceRequest)

DataSourceRequest = _reflection.GeneratedProtocolMessageType('DataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRequest)
  })
_sym_db.RegisterMessage(DataSourceRequest)

GetDataSourceRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetDataSourceRequest)
  })
_sym_db.RegisterMessage(GetDataSourceRequest)

DataSourceQuery = _reflection.GeneratedProtocolMessageType('DataSourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceQuery)
  })
_sym_db.RegisterMessage(DataSourceQuery)

DataSourceInfo = _reflection.GeneratedProtocolMessageType('DataSourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceInfo)
  })
_sym_db.RegisterMessage(DataSourceInfo)

DataSourcesInfo = _reflection.GeneratedProtocolMessageType('DataSourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourcesInfo)
  })
_sym_db.RegisterMessage(DataSourcesInfo)

DataSourceStatQuery = _reflection.GeneratedProtocolMessageType('DataSourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceStatQuery)
  })
_sym_db.RegisterMessage(DataSourceStatQuery)

_DATASOURCE = DESCRIPTOR.services_by_name['DataSource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATASOURCE.methods_by_name['register']._options = None
  _DATASOURCE.methods_by_name['register']._serialized_options = b'\202\323\344\223\002 \"\036/cost-analysis/v1/data-sources'
  _DATASOURCE.methods_by_name['update']._options = None
  _DATASOURCE.methods_by_name['update']._serialized_options = b'\202\323\344\223\0020\032./cost-analysis/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['update_plugin']._options = None
  _DATASOURCE.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\0027\0325/cost-analysis/v1/data-source/{data_source_id}/plugin'
  _DATASOURCE.methods_by_name['verify_plugin']._options = None
  _DATASOURCE.methods_by_name['verify_plugin']._serialized_options = b'\202\323\344\223\002>\"</cost-analysis/v1/data-source/{data_source_id}/plugin/verify'
  _DATASOURCE.methods_by_name['enable']._options = None
  _DATASOURCE.methods_by_name['enable']._serialized_options = b'\202\323\344\223\0027\0325/cost-analysis/v1/data-source/{data_source_id}/enable'
  _DATASOURCE.methods_by_name['disable']._options = None
  _DATASOURCE.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0028\0326/cost-analysis/v1/data-source/{data_source_id}/disable'
  _DATASOURCE.methods_by_name['deregister']._options = None
  _DATASOURCE.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\0020*./cost-analysis/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['sync']._options = None
  _DATASOURCE.methods_by_name['sync']._serialized_options = b'\202\323\344\223\0025\"3/cost-analysis/v1/data-source/{data_source_id}/sync'
  _DATASOURCE.methods_by_name['get']._options = None
  _DATASOURCE.methods_by_name['get']._serialized_options = b'\202\323\344\223\0020\022./cost-analysis/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['list']._options = None
  _DATASOURCE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002I\022\036/cost-analysis/v1/data-sourcesZ\'\"%/cost-analysis/v1/data-sources/search'
  _DATASOURCE.methods_by_name['stat']._options = None
  _DATASOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002%\"#/cost-analysis/v1/data-sources/stat'
  _PLUGININFO._serialized_start=247
  _PLUGININFO._serialized_end=585
  _PLUGININFO_UPGRADEMODE._serialized_start=540
  _PLUGININFO_UPGRADEMODE._serialized_end=585
  _REGISTERDATASOURCEREQUEST._serialized_start=588
  _REGISTERDATASOURCEREQUEST._serialized_end=964
  _REGISTERDATASOURCEREQUEST_DATASOURCETYPE._serialized_start=913
  _REGISTERDATASOURCEREQUEST_DATASOURCETYPE._serialized_end=964
  _UPDATEDATASOURCEREQUEST._serialized_start=967
  _UPDATEDATASOURCEREQUEST._serialized_end=1131
  _UPDATEDATASOURCEPLUGINREQUEST._serialized_start=1134
  _UPDATEDATASOURCEPLUGINREQUEST._serialized_end=1410
  _UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE._serialized_start=540
  _UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE._serialized_end=585
  _SYNCDATASOURCEREQUEST._serialized_start=1412
  _SYNCDATASOURCEREQUEST._serialized_end=1519
  _DATASOURCEREQUEST._serialized_start=1521
  _DATASOURCEREQUEST._serialized_end=1583
  _GETDATASOURCEREQUEST._serialized_start=1585
  _GETDATASOURCEREQUEST._serialized_end=1664
  _DATASOURCEQUERY._serialized_start=1667
  _DATASOURCEQUERY._serialized_end=1960
  _DATASOURCEQUERY_DATASOURCETYPE._serialized_start=913
  _DATASOURCEQUERY_DATASOURCETYPE._serialized_end=964
  _DATASOURCEINFO._serialized_start=1963
  _DATASOURCEINFO._serialized_end=2574
  _DATASOURCEINFO_STATE._serialized_start=2466
  _DATASOURCEINFO_STATE._serialized_end=2516
  _DATASOURCEINFO_DATASOURCETYPE._serialized_start=2518
  _DATASOURCEINFO_DATASOURCETYPE._serialized_end=2574
  _DATASOURCESINFO._serialized_start=2576
  _DATASOURCESINFO._serialized_end=2678
  _DATASOURCESTATQUERY._serialized_start=2680
  _DATASOURCESTATQUERY._serialized_end=2774
  _DATASOURCE._serialized_start=2777
  _DATASOURCE._serialized_end=4603
# @@protoc_insertion_point(module_scope)
