# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import cloud_service_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2


class CloudServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/create',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CreateServiceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/update',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.UpdateCloudServiceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/delete',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/get',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.GetCloudServiceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/list',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServicesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.allow_delete_stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/allow_delete_stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class CloudServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new CloudService. A CloudService instance is created based on data including the `resource`'s attribute values. When creating, the classification information defined by CloudServiceType is also needed. The created CloudService has collection information which is the collection history for the `resource` by plugin.
        request_example: >-
        {
        "cloud_service_type": "Key",
        "provider": "aws",
        "cloud_service_group": "KMS",
        "name": "cloud_service_test",
        "account": "251340636361",
        "launched_at": "2020-08-03T15:00:54.000Z",
        "ip_addresses": [],
        "data": {
        "alias_arn": null,
        "origin": "AWS_KMS",
        "cloudwatch": {
        "region_name": "ap-northeast-1",
        "namespace": "AWS/KMS",
        "dimensions": [
        {
        "Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "Name": "KeyId"
        }
        ]
        },
        "aws_account_id": "251340636361",
        "creation_date": "2020-07-09T09:39:03.097000+0000",
        "encryption_algorithms": [
        "SYMMETRIC_DEFAULT"
        ],
        "key_usage": "ENCRYPT_DECRYPT",
        "key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_type_path": "defaultKeys",
        "key_rotated": false,
        "description": "Default master key that protects my Secrets Manager data when no other key is defined",
        "key_state": "Enabled",
        "customer_master_key_spec": "SYMMETRIC_DEFAULT",
        "enabled": true,
        "arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_manager": "AWS"
        },
        "metadata": {},
        "reference": {
        "resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
        },
        "tags": {
        "a": "b"
        },
        "region_code": "ap-northeast-1"
        }
        response_example: >-
        {
        "cloud_service_id": "cloud-svc-c00f38a173e1",
        "name": "cloud_service_test",
        "state": "ACTIVE",
        "account": "251340636361",
        "cloud_service_type": "Key",
        "cloud_service_group": "KMS",
        "provider": "aws",
        "data": {
        "alias_arn": null,
        "origin": "AWS_KMS",
        "cloudwatch": {
        "region_name": "ap-northeast-1",
        "namespace": "AWS/KMS",
        "dimensions": [
        {
        "Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "Name": "KeyId"
        }
        ]
        },
        "aws_account_id": "251340636361",
        "creation_date": "2020-07-09T09:39:03.097000+0000",
        "encryption_algorithms": [
        "SYMMETRIC_DEFAULT"
        ],
        "key_usage": "ENCRYPT_DECRYPT",
        "key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_type_path": "defaultKeys",
        "key_rotated": false,
        "description": "Default master key that protects my Secrets Manager data when no other key is defined",
        "key_state": "Enabled",
        "customer_master_key_spec": "SYMMETRIC_DEFAULT",
        "enabled": true,
        "arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_manager": "AWS"
        },
        "metadata": {
        "manual": {}
        },
        "reference": {
        "resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
        },
        "tags": {
        "a": "b"
        },
        "collection_info": {
        "collectors": [],
        "service_accounts": [],
        "secrets": []
        },
        "ip_addresses": [],
        "region_code": "ap-northeast-1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T06:38:48.989Z",
        "updated_at": "2022-06-22T06:38:48.989Z",
        "launched_at": "2020-08-03T15:00:54.000Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific CloudService. You can make changes in CloudService settings, except for the classification system of CloudService and the information about the `resource` attribute value.
        request_example: >-
        {
        "cloud_service_id": "cloud-svc-c00f38a173e1",
        "name": "cloud_service_test2",
        "ip_addresses": [
        "1.1.1.1",
        "2.2.2.2"
        ],
        "tags": {
        "description": "spaceone"
        },
        "region_code": "ap-northeast-2"
        }
        response_example: >-
        {
        "cloud_service_id": "cloud-svc-c00f38a173e1",
        "name": "cloud_service_test2",
        "state": "ACTIVE",
        "account": "251340636361",
        "cloud_service_type": "Key",
        "cloud_service_group": "KMS",
        "provider": "aws",
        "data": {
        "alias_arn": null,
        "origin": "AWS_KMS",
        "cloudwatch": {
        "region_name": "ap-northeast-1",
        "namespace": "AWS/KMS",
        "dimensions": [
        {
        "Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "Name": "KeyId"
        }
        ]
        },
        "aws_account_id": "251340636361",
        "creation_date": "2020-07-09T09:39:03.097000+0000",
        "encryption_algorithms": [
        "SYMMETRIC_DEFAULT"
        ],
        "key_usage": "ENCRYPT_DECRYPT",
        "key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_type_path": "defaultKeys",
        "key_rotated": false,
        "description": "Default master key that protects my Secrets Manager data when no other key is defined",
        "key_state": "Enabled",
        "customer_master_key_spec": "SYMMETRIC_DEFAULT",
        "enabled": true,
        "arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_manager": "AWS"
        },
        "metadata": {
        "manual": {}
        },
        "reference": {
        "resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
        },
        "tags": {
        "description": "spaceone"
        },
        "collection_info": {
        "collectors": [],
        "service_accounts": [],
        "secrets": []
        },
        "ip_addresses": [
        "1.1.1.1",
        "2.2.2.2"
        ],
        "region_code": "ap-northeast-1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T06:38:48.989Z",
        "updated_at": "2022-06-22T06:38:48.989Z",
        "launched_at": "2020-08-03T15:00:54.000Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific CloudService. You must specify the `cloud_service_id` of the CloudService to delete.
        request_example: >-
        {
        "cloud_service_id": "cloud-svc-fea2b0d32141"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific CloudService. Prints detailed information about the CloudService, including its state, classification information, and attribute values.
        request_example: >-
        {
        "cloud_service_id": "cloud-svc-fea2b0d32141"
        }
        response_example: >-
        {
        "cloud_service_id": "cloud-svc-c00f38a173e1",
        "name": "cloud_service_test2",
        "state": "ACTIVE",
        "account": "251340636361",
        "cloud_service_type": "Key",
        "cloud_service_group": "KMS",
        "provider": "aws",
        "data": {
        "alias_arn": null,
        "origin": "AWS_KMS",
        "cloudwatch": {
        "region_name": "ap-northeast-1",
        "namespace": "AWS/KMS",
        "dimensions": [
        {
        "Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "Name": "KeyId"
        }
        ]
        },
        "aws_account_id": "251340636361",
        "creation_date": "2020-07-09T09:39:03.097000+0000",
        "encryption_algorithms": [
        "SYMMETRIC_DEFAULT"
        ],
        "key_usage": "ENCRYPT_DECRYPT",
        "key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_type_path": "defaultKeys",
        "key_rotated": false,
        "description": "Default master key that protects my Secrets Manager data when no other key is defined",
        "key_state": "Enabled",
        "customer_master_key_spec": "SYMMETRIC_DEFAULT",
        "enabled": true,
        "arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_manager": "AWS"
        },
        "metadata": {
        "manual": {}
        },
        "reference": {
        "resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
        },
        "tags": {
        "description": "spaceone"
        },
        "collection_info": {
        "collectors": [],
        "service_accounts": [],
        "secrets": []
        },
        "ip_addresses": [
        "1.1.1.1",
        "2.2.2.2"
        ],
        "region_code": "ap-northeast-1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T06:38:48.989Z",
        "updated_at": "2022-06-22T06:38:48.989Z",
        "launched_at": "2020-08-03T15:00:54.000Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all CloudServices. You can use a query to get a filtered list of CloudServices.
        request_example: >-
        {
        "query": {
        "filter": [
        {
        "key": "cloud_service_type",
        "value": "Key",
        "operator": "eq"
        }
        ]
        }
        }
        response_example: >-
        {
        "results": [{
        "cloud_service_id": "cloud-svc-c00f38a173e1",
        "name": "cloud_service_test2",
        "state": "ACTIVE",
        "account": "251340636361",
        "cloud_service_type": "Key",
        "cloud_service_group": "KMS",
        "provider": "aws",
        "data": {
        "alias_arn": null,
        "origin": "AWS_KMS",
        "cloudwatch": {
        "region_name": "ap-northeast-1",
        "namespace": "AWS/KMS",
        "dimensions": [
        {
        "Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "Name": "KeyId"
        }
        ]
        },
        "aws_account_id": "251340636361",
        "creation_date": "2020-07-09T09:39:03.097000+0000",
        "encryption_algorithms": [
        "SYMMETRIC_DEFAULT"
        ],
        "key_usage": "ENCRYPT_DECRYPT",
        "key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_type_path": "defaultKeys",
        "key_rotated": false,
        "description": "Default master key that protects my Secrets Manager data when no other key is defined",
        "key_state": "Enabled",
        "customer_master_key_spec": "SYMMETRIC_DEFAULT",
        "enabled": true,
        "arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_manager": "AWS"
        },
        "metadata": {
        "manual": {}
        },
        "reference": {
        "resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
        },
        "tags": {
        "description": "spaceone"
        },
        "collection_info": {
        "collectors": [],
        "service_accounts": [],
        "secrets": []
        },
        "ip_addresses": [
        "1.1.1.1",
        "2.2.2.2"
        ],
        "region_code": "ap-northeast-1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T06:38:48.989Z",
        "updated_at": "2022-06-22T06:38:48.989Z",
        "launched_at": "2020-08-03T15:00:54.000Z"
        }],
        "total_count": 1
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def allow_delete_stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CloudServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CreateServiceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.UpdateCloudServiceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.GetCloudServiceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServicesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'allow_delete_stat': grpc.unary_unary_rpc_method_handler(
                    servicer.allow_delete_stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.CloudService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CloudService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/create',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CreateServiceRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/update',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.UpdateCloudServiceRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/delete',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/get',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.GetCloudServiceRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/list',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServicesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def allow_delete_stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/allow_delete_stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
