# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import savings_recommendation_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2


class SavingsRecommendationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsRecommendation/get',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.GetSavingsRecommendationRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsRecommendation/list',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsRecommendation/stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class SavingsRecommendationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SavingsRecommendationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.GetSavingsRecommendationRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.SavingsRecommendation', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SavingsRecommendation(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsRecommendation/get',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.GetSavingsRecommendationRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsRecommendation/list',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsRecommendation/stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
