# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/stack_resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1spaceone/api/provisioning/v1/stack_resource.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xa5\x03\n\x1a\x43reateStackResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\x16\n\x0eterraform_code\x18\x05 \x01(\t\x12\x13\n\x0bvalid_value\x18\x06 \x03(\t\x12\x35\n\x14terraform_properties\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x12\n\nupdated_at\x18\n \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0b \x01(\t\x12\x0f\n\x07node_id\x18\x0c \x01(\r\x12\x11\n\timmutable\x18\r \x01(\t\x12\x33\n\x12\x61nsible_properties\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x0f \x01(\t\"V\n\x14StackResourceRequest\x12\x19\n\x11stack_resource_id\x18\x01 \x01(\t\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"U\n\x17GetStackResourceRequest\x12\x19\n\x11stack_resource_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xc0\x03\n\x1aUpdateStackResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11stack_resource_id\x18\x02 \x01(\t\x12\x10\n\x08stack_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x35\n\x14terraform_properties\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0c \x01(\t\x12\x0f\n\x07node_id\x18\r \x01(\r\x12\x11\n\timmutable\x18\x0e \x01(\t\x12\x33\n\x12\x61nsible_properties\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x10 \x01(\t\"\xd2\x01\n\x12StackResourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11stack_resource_id\x18\x02 \x01(\t\x12\x10\n\x08stack_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12$\n\x03tag\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"a\n\x16StackResourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xdf\x03\n\x11StackResourceInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11stack_resource_id\x18\x02 \x01(\t\x12\x10\n\x08stack_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x35\n\x14terraform_properties\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0c \x01(\t\x12\x12\n\ncreated_by\x18\r \x01(\t\x12\x12\n\nupdated_by\x18\x0e \x01(\t\x12\x0f\n\x07node_id\x18\x0f \x01(\r\x12\x11\n\timmutable\x18\x10 \x01(\t\x12\x33\n\x12\x61nsible_properties\x18\x11 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x12 \x01(\t\"k\n\x12StackResourcesInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.provisioning.v1.StackResourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xa1\x08\n\rStackResource\x12\xab\x01\n\x15\x63reate_stack_resource\x12\x38.spaceone.api.provisioning.v1.CreateStackResourceRequest\x1a/.spaceone.api.provisioning.v1.StackResourceInfo\"\'\x82\xd3\xe4\x93\x02!\"\x1f/provisioning/v1/stack-resource\x12\xce\x01\n\x13get_stack_resources\x12\x30.spaceone.api.provisioning.v1.StackResourceQuery\x1a\x30.spaceone.api.provisioning.v1.StackResourcesInfo\"S\x82\xd3\xe4\x93\x02M\x12 /provisioning/v1/stack-resourcesZ)\"\'/provisioning/v1/stack-resources/search\x12\xb9\x01\n\x12get_stack_resource\x12\x35.spaceone.api.provisioning.v1.GetStackResourceRequest\x1a/.spaceone.api.provisioning.v1.StackResourceInfo\";\x82\xd3\xe4\x93\x02\x35\x12\x33/provisioning/v1/stack-resource/{stack_resource_id}\x12\xab\x01\n\x15update_stack_resource\x12\x38.spaceone.api.provisioning.v1.UpdateStackResourceRequest\x1a/.spaceone.api.provisioning.v1.StackResourceInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/provisioning/v1/stack-resource\x12\xa0\x01\n\x15\x64\x65lete_stack_resource\x12\x32.spaceone.api.provisioning.v1.StackResourceRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35*3/provisioning/v1/stack-resource/{stack_resource_id}\x12\x83\x01\n\x04stat\x12\x34.spaceone.api.provisioning.v1.StackResourceStatQuery\x1a\x17.google.protobuf.Struct\",\x82\xd3\xe4\x93\x02&\"$/provisioning/v1/stack-resource/statb\x06proto3')



_CREATESTACKRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateStackResourceRequest']
_STACKRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['StackResourceRequest']
_GETSTACKRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetStackResourceRequest']
_UPDATESTACKRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateStackResourceRequest']
_STACKRESOURCEQUERY = DESCRIPTOR.message_types_by_name['StackResourceQuery']
_STACKRESOURCESTATQUERY = DESCRIPTOR.message_types_by_name['StackResourceStatQuery']
_STACKRESOURCEINFO = DESCRIPTOR.message_types_by_name['StackResourceInfo']
_STACKRESOURCESINFO = DESCRIPTOR.message_types_by_name['StackResourcesInfo']
CreateStackResourceRequest = _reflection.GeneratedProtocolMessageType('CreateStackResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTACKRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateStackResourceRequest)
  })
_sym_db.RegisterMessage(CreateStackResourceRequest)

StackResourceRequest = _reflection.GeneratedProtocolMessageType('StackResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceRequest)
  })
_sym_db.RegisterMessage(StackResourceRequest)

GetStackResourceRequest = _reflection.GeneratedProtocolMessageType('GetStackResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTACKRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetStackResourceRequest)
  })
_sym_db.RegisterMessage(GetStackResourceRequest)

UpdateStackResourceRequest = _reflection.GeneratedProtocolMessageType('UpdateStackResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTACKRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateStackResourceRequest)
  })
_sym_db.RegisterMessage(UpdateStackResourceRequest)

StackResourceQuery = _reflection.GeneratedProtocolMessageType('StackResourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceQuery)
  })
_sym_db.RegisterMessage(StackResourceQuery)

StackResourceStatQuery = _reflection.GeneratedProtocolMessageType('StackResourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCESTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceStatQuery)
  })
_sym_db.RegisterMessage(StackResourceStatQuery)

StackResourceInfo = _reflection.GeneratedProtocolMessageType('StackResourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceInfo)
  })
_sym_db.RegisterMessage(StackResourceInfo)

StackResourcesInfo = _reflection.GeneratedProtocolMessageType('StackResourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourcesInfo)
  })
_sym_db.RegisterMessage(StackResourcesInfo)

_STACKRESOURCE = DESCRIPTOR.services_by_name['StackResource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STACKRESOURCE.methods_by_name['create_stack_resource']._options = None
  _STACKRESOURCE.methods_by_name['create_stack_resource']._serialized_options = b'\202\323\344\223\002!\"\037/provisioning/v1/stack-resource'
  _STACKRESOURCE.methods_by_name['get_stack_resources']._options = None
  _STACKRESOURCE.methods_by_name['get_stack_resources']._serialized_options = b'\202\323\344\223\002M\022 /provisioning/v1/stack-resourcesZ)\"\'/provisioning/v1/stack-resources/search'
  _STACKRESOURCE.methods_by_name['get_stack_resource']._options = None
  _STACKRESOURCE.methods_by_name['get_stack_resource']._serialized_options = b'\202\323\344\223\0025\0223/provisioning/v1/stack-resource/{stack_resource_id}'
  _STACKRESOURCE.methods_by_name['update_stack_resource']._options = None
  _STACKRESOURCE.methods_by_name['update_stack_resource']._serialized_options = b'\202\323\344\223\002!\032\037/provisioning/v1/stack-resource'
  _STACKRESOURCE.methods_by_name['delete_stack_resource']._options = None
  _STACKRESOURCE.methods_by_name['delete_stack_resource']._serialized_options = b'\202\323\344\223\0025*3/provisioning/v1/stack-resource/{stack_resource_id}'
  _STACKRESOURCE.methods_by_name['stat']._options = None
  _STACKRESOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002&\"$/provisioning/v1/stack-resource/stat'
  _CREATESTACKRESOURCEREQUEST._serialized_start=207
  _CREATESTACKRESOURCEREQUEST._serialized_end=628
  _STACKRESOURCEREQUEST._serialized_start=630
  _STACKRESOURCEREQUEST._serialized_end=716
  _GETSTACKRESOURCEREQUEST._serialized_start=718
  _GETSTACKRESOURCEREQUEST._serialized_end=803
  _UPDATESTACKRESOURCEREQUEST._serialized_start=806
  _UPDATESTACKRESOURCEREQUEST._serialized_end=1254
  _STACKRESOURCEQUERY._serialized_start=1257
  _STACKRESOURCEQUERY._serialized_end=1467
  _STACKRESOURCESTATQUERY._serialized_start=1469
  _STACKRESOURCESTATQUERY._serialized_end=1566
  _STACKRESOURCEINFO._serialized_start=1569
  _STACKRESOURCEINFO._serialized_end=2048
  _STACKRESOURCESINFO._serialized_start=2050
  _STACKRESOURCESINFO._serialized_end=2157
  _STACKRESOURCE._serialized_start=2160
  _STACKRESOURCE._serialized_end=3217
# @@protoc_insertion_point(module_scope)
