# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/plugin/notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3spaceone/api/notification/plugin/notification.proto\x12 spaceone.api.notification.plugin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x8c\x03\n\x15PluginDispatchRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07message\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x63\n\x11notification_type\x18\x03 \x01(\x0e\x32H.spaceone.api.notification.plugin.PluginDispatchRequest.NotificationType\x12,\n\x0bsecret_data\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12-\n\x0c\x63hannel_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"]\n\x10NotificationType\x12\x1a\n\x16NOTIFICATION_TYPE_NONE\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07WARNING\x10\x04\x32m\n\x0cNotification\x12]\n\x08\x64ispatch\x12\x37.spaceone.api.notification.plugin.PluginDispatchRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')



_PLUGINDISPATCHREQUEST = DESCRIPTOR.message_types_by_name['PluginDispatchRequest']
_PLUGINDISPATCHREQUEST_NOTIFICATIONTYPE = _PLUGINDISPATCHREQUEST.enum_types_by_name['NotificationType']
PluginDispatchRequest = _reflection.GeneratedProtocolMessageType('PluginDispatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINDISPATCHREQUEST,
  '__module__' : 'spaceone.api.notification.plugin.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.plugin.PluginDispatchRequest)
  })
_sym_db.RegisterMessage(PluginDispatchRequest)

_NOTIFICATION = DESCRIPTOR.services_by_name['Notification']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLUGINDISPATCHREQUEST._serialized_start=149
  _PLUGINDISPATCHREQUEST._serialized_end=545
  _PLUGINDISPATCHREQUEST_NOTIFICATIONTYPE._serialized_start=452
  _PLUGINDISPATCHREQUEST_NOTIFICATIONTYPE._serialized_end=545
  _NOTIFICATION._serialized_start=547
  _NOTIFICATION._serialized_end=656
# @@protoc_insertion_point(module_scope)
