# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/plugin/cost.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/cost_analysis/plugin/cost.proto\x12!spaceone.api.cost_analysis.plugin\x1a\x1cgoogle/protobuf/struct.proto\"\xba\x01\n\x0eGetDataRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12-\n\x0ctask_options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"\xcd\x03\n\x08\x43ostInfo\x12\x0c\n\x04\x63ost\x18\x01 \x01(\x01\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\x12\x16\n\x0eusage_quantity\x18\x03 \x01(\x01\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x13\n\x0bregion_code\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x06 \x01(\t\x12\x0f\n\x07product\x18\x07 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x08 \x01(\t\x12\x12\n\nusage_type\x18\t \x01(\t\x12\x16\n\x0eresource_group\x18\n \x01(\t\x12\x10\n\x08resource\x18\x0b \x01(\t\x12%\n\x04tags\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0f\x61\x64\x64itional_info\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tbilled_at\x18\x0e \x01(\t\x12\x11\n\tcost_type\x18\x0f \x01(\t\x12\x14\n\x0cproduct_code\x18\x10 \x01(\t\x12\x1d\n\x15original_product_code\x18\x11 \x01(\t\x12\x13\n\x0bproduct_sku\x18\x12 \x01(\t\x12\x15\n\rexchange_rate\x18\x13 \x01(\x01\x12\x10\n\x08usd_cost\x18\x14 \x01(\x01\"I\n\tCostsInfo\x12<\n\x07results\x18\x01 \x03(\x0b\x32+.spaceone.api.cost_analysis.plugin.CostInfo2w\n\x04\x43ost\x12o\n\x08get_data\x12\x31.spaceone.api.cost_analysis.plugin.GetDataRequest\x1a,.spaceone.api.cost_analysis.plugin.CostsInfo\"\x00\x30\x01\x62\x06proto3')



_GETDATAREQUEST = DESCRIPTOR.message_types_by_name['GetDataRequest']
_COSTINFO = DESCRIPTOR.message_types_by_name['CostInfo']
_COSTSINFO = DESCRIPTOR.message_types_by_name['CostsInfo']
GetDataRequest = _reflection.GeneratedProtocolMessageType('GetDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.plugin.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.plugin.GetDataRequest)
  })
_sym_db.RegisterMessage(GetDataRequest)

CostInfo = _reflection.GeneratedProtocolMessageType('CostInfo', (_message.Message,), {
  'DESCRIPTOR' : _COSTINFO,
  '__module__' : 'spaceone.api.cost_analysis.plugin.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.plugin.CostInfo)
  })
_sym_db.RegisterMessage(CostInfo)

CostsInfo = _reflection.GeneratedProtocolMessageType('CostsInfo', (_message.Message,), {
  'DESCRIPTOR' : _COSTSINFO,
  '__module__' : 'spaceone.api.cost_analysis.plugin.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.plugin.CostsInfo)
  })
_sym_db.RegisterMessage(CostsInfo)

_COST = DESCRIPTOR.services_by_name['Cost']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETDATAREQUEST._serialized_start=114
  _GETDATAREQUEST._serialized_end=300
  _COSTINFO._serialized_start=303
  _COSTINFO._serialized_end=764
  _COSTSINFO._serialized_start=766
  _COSTSINFO._serialized_end=839
  _COST._serialized_start=841
  _COST._serialized_end=960
# @@protoc_insertion_point(module_scope)
