# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/resource_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.spaceone/api/inventory/v1/resource_group.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"^\n\x08Resource\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12*\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x0f\n\x07keyword\x18\x03 \x01(\t\"\xda\x01\n\x1a\x43reateResourceGroupRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\tresources\x18\x02 \x03(\x0b\x32#.spaceone.api.inventory.v1.Resource\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"\x8e\x02\n\x1aUpdateResourceGroupRequest\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\tresources\x18\x03 \x03(\x0b\x32#.spaceone.api.inventory.v1.Resource\x12(\n\x07options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x17\n\x0frelease_project\x18\x0b \x01(\x08\x12\x12\n\nproject_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\"D\n\x14ResourceGroupRequest\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"U\n\x17GetResourceGroupRequest\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x90\x01\n\x12ResourceGroupQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11resource_group_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"\x80\x02\n\x11ResourceGroupInfo\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\tresources\x18\x03 \x03(\x0b\x32#.spaceone.api.inventory.v1.Resource\x12(\n\x07options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\x12\x12\n\ncreated_at\x18\x08 \x01(\t\"h\n\x12ResourceGroupsInfo\x12=\n\x07results\x18\x01 \x03(\x0b\x32,.spaceone.api.inventory.v1.ResourceGroupInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"a\n\x16ResourceGroupStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xb8\x07\n\rResourceGroup\x12\x94\x01\n\x06\x63reate\x12\x35.spaceone.api.inventory.v1.CreateResourceGroupRequest\x1a,.spaceone.api.inventory.v1.ResourceGroupInfo\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/inventory/v1/resource-groups\x12\xa7\x01\n\x06update\x12\x35.spaceone.api.inventory.v1.UpdateResourceGroupRequest\x1a,.spaceone.api.inventory.v1.ResourceGroupInfo\"8\x82\xd3\xe4\x93\x02\x32\x1a\x30/inventory/v1/resource-group/{resource_group_id}\x12\x8b\x01\n\x06\x64\x65lete\x12/.spaceone.api.inventory.v1.ResourceGroupRequest\x1a\x16.google.protobuf.Empty\"8\x82\xd3\xe4\x93\x02\x32*0/inventory/v1/resource-group/{resource_group_id}\x12\xa1\x01\n\x03get\x12\x32.spaceone.api.inventory.v1.GetResourceGroupRequest\x1a,.spaceone.api.inventory.v1.ResourceGroupInfo\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/inventory/v1/resource-group/{resource_group_id}\x12\xb3\x01\n\x04list\x12-.spaceone.api.inventory.v1.ResourceGroupQuery\x1a-.spaceone.api.inventory.v1.ResourceGroupsInfo\"M\x82\xd3\xe4\x93\x02G\x12\x1d/inventory/v1/resource-groupsZ&\"$/inventory/v1/resource-groups/search\x12~\n\x04stat\x12\x31.spaceone.api.inventory.v1.ResourceGroupStatQuery\x1a\x17.google.protobuf.Struct\"*\x82\xd3\xe4\x93\x02$\"\"/inventory/v1/resource-groups/statb\x06proto3')



_RESOURCE = DESCRIPTOR.message_types_by_name['Resource']
_CREATERESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateResourceGroupRequest']
_UPDATERESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateResourceGroupRequest']
_RESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['ResourceGroupRequest']
_GETRESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetResourceGroupRequest']
_RESOURCEGROUPQUERY = DESCRIPTOR.message_types_by_name['ResourceGroupQuery']
_RESOURCEGROUPINFO = DESCRIPTOR.message_types_by_name['ResourceGroupInfo']
_RESOURCEGROUPSINFO = DESCRIPTOR.message_types_by_name['ResourceGroupsInfo']
_RESOURCEGROUPSTATQUERY = DESCRIPTOR.message_types_by_name['ResourceGroupStatQuery']
Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Resource)
  })
_sym_db.RegisterMessage(Resource)

CreateResourceGroupRequest = _reflection.GeneratedProtocolMessageType('CreateResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateResourceGroupRequest)
  })
_sym_db.RegisterMessage(CreateResourceGroupRequest)

UpdateResourceGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateResourceGroupRequest)
  })
_sym_db.RegisterMessage(UpdateResourceGroupRequest)

ResourceGroupRequest = _reflection.GeneratedProtocolMessageType('ResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceGroupRequest)
  })
_sym_db.RegisterMessage(ResourceGroupRequest)

GetResourceGroupRequest = _reflection.GeneratedProtocolMessageType('GetResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetResourceGroupRequest)
  })
_sym_db.RegisterMessage(GetResourceGroupRequest)

ResourceGroupQuery = _reflection.GeneratedProtocolMessageType('ResourceGroupQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceGroupQuery)
  })
_sym_db.RegisterMessage(ResourceGroupQuery)

ResourceGroupInfo = _reflection.GeneratedProtocolMessageType('ResourceGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceGroupInfo)
  })
_sym_db.RegisterMessage(ResourceGroupInfo)

ResourceGroupsInfo = _reflection.GeneratedProtocolMessageType('ResourceGroupsInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPSINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceGroupsInfo)
  })
_sym_db.RegisterMessage(ResourceGroupsInfo)

ResourceGroupStatQuery = _reflection.GeneratedProtocolMessageType('ResourceGroupStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceGroupStatQuery)
  })
_sym_db.RegisterMessage(ResourceGroupStatQuery)

_RESOURCEGROUP = DESCRIPTOR.services_by_name['ResourceGroup']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCEGROUP.methods_by_name['create']._options = None
  _RESOURCEGROUP.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\037\"\035/inventory/v1/resource-groups'
  _RESOURCEGROUP.methods_by_name['update']._options = None
  _RESOURCEGROUP.methods_by_name['update']._serialized_options = b'\202\323\344\223\0022\0320/inventory/v1/resource-group/{resource_group_id}'
  _RESOURCEGROUP.methods_by_name['delete']._options = None
  _RESOURCEGROUP.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0022*0/inventory/v1/resource-group/{resource_group_id}'
  _RESOURCEGROUP.methods_by_name['get']._options = None
  _RESOURCEGROUP.methods_by_name['get']._serialized_options = b'\202\323\344\223\0022\0220/inventory/v1/resource-group/{resource_group_id}'
  _RESOURCEGROUP.methods_by_name['list']._options = None
  _RESOURCEGROUP.methods_by_name['list']._serialized_options = b'\202\323\344\223\002G\022\035/inventory/v1/resource-groupsZ&\"$/inventory/v1/resource-groups/search'
  _RESOURCEGROUP.methods_by_name['stat']._options = None
  _RESOURCEGROUP.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002$\"\"/inventory/v1/resource-groups/stat'
  _RESOURCE._serialized_start=200
  _RESOURCE._serialized_end=294
  _CREATERESOURCEGROUPREQUEST._serialized_start=297
  _CREATERESOURCEGROUPREQUEST._serialized_end=515
  _UPDATERESOURCEGROUPREQUEST._serialized_start=518
  _UPDATERESOURCEGROUPREQUEST._serialized_end=788
  _RESOURCEGROUPREQUEST._serialized_start=790
  _RESOURCEGROUPREQUEST._serialized_end=858
  _GETRESOURCEGROUPREQUEST._serialized_start=860
  _GETRESOURCEGROUPREQUEST._serialized_end=945
  _RESOURCEGROUPQUERY._serialized_start=948
  _RESOURCEGROUPQUERY._serialized_end=1092
  _RESOURCEGROUPINFO._serialized_start=1095
  _RESOURCEGROUPINFO._serialized_end=1351
  _RESOURCEGROUPSINFO._serialized_start=1353
  _RESOURCEGROUPSINFO._serialized_end=1457
  _RESOURCEGROUPSTATQUERY._serialized_start=1459
  _RESOURCEGROUPSTATQUERY._serialized_end=1556
  _RESOURCEGROUP._serialized_start=1559
  _RESOURCEGROUP._serialized_end=2511
# @@protoc_insertion_point(module_scope)
