# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/price.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%spaceone/api/inventory/v1/price.proto\x12\x19spaceone.api.inventory.v1\x1a\x1cgoogle/api/annotations.proto\"\x97\x01\n\x0fGetPriceRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x14\n\x0cservice_code\x18\x07 \x01(\t\x12\x15\n\rregional_type\x18\x0b \x01(\t\x12\x0f\n\x07\x64\x62_name\x18\x0c \x01(\t\x12\x0f\n\x07storage\x18\r \x01(\t\"\xf0\x01\n\x12GetPriceAltRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\r\n\x05scale\x18\x04 \x01(\t\x12\x11\n\tsort_type\x18\x05 \x01(\t\x12\x32\n\x07\x66ilters\x18\x06 \x03(\x0b\x32!.spaceone.api.inventory.v1.Filter\x12\x14\n\x0cservice_code\x18\x07 \x01(\t\x12\x15\n\rregional_type\x18\x0b \x01(\t\x12\x0f\n\x07\x64\x62_name\x18\x0c \x01(\t\x12\x0f\n\x07storage\x18\r \x01(\t\")\n\x06\x46ilter\x12\t\n\x01k\x18\x01 \x01(\t\x12\t\n\x01o\x18\x02 \x01(\t\x12\t\n\x01v\x18\x03 \x01(\t\"m\n\x16\x43reatePriceInfoRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\r\n\x05\x66orce\x18\x04 \x01(\x08\x12\x14\n\x0cservice_code\x18\x05 \x03(\t\"Q\n\x0c\x43reateResult\x12\x0e\n\x06result\x18\x01 \x01(\t\x12\x31\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32#.spaceone.api.inventory.v1.DataInfo\")\n\x08\x44\x61taInfo\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x11\"`\n\x0bProductInfo\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x0b\n\x03\x63pu\x18\x03 \x01(\x11\x12\x0e\n\x06memory\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\"\xb6\x02\n\x0c\x41ltPriceInfo\x12\x37\n\x07\x63urrent\x18\x01 \x01(\x0b\x32&.spaceone.api.inventory.v1.ProductInfo\x12;\n\x0b\x61lternative\x18\x02 \x01(\x0b\x32&.spaceone.api.inventory.v1.ProductInfo\x12\x39\n\x0e\x63urrent_prices\x18\x03 \x01(\x0b\x32!.spaceone.api.inventory.v1.Prices\x12=\n\x12\x61lternative_prices\x18\x04 \x01(\x0b\x32!.spaceone.api.inventory.v1.Prices\x12\x36\n\x0bprices_diff\x18\x05 \x01(\x0b\x32!.spaceone.api.inventory.v1.Prices\"P\n\x06Prices\x12\x16\n\x0eprice_per_hour\x18\x01 \x01(\x01\x12\x15\n\rprice_per_day\x18\x02 \x01(\x01\x12\x17\n\x0fprice_per_month\x18\x03 \x01(\x01\x32\x93\x03\n\x05Price\x12v\n\x03get\x12*.spaceone.api.inventory.v1.GetPriceRequest\x1a&.spaceone.api.inventory.v1.ProductInfo\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/inventory/v1/price\x12\x8a\x01\n\x0fget_alternative\x12-.spaceone.api.inventory.v1.GetPriceAltRequest\x1a\'.spaceone.api.inventory.v1.AltPriceInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/inventory/v1/price/alt\x12\x84\x01\n\x06\x63reate\x12\x31.spaceone.api.inventory.v1.CreatePriceInfoRequest\x1a\'.spaceone.api.inventory.v1.CreateResult\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/inventory/v1/productsb\x06proto3')



_GETPRICEREQUEST = DESCRIPTOR.message_types_by_name['GetPriceRequest']
_GETPRICEALTREQUEST = DESCRIPTOR.message_types_by_name['GetPriceAltRequest']
_FILTER = DESCRIPTOR.message_types_by_name['Filter']
_CREATEPRICEINFOREQUEST = DESCRIPTOR.message_types_by_name['CreatePriceInfoRequest']
_CREATERESULT = DESCRIPTOR.message_types_by_name['CreateResult']
_DATAINFO = DESCRIPTOR.message_types_by_name['DataInfo']
_PRODUCTINFO = DESCRIPTOR.message_types_by_name['ProductInfo']
_ALTPRICEINFO = DESCRIPTOR.message_types_by_name['AltPriceInfo']
_PRICES = DESCRIPTOR.message_types_by_name['Prices']
GetPriceRequest = _reflection.GeneratedProtocolMessageType('GetPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPRICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetPriceRequest)
  })
_sym_db.RegisterMessage(GetPriceRequest)

GetPriceAltRequest = _reflection.GeneratedProtocolMessageType('GetPriceAltRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPRICEALTREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetPriceAltRequest)
  })
_sym_db.RegisterMessage(GetPriceAltRequest)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Filter)
  })
_sym_db.RegisterMessage(Filter)

CreatePriceInfoRequest = _reflection.GeneratedProtocolMessageType('CreatePriceInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPRICEINFOREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreatePriceInfoRequest)
  })
_sym_db.RegisterMessage(CreatePriceInfoRequest)

CreateResult = _reflection.GeneratedProtocolMessageType('CreateResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESULT,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateResult)
  })
_sym_db.RegisterMessage(CreateResult)

DataInfo = _reflection.GeneratedProtocolMessageType('DataInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATAINFO,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.DataInfo)
  })
_sym_db.RegisterMessage(DataInfo)

ProductInfo = _reflection.GeneratedProtocolMessageType('ProductInfo', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTINFO,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ProductInfo)
  })
_sym_db.RegisterMessage(ProductInfo)

AltPriceInfo = _reflection.GeneratedProtocolMessageType('AltPriceInfo', (_message.Message,), {
  'DESCRIPTOR' : _ALTPRICEINFO,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.AltPriceInfo)
  })
_sym_db.RegisterMessage(AltPriceInfo)

Prices = _reflection.GeneratedProtocolMessageType('Prices', (_message.Message,), {
  'DESCRIPTOR' : _PRICES,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Prices)
  })
_sym_db.RegisterMessage(Prices)

_PRICE = DESCRIPTOR.services_by_name['Price']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRICE.methods_by_name['get']._options = None
  _PRICE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\025\022\023/inventory/v1/price'
  _PRICE.methods_by_name['get_alternative']._options = None
  _PRICE.methods_by_name['get_alternative']._serialized_options = b'\202\323\344\223\002\031\022\027/inventory/v1/price/alt'
  _PRICE.methods_by_name['create']._options = None
  _PRICE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\030\"\026/inventory/v1/products'
  _GETPRICEREQUEST._serialized_start=99
  _GETPRICEREQUEST._serialized_end=250
  _GETPRICEALTREQUEST._serialized_start=253
  _GETPRICEALTREQUEST._serialized_end=493
  _FILTER._serialized_start=495
  _FILTER._serialized_end=536
  _CREATEPRICEINFOREQUEST._serialized_start=538
  _CREATEPRICEINFOREQUEST._serialized_end=647
  _CREATERESULT._serialized_start=649
  _CREATERESULT._serialized_end=730
  _DATAINFO._serialized_start=732
  _DATAINFO._serialized_end=773
  _PRODUCTINFO._serialized_start=775
  _PRODUCTINFO._serialized_end=871
  _ALTPRICEINFO._serialized_start=874
  _ALTPRICEINFO._serialized_end=1184
  _PRICES._serialized_start=1186
  _PRICES._serialized_end=1266
  _PRICE._serialized_start=1269
  _PRICE._serialized_end=1672
# @@protoc_insertion_point(module_scope)
