# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import savings_azure_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2


class SavingsAzureStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create_recommendation = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsAzure/create_recommendation',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.create_inventory = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsAzure/create_inventory',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.create_summary = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsAzure/create_summary',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsSummaryRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get_coverage_ratio = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsAzure/get_coverage_ratio',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.GetCoverageQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class SavingsAzureServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create_recommendation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create_inventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create_summary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_coverage_ratio(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SavingsAzureServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create_recommendation': grpc.unary_unary_rpc_method_handler(
                    servicer.create_recommendation,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'create_inventory': grpc.unary_unary_rpc_method_handler(
                    servicer.create_inventory,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'create_summary': grpc.unary_unary_rpc_method_handler(
                    servicer.create_summary,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsSummaryRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get_coverage_ratio': grpc.unary_unary_rpc_method_handler(
                    servicer.get_coverage_ratio,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.GetCoverageQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.SavingsAzure', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SavingsAzure(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create_recommendation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsAzure/create_recommendation',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def create_inventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsAzure/create_inventory',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def create_summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsAzure/create_summary',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsSummaryRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_coverage_ratio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsAzure/get_coverage_ratio',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.GetCoverageQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
