# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/monthly_exchange_rate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9spaceone/api/cost_analysis/v1/monthly_exchange_rate.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"O\n\x1dSetMonthlyExchangeRateRequest\x12\r\n\x05month\x18\x01 \x01(\t\x12\x0c\n\x04rate\x18\x02 \x01(\x02\x12\x11\n\tdomain_id\x18\x03 \x01(\t\">\n\x1aMonthlyExchangeRateRequest\x12\r\n\x05month\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"Y\n\x18MonthlyExchangeRateQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"J\n\x17MonthlyExchangeRateInfo\x12\r\n\x05month\x18\x01 \x01(\t\x12\x0c\n\x04rate\x18\x02 \x01(\x02\x12\x12\n\ncreated_at\x18\x0b \x01(\t\"x\n\x18MonthlyExchangeRatesInfo\x12G\n\x07results\x18\x01 \x03(\x0b\x32\x36.spaceone.api.cost_analysis.v1.MonthlyExchangeRateInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x93\x04\n\x13MonthlyExchangeRate\x12\x80\x01\n\x06\x63reate\x12<.spaceone.api.cost_analysis.v1.SetMonthlyExchangeRateRequest\x1a\x36.spaceone.api.cost_analysis.v1.MonthlyExchangeRateInfo\"\x00\x12\x80\x01\n\x06update\x12<.spaceone.api.cost_analysis.v1.SetMonthlyExchangeRateRequest\x1a\x36.spaceone.api.cost_analysis.v1.MonthlyExchangeRateInfo\"\x00\x12z\n\x03get\x12\x39.spaceone.api.cost_analysis.v1.MonthlyExchangeRateRequest\x1a\x36.spaceone.api.cost_analysis.v1.MonthlyExchangeRateInfo\"\x00\x12z\n\x04list\x12\x37.spaceone.api.cost_analysis.v1.MonthlyExchangeRateQuery\x1a\x37.spaceone.api.cost_analysis.v1.MonthlyExchangeRatesInfo\"\x00\x62\x06proto3')



_SETMONTHLYEXCHANGERATEREQUEST = DESCRIPTOR.message_types_by_name['SetMonthlyExchangeRateRequest']
_MONTHLYEXCHANGERATEREQUEST = DESCRIPTOR.message_types_by_name['MonthlyExchangeRateRequest']
_MONTHLYEXCHANGERATEQUERY = DESCRIPTOR.message_types_by_name['MonthlyExchangeRateQuery']
_MONTHLYEXCHANGERATEINFO = DESCRIPTOR.message_types_by_name['MonthlyExchangeRateInfo']
_MONTHLYEXCHANGERATESINFO = DESCRIPTOR.message_types_by_name['MonthlyExchangeRatesInfo']
SetMonthlyExchangeRateRequest = _reflection.GeneratedProtocolMessageType('SetMonthlyExchangeRateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMONTHLYEXCHANGERATEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.monthly_exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SetMonthlyExchangeRateRequest)
  })
_sym_db.RegisterMessage(SetMonthlyExchangeRateRequest)

MonthlyExchangeRateRequest = _reflection.GeneratedProtocolMessageType('MonthlyExchangeRateRequest', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYEXCHANGERATEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.monthly_exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.MonthlyExchangeRateRequest)
  })
_sym_db.RegisterMessage(MonthlyExchangeRateRequest)

MonthlyExchangeRateQuery = _reflection.GeneratedProtocolMessageType('MonthlyExchangeRateQuery', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYEXCHANGERATEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.monthly_exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.MonthlyExchangeRateQuery)
  })
_sym_db.RegisterMessage(MonthlyExchangeRateQuery)

MonthlyExchangeRateInfo = _reflection.GeneratedProtocolMessageType('MonthlyExchangeRateInfo', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYEXCHANGERATEINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.monthly_exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.MonthlyExchangeRateInfo)
  })
_sym_db.RegisterMessage(MonthlyExchangeRateInfo)

MonthlyExchangeRatesInfo = _reflection.GeneratedProtocolMessageType('MonthlyExchangeRatesInfo', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYEXCHANGERATESINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.monthly_exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.MonthlyExchangeRatesInfo)
  })
_sym_db.RegisterMessage(MonthlyExchangeRatesInfo)

_MONTHLYEXCHANGERATE = DESCRIPTOR.services_by_name['MonthlyExchangeRate']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SETMONTHLYEXCHANGERATEREQUEST._serialized_start=156
  _SETMONTHLYEXCHANGERATEREQUEST._serialized_end=235
  _MONTHLYEXCHANGERATEREQUEST._serialized_start=237
  _MONTHLYEXCHANGERATEREQUEST._serialized_end=299
  _MONTHLYEXCHANGERATEQUERY._serialized_start=301
  _MONTHLYEXCHANGERATEQUERY._serialized_end=390
  _MONTHLYEXCHANGERATEINFO._serialized_start=392
  _MONTHLYEXCHANGERATEINFO._serialized_end=466
  _MONTHLYEXCHANGERATESINFO._serialized_start=468
  _MONTHLYEXCHANGERATESINFO._serialized_end=588
  _MONTHLYEXCHANGERATE._serialized_start=591
  _MONTHLYEXCHANGERATE._serialized_end=1122
# @@protoc_insertion_point(module_scope)
