# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/collector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)spaceone/api/inventory/v1/collector.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xd7\x02\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x04 \x01(\t\x12\x17\n\x0fsecret_group_id\x18\x05 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12)\n\x08metadata\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12G\n\x0cupgrade_mode\x18\x0b \x01(\x0e\x32\x31.spaceone.api.inventory.v1.PluginInfo.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"\xd5\x01\n\x16\x43reateCollectorRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x0bplugin_info\x18\x02 \x01(\x0b\x32%.spaceone.api.inventory.v1.PluginInfo\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x11\n\tis_public\x18\n \x01(\x08\x12\x12\n\nproject_id\x18\x0b \x01(\t\"\xc4\x01\n\x16UpdateCollectorRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12:\n\x0bplugin_info\x18\x03 \x01(\x0b\x32%.spaceone.api.inventory.v1.PluginInfo\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"\xfa\x01\n\x13UpdatePluginRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12P\n\x0cupgrade_mode\x18\x05 \x01(\x0e\x32:.spaceone.api.inventory.v1.UpdatePluginRequest.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\";\n\x10\x43ollectorRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"L\n\x13GetCollectorRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x86\x02\n\x0e\x43ollectorQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x14\n\x0c\x63ollector_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12>\n\x05state\x18\x04 \x01(\x0e\x32/.spaceone.api.inventory.v1.CollectorQuery.State\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12\x11\n\tplugin_id\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\x9e\x01\n\x0e\x43ollectRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\'\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollect_mode\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x11\n\tuse_cache\x18\x06 \x01(\x08\"Q\n\x13VerifyPluginRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x11\n\tsecret_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"\xbd\x03\n\rCollectorInfo\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12=\n\x05state\x18\x03 \x01(\x0e\x32..spaceone.api.inventory.v1.CollectorInfo.State\x12:\n\x0bplugin_info\x18\x04 \x01(\x0b\x32%.spaceone.api.inventory.v1.PluginInfo\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x19\n\x11last_collected_at\x18\t \x01(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\x12\x10\n\x08provider\x18\x0b \x01(\t\x12+\n\ncapability\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tis_public\x18\x14 \x01(\x08\x12\x12\n\nproject_id\x18\x15 \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"`\n\x0e\x43ollectorsInfo\x12\x39\n\x07results\x18\x01 \x03(\x0b\x32(.spaceone.api.inventory.v1.CollectorInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"]\n\x12\x43ollectorStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x1c\n\nVerifyInfo\x12\x0e\n\x06status\x18\x01 \x01(\x08\"]\n\tErrorInfo\x12\x12\n\nerror_code\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12+\n\nadditional\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xeb\x03\n\x07JobInfo\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x39\n\x06status\x18\x02 \x01(\x0e\x32).spaceone.api.inventory.v1.JobInfo.Status\x12\'\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0btotal_tasks\x18\x04 \x01(\x05\x12\x16\n\x0eremained_tasks\x18\x05 \x01(\x05\x12\x34\n\x06\x65rrors\x18\x06 \x03(\x0b\x32$.spaceone.api.inventory.v1.ErrorInfo\x12@\n\x0e\x63ollector_info\x18\x0b \x01(\x0b\x32(.spaceone.api.inventory.v1.CollectorInfo\x12\x12\n\nproject_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nupdated_at\x18\x16 \x01(\t\x12\x13\n\x0b\x66inished_at\x18\x17 \x01(\t\"c\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0c\n\x08\x43\x41NCELED\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0b\n\x07TIMEOUT\x10\x06\"K\n\tScheduled\x12\x0c\n\x04\x63ron\x18\x01 \x01(\t\x12\x10\n\x08interval\x18\x02 \x01(\x05\x12\x0f\n\x07minutes\x18\x03 \x03(\x05\x12\r\n\x05hours\x18\x04 \x03(\x05\"\xc5\x01\n\x15\x43reateScheduleRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ollector_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollect_mode\x18\x04 \x01(\t\x12\x36\n\x08schedule\x18\x05 \x01(\x0b\x32$.spaceone.api.inventory.v1.Scheduled\x12\'\n\x06\x66ilter\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xda\x01\n\x15UpdateScheduleRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bschedule_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ollector_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0c\x63ollect_mode\x18\x05 \x01(\t\x12\x36\n\x08schedule\x18\x06 \x01(\x0b\x32$.spaceone.api.inventory.v1.Scheduled\x12\'\n\x06\x66ilter\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\"O\n\x0fScheduleRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bschedule_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ollector_id\x18\x03 \x01(\t\"U\n\x15\x44\x65leteScheduleRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bschedule_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ollector_id\x18\x03 \x01(\t\"y\n\rScheduleQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x14\n\x0c\x63ollector_id\x18\x02 \x01(\t\x12\x13\n\x0bschedule_id\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xac\x02\n\x0cScheduleInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bschedule_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollect_mode\x18\x04 \x01(\t\x12\x36\n\x08schedule\x18\x05 \x01(\x0b\x32$.spaceone.api.inventory.v1.Scheduled\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x19\n\x11last_scheduled_at\x18\x0b \x01(\t\x12@\n\x0e\x63ollector_info\x18\x14 \x01(\x0b\x32(.spaceone.api.inventory.v1.CollectorInfo\x12\'\n\x06\x66ilter\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\"^\n\rSchedulesInfo\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\'.spaceone.api.inventory.v1.ScheduleInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xe4\x13\n\tCollector\x12\x87\x01\n\x06\x63reate\x12\x31.spaceone.api.inventory.v1.CreateCollectorRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\" \x82\xd3\xe4\x93\x02\x1a\"\x18/inventory/v1/collectors\x12\x95\x01\n\x06update\x12\x31.spaceone.api.inventory.v1.UpdateCollectorRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\".\x82\xd3\xe4\x93\x02(\x1a&/inventory/v1/collector/{collector_id}\x12\xa0\x01\n\rupdate_plugin\x12..spaceone.api.inventory.v1.UpdatePluginRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\"5\x82\xd3\xe4\x93\x02/\x1a-/inventory/v1/collector/{collector_id}/plugin\x12\x95\x01\n\rverify_plugin\x12..spaceone.api.inventory.v1.VerifyPluginRequest\x1a\x16.google.protobuf.Empty\"<\x82\xd3\xe4\x93\x02\x36\"4/inventory/v1/collector/{collector_id}/plugin/verify\x12}\n\x06\x64\x65lete\x12+.spaceone.api.inventory.v1.CollectorRequest\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(*&/inventory/v1/collector/{collector_id}\x12\x8f\x01\n\x03get\x12..spaceone.api.inventory.v1.GetCollectorRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\".\x82\xd3\xe4\x93\x02(\x12&/inventory/v1/collector/{collector_id}\x12\x96\x01\n\x06\x65nable\x12+.spaceone.api.inventory.v1.CollectorRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\"5\x82\xd3\xe4\x93\x02/\x1a-/inventory/v1/collector/{collector_id}/enable\x12\x98\x01\n\x07\x64isable\x12+.spaceone.api.inventory.v1.CollectorRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./inventory/v1/collector/{collector_id}/disable\x12\xa1\x01\n\x04list\x12).spaceone.api.inventory.v1.CollectorQuery\x1a).spaceone.api.inventory.v1.CollectorsInfo\"C\x82\xd3\xe4\x93\x02=\x12\x18/inventory/v1/collectorsZ!\"\x1f/inventory/v1/collectors/search\x12u\n\x04stat\x12-.spaceone.api.inventory.v1.CollectorStatQuery\x1a\x17.google.protobuf.Struct\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/inventory/v1/collectors/stat\x12\x90\x01\n\x07\x63ollect\x12).spaceone.api.inventory.v1.CollectRequest\x1a\".spaceone.api.inventory.v1.JobInfo\"6\x82\xd3\xe4\x93\x02\x30\"./inventory/v1/collector/{collector_id}/collect\x12\xa2\x01\n\x0c\x61\x64\x64_schedule\x12\x30.spaceone.api.inventory.v1.CreateScheduleRequest\x1a\'.spaceone.api.inventory.v1.ScheduleInfo\"7\x82\xd3\xe4\x93\x02\x31\"//inventory/v1/collector/{collector_id}/schedule\x12\xaa\x01\n\x0cget_schedule\x12*.spaceone.api.inventory.v1.ScheduleRequest\x1a\'.spaceone.api.inventory.v1.ScheduleInfo\"E\x82\xd3\xe4\x93\x02?\x12=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}\x12\xb3\x01\n\x0fupdate_schedule\x12\x30.spaceone.api.inventory.v1.UpdateScheduleRequest\x1a\'.spaceone.api.inventory.v1.ScheduleInfo\"E\x82\xd3\xe4\x93\x02?\"=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}\x12\xa2\x01\n\x0f\x64\x65lete_schedule\x12\x30.spaceone.api.inventory.v1.DeleteScheduleRequest\x1a\x16.google.protobuf.Empty\"E\x82\xd3\xe4\x93\x02?*=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}\x12\xd9\x01\n\x0elist_schedules\x12(.spaceone.api.inventory.v1.ScheduleQuery\x1a(.spaceone.api.inventory.v1.SchedulesInfo\"s\x82\xd3\xe4\x93\x02m\x12\x30/inventory/v1/collector/{collector_id}/schedulesZ9\"7/inventory/v1/collector/{collector_id}/schedules/searchb\x06proto3')



_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_CREATECOLLECTORREQUEST = DESCRIPTOR.message_types_by_name['CreateCollectorRequest']
_UPDATECOLLECTORREQUEST = DESCRIPTOR.message_types_by_name['UpdateCollectorRequest']
_UPDATEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdatePluginRequest']
_COLLECTORREQUEST = DESCRIPTOR.message_types_by_name['CollectorRequest']
_GETCOLLECTORREQUEST = DESCRIPTOR.message_types_by_name['GetCollectorRequest']
_COLLECTORQUERY = DESCRIPTOR.message_types_by_name['CollectorQuery']
_COLLECTREQUEST = DESCRIPTOR.message_types_by_name['CollectRequest']
_VERIFYPLUGINREQUEST = DESCRIPTOR.message_types_by_name['VerifyPluginRequest']
_COLLECTORINFO = DESCRIPTOR.message_types_by_name['CollectorInfo']
_COLLECTORSINFO = DESCRIPTOR.message_types_by_name['CollectorsInfo']
_COLLECTORSTATQUERY = DESCRIPTOR.message_types_by_name['CollectorStatQuery']
_VERIFYINFO = DESCRIPTOR.message_types_by_name['VerifyInfo']
_ERRORINFO = DESCRIPTOR.message_types_by_name['ErrorInfo']
_JOBINFO = DESCRIPTOR.message_types_by_name['JobInfo']
_SCHEDULED = DESCRIPTOR.message_types_by_name['Scheduled']
_CREATESCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['CreateScheduleRequest']
_UPDATESCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['UpdateScheduleRequest']
_SCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['ScheduleRequest']
_DELETESCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['DeleteScheduleRequest']
_SCHEDULEQUERY = DESCRIPTOR.message_types_by_name['ScheduleQuery']
_SCHEDULEINFO = DESCRIPTOR.message_types_by_name['ScheduleInfo']
_SCHEDULESINFO = DESCRIPTOR.message_types_by_name['SchedulesInfo']
_PLUGININFO_UPGRADEMODE = _PLUGININFO.enum_types_by_name['UpgradeMode']
_UPDATEPLUGINREQUEST_UPGRADEMODE = _UPDATEPLUGINREQUEST.enum_types_by_name['UpgradeMode']
_COLLECTORQUERY_STATE = _COLLECTORQUERY.enum_types_by_name['State']
_COLLECTORINFO_STATE = _COLLECTORINFO.enum_types_by_name['State']
_JOBINFO_STATUS = _JOBINFO.enum_types_by_name['Status']
PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

CreateCollectorRequest = _reflection.GeneratedProtocolMessageType('CreateCollectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOLLECTORREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateCollectorRequest)
  })
_sym_db.RegisterMessage(CreateCollectorRequest)

UpdateCollectorRequest = _reflection.GeneratedProtocolMessageType('UpdateCollectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOLLECTORREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateCollectorRequest)
  })
_sym_db.RegisterMessage(UpdateCollectorRequest)

UpdatePluginRequest = _reflection.GeneratedProtocolMessageType('UpdatePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPLUGINREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdatePluginRequest)
  })
_sym_db.RegisterMessage(UpdatePluginRequest)

CollectorRequest = _reflection.GeneratedProtocolMessageType('CollectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectorRequest)
  })
_sym_db.RegisterMessage(CollectorRequest)

GetCollectorRequest = _reflection.GeneratedProtocolMessageType('GetCollectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOLLECTORREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetCollectorRequest)
  })
_sym_db.RegisterMessage(GetCollectorRequest)

CollectorQuery = _reflection.GeneratedProtocolMessageType('CollectorQuery', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORQUERY,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectorQuery)
  })
_sym_db.RegisterMessage(CollectorQuery)

CollectRequest = _reflection.GeneratedProtocolMessageType('CollectRequest', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectRequest)
  })
_sym_db.RegisterMessage(CollectRequest)

VerifyPluginRequest = _reflection.GeneratedProtocolMessageType('VerifyPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYPLUGINREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.VerifyPluginRequest)
  })
_sym_db.RegisterMessage(VerifyPluginRequest)

CollectorInfo = _reflection.GeneratedProtocolMessageType('CollectorInfo', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectorInfo)
  })
_sym_db.RegisterMessage(CollectorInfo)

CollectorsInfo = _reflection.GeneratedProtocolMessageType('CollectorsInfo', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORSINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectorsInfo)
  })
_sym_db.RegisterMessage(CollectorsInfo)

CollectorStatQuery = _reflection.GeneratedProtocolMessageType('CollectorStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectorStatQuery)
  })
_sym_db.RegisterMessage(CollectorStatQuery)

VerifyInfo = _reflection.GeneratedProtocolMessageType('VerifyInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.VerifyInfo)
  })
_sym_db.RegisterMessage(VerifyInfo)

ErrorInfo = _reflection.GeneratedProtocolMessageType('ErrorInfo', (_message.Message,), {
  'DESCRIPTOR' : _ERRORINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ErrorInfo)
  })
_sym_db.RegisterMessage(ErrorInfo)

JobInfo = _reflection.GeneratedProtocolMessageType('JobInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobInfo)
  })
_sym_db.RegisterMessage(JobInfo)

Scheduled = _reflection.GeneratedProtocolMessageType('Scheduled', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULED,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Scheduled)
  })
_sym_db.RegisterMessage(Scheduled)

CreateScheduleRequest = _reflection.GeneratedProtocolMessageType('CreateScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCHEDULEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateScheduleRequest)
  })
_sym_db.RegisterMessage(CreateScheduleRequest)

UpdateScheduleRequest = _reflection.GeneratedProtocolMessageType('UpdateScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCHEDULEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateScheduleRequest)
  })
_sym_db.RegisterMessage(UpdateScheduleRequest)

ScheduleRequest = _reflection.GeneratedProtocolMessageType('ScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ScheduleRequest)
  })
_sym_db.RegisterMessage(ScheduleRequest)

DeleteScheduleRequest = _reflection.GeneratedProtocolMessageType('DeleteScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCHEDULEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.DeleteScheduleRequest)
  })
_sym_db.RegisterMessage(DeleteScheduleRequest)

ScheduleQuery = _reflection.GeneratedProtocolMessageType('ScheduleQuery', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ScheduleQuery)
  })
_sym_db.RegisterMessage(ScheduleQuery)

ScheduleInfo = _reflection.GeneratedProtocolMessageType('ScheduleInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ScheduleInfo)
  })
_sym_db.RegisterMessage(ScheduleInfo)

SchedulesInfo = _reflection.GeneratedProtocolMessageType('SchedulesInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULESINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SchedulesInfo)
  })
_sym_db.RegisterMessage(SchedulesInfo)

_COLLECTOR = DESCRIPTOR.services_by_name['Collector']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COLLECTOR.methods_by_name['create']._options = None
  _COLLECTOR.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\032\"\030/inventory/v1/collectors'
  _COLLECTOR.methods_by_name['update']._options = None
  _COLLECTOR.methods_by_name['update']._serialized_options = b'\202\323\344\223\002(\032&/inventory/v1/collector/{collector_id}'
  _COLLECTOR.methods_by_name['update_plugin']._options = None
  _COLLECTOR.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\002/\032-/inventory/v1/collector/{collector_id}/plugin'
  _COLLECTOR.methods_by_name['verify_plugin']._options = None
  _COLLECTOR.methods_by_name['verify_plugin']._serialized_options = b'\202\323\344\223\0026\"4/inventory/v1/collector/{collector_id}/plugin/verify'
  _COLLECTOR.methods_by_name['delete']._options = None
  _COLLECTOR.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002(*&/inventory/v1/collector/{collector_id}'
  _COLLECTOR.methods_by_name['get']._options = None
  _COLLECTOR.methods_by_name['get']._serialized_options = b'\202\323\344\223\002(\022&/inventory/v1/collector/{collector_id}'
  _COLLECTOR.methods_by_name['enable']._options = None
  _COLLECTOR.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002/\032-/inventory/v1/collector/{collector_id}/enable'
  _COLLECTOR.methods_by_name['disable']._options = None
  _COLLECTOR.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0020\032./inventory/v1/collector/{collector_id}/disable'
  _COLLECTOR.methods_by_name['list']._options = None
  _COLLECTOR.methods_by_name['list']._serialized_options = b'\202\323\344\223\002=\022\030/inventory/v1/collectorsZ!\"\037/inventory/v1/collectors/search'
  _COLLECTOR.methods_by_name['stat']._options = None
  _COLLECTOR.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\037\"\035/inventory/v1/collectors/stat'
  _COLLECTOR.methods_by_name['collect']._options = None
  _COLLECTOR.methods_by_name['collect']._serialized_options = b'\202\323\344\223\0020\"./inventory/v1/collector/{collector_id}/collect'
  _COLLECTOR.methods_by_name['add_schedule']._options = None
  _COLLECTOR.methods_by_name['add_schedule']._serialized_options = b'\202\323\344\223\0021\"//inventory/v1/collector/{collector_id}/schedule'
  _COLLECTOR.methods_by_name['get_schedule']._options = None
  _COLLECTOR.methods_by_name['get_schedule']._serialized_options = b'\202\323\344\223\002?\022=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}'
  _COLLECTOR.methods_by_name['update_schedule']._options = None
  _COLLECTOR.methods_by_name['update_schedule']._serialized_options = b'\202\323\344\223\002?\"=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}'
  _COLLECTOR.methods_by_name['delete_schedule']._options = None
  _COLLECTOR.methods_by_name['delete_schedule']._serialized_options = b'\202\323\344\223\002?*=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}'
  _COLLECTOR.methods_by_name['list_schedules']._options = None
  _COLLECTOR.methods_by_name['list_schedules']._serialized_options = b'\202\323\344\223\002m\0220/inventory/v1/collector/{collector_id}/schedulesZ9\"7/inventory/v1/collector/{collector_id}/schedules/search'
  _PLUGININFO._serialized_start=196
  _PLUGININFO._serialized_end=539
  _PLUGININFO_UPGRADEMODE._serialized_start=494
  _PLUGININFO_UPGRADEMODE._serialized_end=539
  _CREATECOLLECTORREQUEST._serialized_start=542
  _CREATECOLLECTORREQUEST._serialized_end=755
  _UPDATECOLLECTORREQUEST._serialized_start=758
  _UPDATECOLLECTORREQUEST._serialized_end=954
  _UPDATEPLUGINREQUEST._serialized_start=957
  _UPDATEPLUGINREQUEST._serialized_end=1207
  _UPDATEPLUGINREQUEST_UPGRADEMODE._serialized_start=494
  _UPDATEPLUGINREQUEST_UPGRADEMODE._serialized_end=539
  _COLLECTORREQUEST._serialized_start=1209
  _COLLECTORREQUEST._serialized_end=1268
  _GETCOLLECTORREQUEST._serialized_start=1270
  _GETCOLLECTORREQUEST._serialized_end=1346
  _COLLECTORQUERY._serialized_start=1349
  _COLLECTORQUERY._serialized_end=1611
  _COLLECTORQUERY_STATE._serialized_start=1567
  _COLLECTORQUERY_STATE._serialized_end=1611
  _COLLECTREQUEST._serialized_start=1614
  _COLLECTREQUEST._serialized_end=1772
  _VERIFYPLUGINREQUEST._serialized_start=1774
  _VERIFYPLUGINREQUEST._serialized_end=1855
  _COLLECTORINFO._serialized_start=1858
  _COLLECTORINFO._serialized_end=2303
  _COLLECTORINFO_STATE._serialized_start=1567
  _COLLECTORINFO_STATE._serialized_end=1611
  _COLLECTORSINFO._serialized_start=2305
  _COLLECTORSINFO._serialized_end=2401
  _COLLECTORSTATQUERY._serialized_start=2403
  _COLLECTORSTATQUERY._serialized_end=2496
  _VERIFYINFO._serialized_start=2498
  _VERIFYINFO._serialized_end=2526
  _ERRORINFO._serialized_start=2528
  _ERRORINFO._serialized_end=2621
  _JOBINFO._serialized_start=2624
  _JOBINFO._serialized_end=3115
  _JOBINFO_STATUS._serialized_start=3016
  _JOBINFO_STATUS._serialized_end=3115
  _SCHEDULED._serialized_start=3117
  _SCHEDULED._serialized_end=3192
  _CREATESCHEDULEREQUEST._serialized_start=3195
  _CREATESCHEDULEREQUEST._serialized_end=3392
  _UPDATESCHEDULEREQUEST._serialized_start=3395
  _UPDATESCHEDULEREQUEST._serialized_end=3613
  _SCHEDULEREQUEST._serialized_start=3615
  _SCHEDULEREQUEST._serialized_end=3694
  _DELETESCHEDULEREQUEST._serialized_start=3696
  _DELETESCHEDULEREQUEST._serialized_end=3781
  _SCHEDULEQUERY._serialized_start=3783
  _SCHEDULEQUERY._serialized_end=3904
  _SCHEDULEINFO._serialized_start=3907
  _SCHEDULEINFO._serialized_end=4207
  _SCHEDULESINFO._serialized_start=4209
  _SCHEDULESINFO._serialized_end=4303
  _COLLECTOR._serialized_start=4306
  _COLLECTOR._serialized_end=6838
# @@protoc_insertion_point(module_scope)
