# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/stack_resource_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9spaceone/api/provisioning/v1/stack_resource_history.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x99\x03\n\x19StackResourceHistoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12!\n\x19stack_resource_history_id\x18\x03 \x01(\t\x12\x18\n\x10stack_history_id\x18\x04 \x01(\t\x12\x19\n\x11stack_resource_id\x18\x05 \x01(\t\x12\x15\n\rresource_name\x18\x06 \x01(\t\x12N\n\x06\x61\x63tion\x18\x07 \x01(\x0e\x32>.spaceone.api.provisioning.v1.StackResourceHistoryQuery.Action\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x12\x10\n\x08stack_id\x18\n \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\"6\n\x06\x41\x63tion\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"\xa9\x03\n\x18StackResourceHistoryInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12!\n\x19stack_resource_history_id\x18\x02 \x01(\t\x12\x18\n\x10stack_history_id\x18\x03 \x01(\t\x12\x19\n\x11stack_resource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12M\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32=.spaceone.api.provisioning.v1.StackResourceHistoryInfo.Action\x12(\n\x04\x64iff\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x12\n\ndiff_count\x18\x08 \x01(\x05\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12\x10\n\x08stack_id\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x0c \x01(\t\"6\n\x06\x41\x63tion\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"z\n\x1aStackResourceHistoriesInfo\x12G\n\x07results\x18\x01 \x03(\x0b\x32\x36.spaceone.api.provisioning.v1.StackResourceHistoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x95\x01\n\x1dStackResourceHistoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x19\n\x11stack_resource_id\x18\x03 \x01(\t\x12\x10\n\x08stack_id\x18\x04 \x01(\t2\x8d\x05\n\x14StackResourceHistory\x12\x8a\x02\n\x1cget_stack_resource_histories\x12\x37.spaceone.api.provisioning.v1.StackResourceHistoryQuery\x1a\x38.spaceone.api.provisioning.v1.StackResourceHistoriesInfo\"w\x82\xd3\xe4\x93\x02q\x12=/provisioning/v1/stack-resource/{stack_resource_id}/historiesZ0\"./provisioning/v1/stack-resource-history/search\x12\xd2\x01\n\x1aget_stack_resource_history\x12\x37.spaceone.api.provisioning.v1.StackResourceHistoryQuery\x1a\x36.spaceone.api.provisioning.v1.StackResourceHistoryInfo\"C\x82\xd3\xe4\x93\x02=\";/provisioning/v1/stack-resource/{stack_resource_id}/history\x12\x92\x01\n\x04stat\x12;.spaceone.api.provisioning.v1.StackResourceHistoryStatQuery\x1a\x17.google.protobuf.Struct\"4\x82\xd3\xe4\x93\x02.\",/provisioning/v1/stack-resource-history/statb\x06proto3')



_STACKRESOURCEHISTORYQUERY = DESCRIPTOR.message_types_by_name['StackResourceHistoryQuery']
_STACKRESOURCEHISTORYINFO = DESCRIPTOR.message_types_by_name['StackResourceHistoryInfo']
_STACKRESOURCEHISTORIESINFO = DESCRIPTOR.message_types_by_name['StackResourceHistoriesInfo']
_STACKRESOURCEHISTORYSTATQUERY = DESCRIPTOR.message_types_by_name['StackResourceHistoryStatQuery']
_STACKRESOURCEHISTORYQUERY_ACTION = _STACKRESOURCEHISTORYQUERY.enum_types_by_name['Action']
_STACKRESOURCEHISTORYINFO_ACTION = _STACKRESOURCEHISTORYINFO.enum_types_by_name['Action']
StackResourceHistoryQuery = _reflection.GeneratedProtocolMessageType('StackResourceHistoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEHISTORYQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceHistoryQuery)
  })
_sym_db.RegisterMessage(StackResourceHistoryQuery)

StackResourceHistoryInfo = _reflection.GeneratedProtocolMessageType('StackResourceHistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEHISTORYINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceHistoryInfo)
  })
_sym_db.RegisterMessage(StackResourceHistoryInfo)

StackResourceHistoriesInfo = _reflection.GeneratedProtocolMessageType('StackResourceHistoriesInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEHISTORIESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceHistoriesInfo)
  })
_sym_db.RegisterMessage(StackResourceHistoriesInfo)

StackResourceHistoryStatQuery = _reflection.GeneratedProtocolMessageType('StackResourceHistoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEHISTORYSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceHistoryStatQuery)
  })
_sym_db.RegisterMessage(StackResourceHistoryStatQuery)

_STACKRESOURCEHISTORY = DESCRIPTOR.services_by_name['StackResourceHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STACKRESOURCEHISTORY.methods_by_name['get_stack_resource_histories']._options = None
  _STACKRESOURCEHISTORY.methods_by_name['get_stack_resource_histories']._serialized_options = b'\202\323\344\223\002q\022=/provisioning/v1/stack-resource/{stack_resource_id}/historiesZ0\"./provisioning/v1/stack-resource-history/search'
  _STACKRESOURCEHISTORY.methods_by_name['get_stack_resource_history']._options = None
  _STACKRESOURCEHISTORY.methods_by_name['get_stack_resource_history']._serialized_options = b'\202\323\344\223\002=\";/provisioning/v1/stack-resource/{stack_resource_id}/history'
  _STACKRESOURCEHISTORY.methods_by_name['stat']._options = None
  _STACKRESOURCEHISTORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002.\",/provisioning/v1/stack-resource-history/stat'
  _STACKRESOURCEHISTORYQUERY._serialized_start=186
  _STACKRESOURCEHISTORYQUERY._serialized_end=595
  _STACKRESOURCEHISTORYQUERY_ACTION._serialized_start=541
  _STACKRESOURCEHISTORYQUERY_ACTION._serialized_end=595
  _STACKRESOURCEHISTORYINFO._serialized_start=598
  _STACKRESOURCEHISTORYINFO._serialized_end=1023
  _STACKRESOURCEHISTORYINFO_ACTION._serialized_start=541
  _STACKRESOURCEHISTORYINFO_ACTION._serialized_end=595
  _STACKRESOURCEHISTORIESINFO._serialized_start=1025
  _STACKRESOURCEHISTORIESINFO._serialized_end=1147
  _STACKRESOURCEHISTORYSTATQUERY._serialized_start=1150
  _STACKRESOURCEHISTORYSTATQUERY._serialized_end=1299
  _STACKRESOURCEHISTORY._serialized_start=1302
  _STACKRESOURCEHISTORY._serialized_end=1955
# @@protoc_insertion_point(module_scope)
