# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/stack.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.provisioning.v1 import stack_resource_pb2 as spaceone_dot_api_dot_provisioning_dot_v1_dot_stack__resource__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.identity.v1 import project_group_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/provisioning/v1/stack.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x31spaceone/api/provisioning/v1/stack_resource.proto\x1a spaceone/api/core/v1/query.proto\x1a,spaceone/api/identity/v1/project_group.proto\"\xb5\x01\n\x13PublishStackRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\x12\x13\n\x0bplan_status\x18\x07 \x01(\t\x12\x14\n\x0cpublish_type\x18\x08 \x01(\t\"\x8a\x02\n\x12\x43reateStackRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nstack_name\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x42\n\tresources\x18\x08 \x03(\x0b\x32/.spaceone.api.provisioning.v1.StackResourceInfo\"3\n\x0cStackRequest\x12\x10\n\x08stack_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"X\n\x0fGetStackRequest\x12\x10\n\x08stack_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\x12\x12\n\nstack_type\x18\x04 \x01(\t\"\xbc\x03\n\x12UpdateStackRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x12\n\ncatalog_id\x18\x04 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\x08 \x01(\t\x12\x12\n\nupdated_by\x18\t \x01(\t\x12\x0e\n\x06status\x18\n \x01(\t\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x1a\n\x12service_account_id\x18\x0c \x01(\t\x12\x10\n\x08provider\x18\r \x01(\t\x12\x13\n\x0bplan_status\x18\x0e \x01(\t\x12\x15\n\rstack_summary\x18\x0f \x01(\t\x12\x12\n\nstack_desc\x18\x10 \x01(\t\x12\x42\n\tresources\x18\x11 \x03(\x0b\x32/.spaceone.api.provisioning.v1.StackResourceInfo\"\x8b\x05\n\tStackInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x12\n\ncatalog_id\x18\x04 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\t \x01(\t\x12\x12\n\nupdated_by\x18\n \x01(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\t\x12\x12\n\nupdated_at\x18\x0c \x01(\t\x12\x0e\n\x06status\x18\r \x01(\t\x12\x12\n\nproject_id\x18\x0e \x01(\t\x12\x1a\n\x12service_account_id\x18\x0f \x01(\t\x12\x10\n\x08provider\x18\x10 \x01(\t\x12\x13\n\x0bplan_status\x18\x11 \x01(\t\x12\x15\n\rstack_summary\x18\x12 \x01(\t\x12\x12\n\nstack_desc\x18\x13 \x01(\t\x12\x42\n\tresources\x18\x14 \x03(\x0b\x32/.spaceone.api.provisioning.v1.StackResourceInfo\x12\x13\n\x0b\x61pproved_at\x18\x15 \x01(\t\x12\x13\n\x0b\x61pproved_by\x18\x16 \x01(\t\x12\x18\n\x10project_group_id\x18\x17 \x01(\t\x12\x1a\n\x12project_group_name\x18\x18 \x01(\t\x12\x14\n\x0cproject_name\x18\x19 \x01(\t\x12\r\n\x05graph\x18\x1a \x01(\t\x12\x12\n\nstack_type\x18\x1b \x01(\t\x12\x15\n\rstack_temp_id\x18\x1c \x01(\t\"[\n\nStacksInfo\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\'.spaceone.api.provisioning.v1.StackInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xa9\x01\n\nStackQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x12\n\nupdated_by\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\t\"Y\n\x0eStackStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xcc\x08\n\x05Stack\x12\x89\x01\n\x0c\x63reate_stack\x12\x30.spaceone.api.provisioning.v1.CreateStackRequest\x1a\'.spaceone.api.provisioning.v1.StackInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/provisioning/v1/stack\x12\xa3\x01\n\nget_stacks\x12(.spaceone.api.provisioning.v1.StackQuery\x1a(.spaceone.api.provisioning.v1.StacksInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/provisioning/v1/stacksZ \"\x1e/provisioning/v1/stacks/search\x12\x8e\x01\n\tget_stack\x12-.spaceone.api.provisioning.v1.GetStackRequest\x1a\'.spaceone.api.provisioning.v1.StackInfo\")\x82\xd3\xe4\x93\x02#\x12!/provisioning/v1/stack/{stack_id}\x12\x89\x01\n\x0cupdate_stack\x12\x30.spaceone.api.provisioning.v1.UpdateStackRequest\x1a\'.spaceone.api.provisioning.v1.StackInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\x1a\x16/provisioning/v1/stack\x12}\n\x0c\x64\x65lete_stack\x12*.spaceone.api.provisioning.v1.StackRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/provisioning/v1/stack/{stack_id}\x12\x82\x01\n\rpublish_stack\x12\x31.spaceone.api.provisioning.v1.PublishStackRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1e/provisioning/v1/stack/publish\x12r\n\x04stat\x12,.spaceone.api.provisioning.v1.StackStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/provisioning/v1/stack/stat\x12|\n\nplan_stack\x12\x31.spaceone.api.provisioning.v1.PublishStackRequest\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/provisioning/v1/stack/planb\x06proto3')



_PUBLISHSTACKREQUEST = DESCRIPTOR.message_types_by_name['PublishStackRequest']
_CREATESTACKREQUEST = DESCRIPTOR.message_types_by_name['CreateStackRequest']
_STACKREQUEST = DESCRIPTOR.message_types_by_name['StackRequest']
_GETSTACKREQUEST = DESCRIPTOR.message_types_by_name['GetStackRequest']
_UPDATESTACKREQUEST = DESCRIPTOR.message_types_by_name['UpdateStackRequest']
_STACKINFO = DESCRIPTOR.message_types_by_name['StackInfo']
_STACKSINFO = DESCRIPTOR.message_types_by_name['StacksInfo']
_STACKQUERY = DESCRIPTOR.message_types_by_name['StackQuery']
_STACKSTATQUERY = DESCRIPTOR.message_types_by_name['StackStatQuery']
PublishStackRequest = _reflection.GeneratedProtocolMessageType('PublishStackRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHSTACKREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.PublishStackRequest)
  })
_sym_db.RegisterMessage(PublishStackRequest)

CreateStackRequest = _reflection.GeneratedProtocolMessageType('CreateStackRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTACKREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateStackRequest)
  })
_sym_db.RegisterMessage(CreateStackRequest)

StackRequest = _reflection.GeneratedProtocolMessageType('StackRequest', (_message.Message,), {
  'DESCRIPTOR' : _STACKREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackRequest)
  })
_sym_db.RegisterMessage(StackRequest)

GetStackRequest = _reflection.GeneratedProtocolMessageType('GetStackRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTACKREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetStackRequest)
  })
_sym_db.RegisterMessage(GetStackRequest)

UpdateStackRequest = _reflection.GeneratedProtocolMessageType('UpdateStackRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTACKREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateStackRequest)
  })
_sym_db.RegisterMessage(UpdateStackRequest)

StackInfo = _reflection.GeneratedProtocolMessageType('StackInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackInfo)
  })
_sym_db.RegisterMessage(StackInfo)

StacksInfo = _reflection.GeneratedProtocolMessageType('StacksInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StacksInfo)
  })
_sym_db.RegisterMessage(StacksInfo)

StackQuery = _reflection.GeneratedProtocolMessageType('StackQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackQuery)
  })
_sym_db.RegisterMessage(StackQuery)

StackStatQuery = _reflection.GeneratedProtocolMessageType('StackStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackStatQuery)
  })
_sym_db.RegisterMessage(StackStatQuery)

_STACK = DESCRIPTOR.services_by_name['Stack']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STACK.methods_by_name['create_stack']._options = None
  _STACK.methods_by_name['create_stack']._serialized_options = b'\202\323\344\223\002\030\"\026/provisioning/v1/stack'
  _STACK.methods_by_name['get_stacks']._options = None
  _STACK.methods_by_name['get_stacks']._serialized_options = b'\202\323\344\223\002;\022\027/provisioning/v1/stacksZ \"\036/provisioning/v1/stacks/search'
  _STACK.methods_by_name['get_stack']._options = None
  _STACK.methods_by_name['get_stack']._serialized_options = b'\202\323\344\223\002#\022!/provisioning/v1/stack/{stack_id}'
  _STACK.methods_by_name['update_stack']._options = None
  _STACK.methods_by_name['update_stack']._serialized_options = b'\202\323\344\223\002\030\032\026/provisioning/v1/stack'
  _STACK.methods_by_name['delete_stack']._options = None
  _STACK.methods_by_name['delete_stack']._serialized_options = b'\202\323\344\223\002#*!/provisioning/v1/stack/{stack_id}'
  _STACK.methods_by_name['publish_stack']._options = None
  _STACK.methods_by_name['publish_stack']._serialized_options = b'\202\323\344\223\002 \"\036/provisioning/v1/stack/publish'
  _STACK.methods_by_name['stat']._options = None
  _STACK.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/provisioning/v1/stack/stat'
  _STACK.methods_by_name['plan_stack']._options = None
  _STACK.methods_by_name['plan_stack']._serialized_options = b'\202\323\344\223\002\035\"\033/provisioning/v1/stack/plan'
  _PUBLISHSTACKREQUEST._serialized_start=295
  _PUBLISHSTACKREQUEST._serialized_end=476
  _CREATESTACKREQUEST._serialized_start=479
  _CREATESTACKREQUEST._serialized_end=745
  _STACKREQUEST._serialized_start=747
  _STACKREQUEST._serialized_end=798
  _GETSTACKREQUEST._serialized_start=800
  _GETSTACKREQUEST._serialized_end=888
  _UPDATESTACKREQUEST._serialized_start=891
  _UPDATESTACKREQUEST._serialized_end=1335
  _STACKINFO._serialized_start=1338
  _STACKINFO._serialized_end=1989
  _STACKSINFO._serialized_start=1991
  _STACKSINFO._serialized_end=2082
  _STACKQUERY._serialized_start=2085
  _STACKQUERY._serialized_end=2254
  _STACKSTATQUERY._serialized_start=2256
  _STACKSTATQUERY._serialized_end=2345
  _STACK._serialized_start=2348
  _STACK._serialized_end=3448
# @@protoc_insertion_point(module_scope)
