# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/repository/v1/policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.repository.v1 import repository_pb2 as spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/repository/v1/policy.proto\x12\x1aspaceone.api.repository.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a+spaceone/api/repository/v1/repository.proto\"\xc5\x01\n\x13\x43reatePolicyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bpermissions\x18\x02 \x03(\t\x12\x11\n\tpolicy_id\x18\x03 \x01(\t\x12*\n\x06labels\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\"\xb1\x01\n\x13UpdatePolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x03(\t\x12*\n\x06labels\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"5\n\rPolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"g\n\x1aGetRepositoryPolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x15\n\rrepository_id\x18\x03 \x01(\t\x12\x0c\n\x04only\x18\x04 \x03(\t\"\x84\x02\n\x0bPolicyQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tpolicy_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x15\n\rrepository_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12<\n\x05state\x18\x07 \x01(\x0e\x32-.spaceone.api.repository.v1.PolicyQuery.State\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\x94\x03\n\nPolicyInfo\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12;\n\x05state\x18\x03 \x01(\x0e\x32,.spaceone.api.repository.v1.PolicyInfo.State\x12\x13\n\x0bpermissions\x18\x0b \x03(\t\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\x0frepository_info\x18\x15 \x01(\x0b\x32*.spaceone.api.repository.v1.RepositoryInfo\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\\\n\x0cPoliciesInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.repository.v1.PolicyInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"q\n\x0fPolicyStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x15\n\rrepository_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t2\xb3\x06\n\x06Policy\x12\x82\x01\n\x06\x63reate\x12/.spaceone.api.repository.v1.CreatePolicyRequest\x1a&.spaceone.api.repository.v1.PolicyInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/repository/v1/policies\x12\x89\x01\n\x06update\x12/.spaceone.api.repository.v1.UpdatePolicyRequest\x1a&.spaceone.api.repository.v1.PolicyInfo\"&\x82\xd3\xe4\x93\x02 \x1a\x1e/repository/v1/policy/{policy}\x12s\n\x06\x64\x65lete\x12).spaceone.api.repository.v1.PolicyRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 *\x1e/repository/v1/policy/{policy}\x12\x8f\x01\n\x03get\x12\x36.spaceone.api.repository.v1.GetRepositoryPolicyRequest\x1a&.spaceone.api.repository.v1.PolicyInfo\"(\x82\xd3\xe4\x93\x02\"\x12 /repository/v1/policies/{policy}\x12\x9c\x01\n\x04list\x12\'.spaceone.api.repository.v1.PolicyQuery\x1a(.spaceone.api.repository.v1.PoliciesInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/repository/v1/policiesZ \"\x1e/repository/v1/policies/search\x12r\n\x04stat\x12+.spaceone.api.repository.v1.PolicyStatQuery\x1a\x17.google.protobuf.Struct\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/repository/v1/policies/statb\x06proto3')



_CREATEPOLICYREQUEST = DESCRIPTOR.message_types_by_name['CreatePolicyRequest']
_UPDATEPOLICYREQUEST = DESCRIPTOR.message_types_by_name['UpdatePolicyRequest']
_POLICYREQUEST = DESCRIPTOR.message_types_by_name['PolicyRequest']
_GETREPOSITORYPOLICYREQUEST = DESCRIPTOR.message_types_by_name['GetRepositoryPolicyRequest']
_POLICYQUERY = DESCRIPTOR.message_types_by_name['PolicyQuery']
_POLICYINFO = DESCRIPTOR.message_types_by_name['PolicyInfo']
_POLICIESINFO = DESCRIPTOR.message_types_by_name['PoliciesInfo']
_POLICYSTATQUERY = DESCRIPTOR.message_types_by_name['PolicyStatQuery']
_POLICYQUERY_STATE = _POLICYQUERY.enum_types_by_name['State']
_POLICYINFO_STATE = _POLICYINFO.enum_types_by_name['State']
CreatePolicyRequest = _reflection.GeneratedProtocolMessageType('CreatePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOLICYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.CreatePolicyRequest)
  })
_sym_db.RegisterMessage(CreatePolicyRequest)

UpdatePolicyRequest = _reflection.GeneratedProtocolMessageType('UpdatePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOLICYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.UpdatePolicyRequest)
  })
_sym_db.RegisterMessage(UpdatePolicyRequest)

PolicyRequest = _reflection.GeneratedProtocolMessageType('PolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _POLICYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PolicyRequest)
  })
_sym_db.RegisterMessage(PolicyRequest)

GetRepositoryPolicyRequest = _reflection.GeneratedProtocolMessageType('GetRepositoryPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPOSITORYPOLICYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.GetRepositoryPolicyRequest)
  })
_sym_db.RegisterMessage(GetRepositoryPolicyRequest)

PolicyQuery = _reflection.GeneratedProtocolMessageType('PolicyQuery', (_message.Message,), {
  'DESCRIPTOR' : _POLICYQUERY,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PolicyQuery)
  })
_sym_db.RegisterMessage(PolicyQuery)

PolicyInfo = _reflection.GeneratedProtocolMessageType('PolicyInfo', (_message.Message,), {
  'DESCRIPTOR' : _POLICYINFO,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PolicyInfo)
  })
_sym_db.RegisterMessage(PolicyInfo)

PoliciesInfo = _reflection.GeneratedProtocolMessageType('PoliciesInfo', (_message.Message,), {
  'DESCRIPTOR' : _POLICIESINFO,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PoliciesInfo)
  })
_sym_db.RegisterMessage(PoliciesInfo)

PolicyStatQuery = _reflection.GeneratedProtocolMessageType('PolicyStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _POLICYSTATQUERY,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PolicyStatQuery)
  })
_sym_db.RegisterMessage(PolicyStatQuery)

_POLICY = DESCRIPTOR.services_by_name['Policy']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _POLICY.methods_by_name['create']._options = None
  _POLICY.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\031\"\027/repository/v1/policies'
  _POLICY.methods_by_name['update']._options = None
  _POLICY.methods_by_name['update']._serialized_options = b'\202\323\344\223\002 \032\036/repository/v1/policy/{policy}'
  _POLICY.methods_by_name['delete']._options = None
  _POLICY.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002 *\036/repository/v1/policy/{policy}'
  _POLICY.methods_by_name['get']._options = None
  _POLICY.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\"\022 /repository/v1/policies/{policy}'
  _POLICY.methods_by_name['list']._options = None
  _POLICY.methods_by_name['list']._serialized_options = b'\202\323\344\223\002;\022\027/repository/v1/policiesZ \"\036/repository/v1/policies/search'
  _POLICY.methods_by_name['stat']._options = None
  _POLICY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\036\"\034/repository/v1/policies/stat'
  _CREATEPOLICYREQUEST._serialized_start=240
  _CREATEPOLICYREQUEST._serialized_end=437
  _UPDATEPOLICYREQUEST._serialized_start=440
  _UPDATEPOLICYREQUEST._serialized_end=617
  _POLICYREQUEST._serialized_start=619
  _POLICYREQUEST._serialized_end=672
  _GETREPOSITORYPOLICYREQUEST._serialized_start=674
  _GETREPOSITORYPOLICYREQUEST._serialized_end=777
  _POLICYQUERY._serialized_start=780
  _POLICYQUERY._serialized_end=1040
  _POLICYQUERY_STATE._serialized_start=996
  _POLICYQUERY_STATE._serialized_end=1040
  _POLICYINFO._serialized_start=1043
  _POLICYINFO._serialized_end=1447
  _POLICYINFO_STATE._serialized_start=996
  _POLICYINFO_STATE._serialized_end=1040
  _POLICIESINFO._serialized_start=1449
  _POLICIESINFO._serialized_end=1541
  _POLICYSTATQUERY._serialized_start=1543
  _POLICYSTATQUERY._serialized_end=1656
  _POLICY._serialized_start=1659
  _POLICY._serialized_end=2478
# @@protoc_insertion_point(module_scope)
