# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/cloud_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-spaceone/api/inventory/v1/cloud_service.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"C\n\x15\x43loudServiceReference\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x15\n\rexternal_link\x18\x02 \x01(\t\"\xbe\x03\n\x14\x43reateServiceRequest\x12\x1a\n\x12\x63loud_service_type\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x15\n\rinstance_size\x18\x07 \x01(\x02\x12\x14\n\x0cip_addresses\x18\n \x03(\t\x12%\n\x04\x64\x61ta\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\treference\x18\r \x01(\x0b\x32\x30.spaceone.api.inventory.v1.CloudServiceReference\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0bregion_code\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\"\xc3\x03\n\x19UpdateCloudServiceRequest\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x03 \x01(\t\x12\x15\n\rinstance_type\x18\x04 \x01(\t\x12\x15\n\rinstance_size\x18\x05 \x01(\x02\x12\x14\n\x0cip_addresses\x18\x06 \x03(\t\x12%\n\x04\x64\x61ta\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\treference\x18\r \x01(\x0b\x32\x30.spaceone.api.inventory.v1.CloudServiceReference\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0bregion_code\x18\x14 \x01(\t\x12\x12\n\nproject_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\x12\x17\n\x0frelease_project\x18\x1e \x01(\x08\x12\x16\n\x0erelease_region\x18\x1f \x01(\x08\"W\n\x1aPinCloudServiceDataRequest\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"B\n\x13\x43loudServiceRequest\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"S\n\x16GetCloudServiceRequest\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xee\x02\n\x11\x43loudServiceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x18\n\x10\x63loud_service_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x13\n\x0bregion_code\x18\n \x01(\t\x12\x12\n\nip_address\x18\x0b \x01(\t\x12\x19\n\x11resource_group_id\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x18\n\x10project_group_id\x18\x17 \x01(\t\x12\x11\n\tdomain_id\x18\x18 \x01(\t\"\xd1\x04\n\x10\x43loudServiceInfo\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x15\n\rinstance_type\x18\x05 \x01(\t\x12\x15\n\rinstance_size\x18\x06 \x01(\x02\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12%\n\x04\x64\x61ta\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\treference\x18\r \x01(\x0b\x32\x30.spaceone.api.inventory.v1.CloudServiceReference\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0f\x63ollection_info\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cip_addresses\x18\x11 \x03(\t\x12\x13\n\x0bregion_code\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\x12\x12\n\ndeleted_at\x18! \x01(\t\"f\n\x11\x43loudServicesInfo\x12<\n\x07results\x18\x01 \x03(\x0b\x32+.spaceone.api.inventory.v1.CloudServiceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x97\x01\n\x15\x43loudServiceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\x12\x1a\n\x12\x61llow_delete_state\x18\x04 \x01(\x08\x32\xb7\x08\n\x0c\x43loudService\x12\x8c\x01\n\x06\x63reate\x12/.spaceone.api.inventory.v1.CreateServiceRequest\x1a+.spaceone.api.inventory.v1.CloudServiceInfo\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/inventory/v1/cloud-services\x12\xa3\x01\n\x06update\x12\x34.spaceone.api.inventory.v1.UpdateCloudServiceRequest\x1a+.spaceone.api.inventory.v1.CloudServiceInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./inventory/v1/cloud-service/{cloud_service_id}\x12\x88\x01\n\x06\x64\x65lete\x12..spaceone.api.inventory.v1.CloudServiceRequest\x1a\x16.google.protobuf.Empty\"6\x82\xd3\xe4\x93\x02\x30*./inventory/v1/cloud-service/{cloud_service_id}\x12\x9d\x01\n\x03get\x12\x31.spaceone.api.inventory.v1.GetCloudServiceRequest\x1a+.spaceone.api.inventory.v1.CloudServiceInfo\"6\x82\xd3\xe4\x93\x02\x30\x12./inventory/v1/cloud-service/{cloud_service_id}\x12\xaf\x01\n\x04list\x12,.spaceone.api.inventory.v1.CloudServiceQuery\x1a,.spaceone.api.inventory.v1.CloudServicesInfo\"K\x82\xd3\xe4\x93\x02\x45\x12\x1c/inventory/v1/cloud-servicesZ%\"#/inventory/v1/cloud-services/search\x12|\n\x04stat\x12\x30.spaceone.api.inventory.v1.CloudServiceStatQuery\x1a\x17.google.protobuf.Struct\")\x82\xd3\xe4\x93\x02#\"!/inventory/v1/cloud-services/stat\x12\x96\x01\n\x11\x61llow_delete_stat\x12\x30.spaceone.api.inventory.v1.CloudServiceStatQuery\x1a\x17.google.protobuf.Struct\"6\x82\xd3\xe4\x93\x02\x30\"./inventory/v1/cloud-services/allow_delete_statb\x06proto3')



_CLOUDSERVICEREFERENCE = DESCRIPTOR.message_types_by_name['CloudServiceReference']
_CREATESERVICEREQUEST = DESCRIPTOR.message_types_by_name['CreateServiceRequest']
_UPDATECLOUDSERVICEREQUEST = DESCRIPTOR.message_types_by_name['UpdateCloudServiceRequest']
_PINCLOUDSERVICEDATAREQUEST = DESCRIPTOR.message_types_by_name['PinCloudServiceDataRequest']
_CLOUDSERVICEREQUEST = DESCRIPTOR.message_types_by_name['CloudServiceRequest']
_GETCLOUDSERVICEREQUEST = DESCRIPTOR.message_types_by_name['GetCloudServiceRequest']
_CLOUDSERVICEQUERY = DESCRIPTOR.message_types_by_name['CloudServiceQuery']
_CLOUDSERVICEINFO = DESCRIPTOR.message_types_by_name['CloudServiceInfo']
_CLOUDSERVICESINFO = DESCRIPTOR.message_types_by_name['CloudServicesInfo']
_CLOUDSERVICESTATQUERY = DESCRIPTOR.message_types_by_name['CloudServiceStatQuery']
CloudServiceReference = _reflection.GeneratedProtocolMessageType('CloudServiceReference', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICEREFERENCE,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceReference)
  })
_sym_db.RegisterMessage(CloudServiceReference)

CreateServiceRequest = _reflection.GeneratedProtocolMessageType('CreateServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateServiceRequest)
  })
_sym_db.RegisterMessage(CreateServiceRequest)

UpdateCloudServiceRequest = _reflection.GeneratedProtocolMessageType('UpdateCloudServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLOUDSERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateCloudServiceRequest)
  })
_sym_db.RegisterMessage(UpdateCloudServiceRequest)

PinCloudServiceDataRequest = _reflection.GeneratedProtocolMessageType('PinCloudServiceDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINCLOUDSERVICEDATAREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PinCloudServiceDataRequest)
  })
_sym_db.RegisterMessage(PinCloudServiceDataRequest)

CloudServiceRequest = _reflection.GeneratedProtocolMessageType('CloudServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceRequest)
  })
_sym_db.RegisterMessage(CloudServiceRequest)

GetCloudServiceRequest = _reflection.GeneratedProtocolMessageType('GetCloudServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDSERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetCloudServiceRequest)
  })
_sym_db.RegisterMessage(GetCloudServiceRequest)

CloudServiceQuery = _reflection.GeneratedProtocolMessageType('CloudServiceQuery', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceQuery)
  })
_sym_db.RegisterMessage(CloudServiceQuery)

CloudServiceInfo = _reflection.GeneratedProtocolMessageType('CloudServiceInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICEINFO,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceInfo)
  })
_sym_db.RegisterMessage(CloudServiceInfo)

CloudServicesInfo = _reflection.GeneratedProtocolMessageType('CloudServicesInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICESINFO,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServicesInfo)
  })
_sym_db.RegisterMessage(CloudServicesInfo)

CloudServiceStatQuery = _reflection.GeneratedProtocolMessageType('CloudServiceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICESTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceStatQuery)
  })
_sym_db.RegisterMessage(CloudServiceStatQuery)

_CLOUDSERVICE = DESCRIPTOR.services_by_name['CloudService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDSERVICE.methods_by_name['create']._options = None
  _CLOUDSERVICE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\036\"\034/inventory/v1/cloud-services'
  _CLOUDSERVICE.methods_by_name['update']._options = None
  _CLOUDSERVICE.methods_by_name['update']._serialized_options = b'\202\323\344\223\0020\032./inventory/v1/cloud-service/{cloud_service_id}'
  _CLOUDSERVICE.methods_by_name['delete']._options = None
  _CLOUDSERVICE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0020*./inventory/v1/cloud-service/{cloud_service_id}'
  _CLOUDSERVICE.methods_by_name['get']._options = None
  _CLOUDSERVICE.methods_by_name['get']._serialized_options = b'\202\323\344\223\0020\022./inventory/v1/cloud-service/{cloud_service_id}'
  _CLOUDSERVICE.methods_by_name['list']._options = None
  _CLOUDSERVICE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002E\022\034/inventory/v1/cloud-servicesZ%\"#/inventory/v1/cloud-services/search'
  _CLOUDSERVICE.methods_by_name['stat']._options = None
  _CLOUDSERVICE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002#\"!/inventory/v1/cloud-services/stat'
  _CLOUDSERVICE.methods_by_name['allow_delete_stat']._options = None
  _CLOUDSERVICE.methods_by_name['allow_delete_stat']._serialized_options = b'\202\323\344\223\0020\"./inventory/v1/cloud-services/allow_delete_stat'
  _CLOUDSERVICEREFERENCE._serialized_start=199
  _CLOUDSERVICEREFERENCE._serialized_end=266
  _CREATESERVICEREQUEST._serialized_start=269
  _CREATESERVICEREQUEST._serialized_end=715
  _UPDATECLOUDSERVICEREQUEST._serialized_start=718
  _UPDATECLOUDSERVICEREQUEST._serialized_end=1169
  _PINCLOUDSERVICEDATAREQUEST._serialized_start=1171
  _PINCLOUDSERVICEDATAREQUEST._serialized_end=1258
  _CLOUDSERVICEREQUEST._serialized_start=1260
  _CLOUDSERVICEREQUEST._serialized_end=1326
  _GETCLOUDSERVICEREQUEST._serialized_start=1328
  _GETCLOUDSERVICEREQUEST._serialized_end=1411
  _CLOUDSERVICEQUERY._serialized_start=1414
  _CLOUDSERVICEQUERY._serialized_end=1780
  _CLOUDSERVICEINFO._serialized_start=1783
  _CLOUDSERVICEINFO._serialized_end=2376
  _CLOUDSERVICESINFO._serialized_start=2378
  _CLOUDSERVICESINFO._serialized_end=2480
  _CLOUDSERVICESTATQUERY._serialized_start=2483
  _CLOUDSERVICESTATQUERY._serialized_end=2634
  _CLOUDSERVICE._serialized_start=2637
  _CLOUDSERVICE._serialized_end=3716
# @@protoc_insertion_point(module_scope)
