# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/alert.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/monitoring/v1/alert.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"I\n\rAlertResource\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"<\n\x0e\x41lertResponder\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\"8\n\x0c\x41lertAccount\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\"\xac\x01\n\x12\x43reateAlertRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x61ssignee\x18\x03 \x01(\t\x12\x39\n\x07urgency\x18\x04 \x01(\x0e\x32(.spaceone.api.monitoring.v1.AlertUrgency\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xb6\x02\n\x12UpdateAlertRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x16\n\x0estatus_message\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x10\n\x08\x61ssignee\x18\x06 \x01(\t\x12\x39\n\x07urgency\x18\x07 \x01(\x0e\x32(.spaceone.api.monitoring.v1.AlertUrgency\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12\x1c\n\x14reset_status_message\x18\x0b \x01(\x08\x12\x19\n\x11reset_description\x18\x0c \x01(\x08\x12\x16\n\x0ereset_assignee\x18\r \x01(\x08\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"N\n\x17UpdateAlertStateRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x12\n\naccess_key\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\"H\n\x11MergeAlertRequest\x12\x0e\n\x06\x61lerts\x18\x01 \x03(\t\x12\x10\n\x08merge_to\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"K\n\x12SnoozeAlertRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"h\n\x15\x41lertResponderRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"X\n\x1d\x41lertProjectDependencyRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"3\n\x0c\x41lertRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"D\n\x0fGetAlertRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xc0\x03\n\nAlertQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x14\n\x0c\x61lert_number\x18\x02 \x01(\x05\x12\x10\n\x08\x61lert_id\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x35\n\x05state\x18\x05 \x01(\x0e\x32&.spaceone.api.monitoring.v1.AlertState\x12\x10\n\x08\x61ssignee\x18\x06 \x01(\t\x12\x39\n\x07urgency\x18\x07 \x01(\x0e\x32(.spaceone.api.monitoring.v1.AlertUrgency\x12\x10\n\x08severity\x18\x08 \x01(\t\x12\x12\n\nis_snoozed\x18\t \x01(\t\x12\x13\n\x0bresource_id\x18\n \x01(\t\x12\x10\n\x08provider\x18\x0b \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x0c \x01(\t\x12\x14\n\x0ctriggered_by\x18\r \x01(\t\x12\x12\n\nwebhook_id\x18\x15 \x01(\t\x12\x1c\n\x14\x65scalation_policy_id\x18\x16 \x01(\t\x12\x12\n\nproject_id\x18\x17 \x01(\t\x12\x11\n\tdomain_id\x18\x18 \x01(\t\"\xa2\x08\n\tAlertInfo\x12\x14\n\x0c\x61lert_number\x18\x01 \x01(\x05\x12\x10\n\x08\x61lert_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x35\n\x05state\x18\x04 \x01(\x0e\x32&.spaceone.api.monitoring.v1.AlertState\x12\x16\n\x0estatus_message\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x10\n\x08\x61ssignee\x18\x07 \x01(\t\x12\x39\n\x07urgency\x18\x08 \x01(\x0e\x32(.spaceone.api.monitoring.v1.AlertUrgency\x12\x10\n\x08severity\x18\t \x01(\t\x12\x0c\n\x04rule\x18\n \x01(\t\x12;\n\x08resource\x18\x0b \x01(\x0b\x32).spaceone.api.monitoring.v1.AlertResource\x12\x10\n\x08provider\x18\x0c \x01(\t\x12\x39\n\x07\x61\x63\x63ount\x18\r \x01(\x0b\x32(.spaceone.api.monitoring.v1.AlertAccount\x12\x12\n\nis_snoozed\x18\x0e \x01(\x08\x12\x18\n\x10snoozed_end_time\x18\x0f \x01(\t\x12\x17\n\x0f\x65scalation_step\x18\x10 \x01(\x05\x12\x16\n\x0e\x65scalation_ttl\x18\x11 \x01(\x05\x12>\n\nresponders\x18\x12 \x03(\x0b\x32*.spaceone.api.monitoring.v1.AlertResponder\x12\x1c\n\x14project_dependencies\x18\x13 \x03(\t\x12\x11\n\timage_url\x18\x14 \x01(\t\x12\x30\n\x0f\x61\x64\x64itional_info\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0ctriggered_by\x18\x1f \x01(\t\x12\x12\n\nwebhook_id\x18  \x01(\t\x12\x1c\n\x14\x65scalation_policy_id\x18! \x01(\t\x12\x12\n\nproject_id\x18\" \x01(\t\x12\x11\n\tdomain_id\x18# \x01(\t\x12\x12\n\ncreated_at\x18) \x01(\t\x12\x12\n\nupdated_at\x18* \x01(\t\x12\x17\n\x0f\x61\x63knowledged_at\x18+ \x01(\t\x12\x13\n\x0bresolved_at\x18, \x01(\t\x12\x14\n\x0c\x65scalated_at\x18- \x01(\t\x12\x14\n\x0cservice_name\x18. \x01(\t\x12\x11\n\thost_name\x18/ \x01(\t\x12\n\n\x02ip\x18\x30 \x01(\t\x12\x15\n\rreal_time_log\x18\x31 \x01(\t\x12\x15\n\rlast_error_at\x18\x32 \x01(\t\x12\x18\n\x10\x61lert_number_str\x18\x33 \x01(\t\x12)\n\x08raw_data\x18\x34 \x01(\x0b\x32\x17.google.protobuf.Struct\"Y\n\nAlertsInfo\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.spaceone.api.monitoring.v1.AlertInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Y\n\x0e\x41lertStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*9\n\x0c\x41lertUrgency\x12\x16\n\x12\x41LERT_URGENCY_NONE\x10\x00\x12\x08\n\x04HIGH\x10\x01\x12\x07\n\x03LOW\x10\x02*h\n\nAlertState\x12\x14\n\x10\x41LERT_STATE_NONE\x10\x00\x12\r\n\tTRIGGERED\x10\x01\x12\x10\n\x0c\x41\x43KNOWLEDGED\x10\x02\x12\x0c\n\x08RESOLVED\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\n\n\x06PUSHED\x10\x05\x32\x9e\x0f\n\x05\x41lert\x12~\n\x06\x63reate\x12..spaceone.api.monitoring.v1.CreateAlertRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/monitoring/v1/alerts\x12\x88\x01\n\x06update\x12..spaceone.api.monitoring.v1.UpdateAlertRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/monitoring/v1/alert/{alert_id}\x12\xa8\x01\n\x0cupdate_state\x12\x33.spaceone.api.monitoring.v1.UpdateAlertStateRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"<\x82\xd3\xe4\x93\x02\x36\"4/monitoring/v1/alert/{alert_id}/{access_key}/{state}\x12\x82\x01\n\x05merge\x12-.spaceone.api.monitoring.v1.MergeAlertRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/monitoring/v1/alerts/merge\x12\x8f\x01\n\x06snooze\x12..spaceone.api.monitoring.v1.SnoozeAlertRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\".\x82\xd3\xe4\x93\x02(\"&/monitoring/v1/alert/{alert_id}/snooze\x12\x9d\x01\n\radd_responder\x12\x31.spaceone.api.monitoring.v1.AlertResponderRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"2\x82\xd3\xe4\x93\x02,\"*/monitoring/v1/alert/{alert_id}/responders\x12\xa0\x01\n\x10remove_responder\x12\x31.spaceone.api.monitoring.v1.AlertResponderRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"2\x82\xd3\xe4\x93\x02,**/monitoring/v1/alert/{alert_id}/responders\x12\xb8\x01\n\x16\x61\x64\x64_project_dependency\x12\x39.spaceone.api.monitoring.v1.AlertProjectDependencyRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"<\x82\xd3\xe4\x93\x02\x36\"4/monitoring/v1/alert/{alert_id}/project-dependencies\x12\xc6\x01\n\x19remove_project_dependency\x12\x39.spaceone.api.monitoring.v1.AlertProjectDependencyRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"G\x82\xd3\xe4\x93\x02\x41*?/monitoring/v1/alert/{alert_id}/project-dependency/{project_id}\x12s\n\x06\x64\x65lete\x12(.spaceone.api.monitoring.v1.AlertRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!*\x1f/monitoring/v1/alert/{alert_id}\x12\x82\x01\n\x03get\x12+.spaceone.api.monitoring.v1.GetAlertRequest\x1a%.spaceone.api.monitoring.v1.AlertInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/monitoring/v1/alert/{alert_id}\x12\x95\x01\n\x04list\x12&.spaceone.api.monitoring.v1.AlertQuery\x1a&.spaceone.api.monitoring.v1.AlertsInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x15/monitoring/v1/alertsZ\x1e\"\x1c/monitoring/v1/alerts/search\x12o\n\x04stat\x12*.spaceone.api.monitoring.v1.AlertStatQuery\x1a\x17.google.protobuf.Struct\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/monitoring/v1/alerts/statb\x06proto3')

_ALERTURGENCY = DESCRIPTOR.enum_types_by_name['AlertUrgency']
AlertUrgency = enum_type_wrapper.EnumTypeWrapper(_ALERTURGENCY)
_ALERTSTATE = DESCRIPTOR.enum_types_by_name['AlertState']
AlertState = enum_type_wrapper.EnumTypeWrapper(_ALERTSTATE)
ALERT_URGENCY_NONE = 0
HIGH = 1
LOW = 2
ALERT_STATE_NONE = 0
TRIGGERED = 1
ACKNOWLEDGED = 2
RESOLVED = 3
ERROR = 4
PUSHED = 5


_ALERTRESOURCE = DESCRIPTOR.message_types_by_name['AlertResource']
_ALERTRESPONDER = DESCRIPTOR.message_types_by_name['AlertResponder']
_ALERTACCOUNT = DESCRIPTOR.message_types_by_name['AlertAccount']
_CREATEALERTREQUEST = DESCRIPTOR.message_types_by_name['CreateAlertRequest']
_UPDATEALERTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAlertRequest']
_UPDATEALERTSTATEREQUEST = DESCRIPTOR.message_types_by_name['UpdateAlertStateRequest']
_MERGEALERTREQUEST = DESCRIPTOR.message_types_by_name['MergeAlertRequest']
_SNOOZEALERTREQUEST = DESCRIPTOR.message_types_by_name['SnoozeAlertRequest']
_ALERTRESPONDERREQUEST = DESCRIPTOR.message_types_by_name['AlertResponderRequest']
_ALERTPROJECTDEPENDENCYREQUEST = DESCRIPTOR.message_types_by_name['AlertProjectDependencyRequest']
_ALERTREQUEST = DESCRIPTOR.message_types_by_name['AlertRequest']
_GETALERTREQUEST = DESCRIPTOR.message_types_by_name['GetAlertRequest']
_ALERTQUERY = DESCRIPTOR.message_types_by_name['AlertQuery']
_ALERTINFO = DESCRIPTOR.message_types_by_name['AlertInfo']
_ALERTSINFO = DESCRIPTOR.message_types_by_name['AlertsInfo']
_ALERTSTATQUERY = DESCRIPTOR.message_types_by_name['AlertStatQuery']
AlertResource = _reflection.GeneratedProtocolMessageType('AlertResource', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRESOURCE,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertResource)
  })
_sym_db.RegisterMessage(AlertResource)

AlertResponder = _reflection.GeneratedProtocolMessageType('AlertResponder', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRESPONDER,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertResponder)
  })
_sym_db.RegisterMessage(AlertResponder)

AlertAccount = _reflection.GeneratedProtocolMessageType('AlertAccount', (_message.Message,), {
  'DESCRIPTOR' : _ALERTACCOUNT,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertAccount)
  })
_sym_db.RegisterMessage(AlertAccount)

CreateAlertRequest = _reflection.GeneratedProtocolMessageType('CreateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateAlertRequest)
  })
_sym_db.RegisterMessage(CreateAlertRequest)

UpdateAlertRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateAlertRequest)
  })
_sym_db.RegisterMessage(UpdateAlertRequest)

UpdateAlertStateRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTSTATEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateAlertStateRequest)
  })
_sym_db.RegisterMessage(UpdateAlertStateRequest)

MergeAlertRequest = _reflection.GeneratedProtocolMessageType('MergeAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _MERGEALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MergeAlertRequest)
  })
_sym_db.RegisterMessage(MergeAlertRequest)

SnoozeAlertRequest = _reflection.GeneratedProtocolMessageType('SnoozeAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _SNOOZEALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.SnoozeAlertRequest)
  })
_sym_db.RegisterMessage(SnoozeAlertRequest)

AlertResponderRequest = _reflection.GeneratedProtocolMessageType('AlertResponderRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRESPONDERREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertResponderRequest)
  })
_sym_db.RegisterMessage(AlertResponderRequest)

AlertProjectDependencyRequest = _reflection.GeneratedProtocolMessageType('AlertProjectDependencyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALERTPROJECTDEPENDENCYREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertProjectDependencyRequest)
  })
_sym_db.RegisterMessage(AlertProjectDependencyRequest)

AlertRequest = _reflection.GeneratedProtocolMessageType('AlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertRequest)
  })
_sym_db.RegisterMessage(AlertRequest)

GetAlertRequest = _reflection.GeneratedProtocolMessageType('GetAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetAlertRequest)
  })
_sym_db.RegisterMessage(GetAlertRequest)

AlertQuery = _reflection.GeneratedProtocolMessageType('AlertQuery', (_message.Message,), {
  'DESCRIPTOR' : _ALERTQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertQuery)
  })
_sym_db.RegisterMessage(AlertQuery)

AlertInfo = _reflection.GeneratedProtocolMessageType('AlertInfo', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINFO,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertInfo)
  })
_sym_db.RegisterMessage(AlertInfo)

AlertsInfo = _reflection.GeneratedProtocolMessageType('AlertsInfo', (_message.Message,), {
  'DESCRIPTOR' : _ALERTSINFO,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertsInfo)
  })
_sym_db.RegisterMessage(AlertsInfo)

AlertStatQuery = _reflection.GeneratedProtocolMessageType('AlertStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _ALERTSTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertStatQuery)
  })
_sym_db.RegisterMessage(AlertStatQuery)

_ALERT = DESCRIPTOR.services_by_name['Alert']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ALERT.methods_by_name['create']._options = None
  _ALERT.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\027\"\025/monitoring/v1/alerts'
  _ALERT.methods_by_name['update']._options = None
  _ALERT.methods_by_name['update']._serialized_options = b'\202\323\344\223\002!\032\037/monitoring/v1/alert/{alert_id}'
  _ALERT.methods_by_name['update_state']._options = None
  _ALERT.methods_by_name['update_state']._serialized_options = b'\202\323\344\223\0026\"4/monitoring/v1/alert/{alert_id}/{access_key}/{state}'
  _ALERT.methods_by_name['merge']._options = None
  _ALERT.methods_by_name['merge']._serialized_options = b'\202\323\344\223\002\035\"\033/monitoring/v1/alerts/merge'
  _ALERT.methods_by_name['snooze']._options = None
  _ALERT.methods_by_name['snooze']._serialized_options = b'\202\323\344\223\002(\"&/monitoring/v1/alert/{alert_id}/snooze'
  _ALERT.methods_by_name['add_responder']._options = None
  _ALERT.methods_by_name['add_responder']._serialized_options = b'\202\323\344\223\002,\"*/monitoring/v1/alert/{alert_id}/responders'
  _ALERT.methods_by_name['remove_responder']._options = None
  _ALERT.methods_by_name['remove_responder']._serialized_options = b'\202\323\344\223\002,**/monitoring/v1/alert/{alert_id}/responders'
  _ALERT.methods_by_name['add_project_dependency']._options = None
  _ALERT.methods_by_name['add_project_dependency']._serialized_options = b'\202\323\344\223\0026\"4/monitoring/v1/alert/{alert_id}/project-dependencies'
  _ALERT.methods_by_name['remove_project_dependency']._options = None
  _ALERT.methods_by_name['remove_project_dependency']._serialized_options = b'\202\323\344\223\002A*?/monitoring/v1/alert/{alert_id}/project-dependency/{project_id}'
  _ALERT.methods_by_name['delete']._options = None
  _ALERT.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002!*\037/monitoring/v1/alert/{alert_id}'
  _ALERT.methods_by_name['get']._options = None
  _ALERT.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/monitoring/v1/alert/{alert_id}'
  _ALERT.methods_by_name['list']._options = None
  _ALERT.methods_by_name['list']._serialized_options = b'\202\323\344\223\0027\022\025/monitoring/v1/alertsZ\036\"\034/monitoring/v1/alerts/search'
  _ALERT.methods_by_name['stat']._options = None
  _ALERT.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\034\"\032/monitoring/v1/alerts/stat'
  _ALERTURGENCY._serialized_start=3120
  _ALERTURGENCY._serialized_end=3177
  _ALERTSTATE._serialized_start=3179
  _ALERTSTATE._serialized_end=3283
  _ALERTRESOURCE._serialized_start=193
  _ALERTRESOURCE._serialized_end=266
  _ALERTRESPONDER._serialized_start=268
  _ALERTRESPONDER._serialized_end=328
  _ALERTACCOUNT._serialized_start=330
  _ALERTACCOUNT._serialized_end=386
  _CREATEALERTREQUEST._serialized_start=389
  _CREATEALERTREQUEST._serialized_end=561
  _UPDATEALERTREQUEST._serialized_start=564
  _UPDATEALERTREQUEST._serialized_end=874
  _UPDATEALERTSTATEREQUEST._serialized_start=876
  _UPDATEALERTSTATEREQUEST._serialized_end=954
  _MERGEALERTREQUEST._serialized_start=956
  _MERGEALERTREQUEST._serialized_end=1028
  _SNOOZEALERTREQUEST._serialized_start=1030
  _SNOOZEALERTREQUEST._serialized_end=1105
  _ALERTRESPONDERREQUEST._serialized_start=1107
  _ALERTRESPONDERREQUEST._serialized_end=1211
  _ALERTPROJECTDEPENDENCYREQUEST._serialized_start=1213
  _ALERTPROJECTDEPENDENCYREQUEST._serialized_end=1301
  _ALERTREQUEST._serialized_start=1303
  _ALERTREQUEST._serialized_end=1354
  _GETALERTREQUEST._serialized_start=1356
  _GETALERTREQUEST._serialized_end=1424
  _ALERTQUERY._serialized_start=1427
  _ALERTQUERY._serialized_end=1875
  _ALERTINFO._serialized_start=1878
  _ALERTINFO._serialized_end=2936
  _ALERTSINFO._serialized_start=2938
  _ALERTSINFO._serialized_end=3027
  _ALERTSTATQUERY._serialized_start=3029
  _ALERTSTATQUERY._serialized_end=3118
  _ALERT._serialized_start=3286
  _ALERT._serialized_end=5236
# @@protoc_insertion_point(module_scope)
