# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/role_binding.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.identity.v1 import project_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2
from spaceone.api.identity.v1 import project_group_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__group__pb2
from spaceone.api.identity.v1 import role_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/identity/v1/role_binding.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a&spaceone/api/identity/v1/project.proto\x1a,spaceone/api/identity/v1/project_group.proto\x1a#spaceone/api/identity/v1/role.proto\"\xeb\x01\n\x18\x43reateRoleBindingRequest\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x0f\n\x07role_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x18\n\x10project_group_id\x18\x05 \x01(\t\x12*\n\x06labels\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x08 \x01(\t\"\x99\x01\n\x18UpdateRoleBindingRequest\x12\x17\n\x0frole_binding_id\x18\x01 \x01(\t\x12*\n\x06labels\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"@\n\x12RoleBindingRequest\x12\x17\n\x0frole_binding_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"Q\n\x15GetRoleBindingRequest\x12\x17\n\x0frole_binding_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x8c\x03\n\x0fRoleBindingInfo\x12\x17\n\x0frole_binding_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x35\n\trole_info\x18\x04 \x01(\x0b\x32\".spaceone.api.identity.v1.RoleInfo\x12;\n\x0cproject_info\x18\x05 \x01(\x0b\x32%.spaceone.api.identity.v1.ProjectInfo\x12\x46\n\x12project_group_info\x18\x06 \x01(\x0b\x32*.spaceone.api.identity.v1.ProjectGroupInfo\x12*\n\x06labels\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"\xe8\x01\n\x10RoleBindingQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x17\n\x0frole_binding_id\x18\x02 \x01(\t\x12\x15\n\rresource_type\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x0f\n\x07role_id\x18\x05 \x01(\t\x12\x11\n\trole_type\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\x18\n\x10project_group_id\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\t \x01(\t\"c\n\x10RoleBindingsInfo\x12:\n\x07results\x18\x01 \x03(\x0b\x32).spaceone.api.identity.v1.RoleBindingInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"_\n\x14RoleBindingStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xf8\x06\n\x0bRoleBinding\x12\x8b\x01\n\x06\x63reate\x12\x32.spaceone.api.identity.v1.CreateRoleBindingRequest\x1a).spaceone.api.identity.v1.RoleBindingInfo\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/identity/v1/role-bindings\x12\x9d\x01\n\x06update\x12\x32.spaceone.api.identity.v1.UpdateRoleBindingRequest\x1a).spaceone.api.identity.v1.RoleBindingInfo\"4\x82\xd3\xe4\x93\x02.\x1a,/identity/v1/role-bindings/{role_binding_id}\x12\x84\x01\n\x06\x64\x65lete\x12,.spaceone.api.identity.v1.RoleBindingRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.*,/identity/v1/role-bindings/{role_binding_id}\x12\x97\x01\n\x03get\x12/.spaceone.api.identity.v1.GetRoleBindingRequest\x1a).spaceone.api.identity.v1.RoleBindingInfo\"4\x82\xd3\xe4\x93\x02.\x12,/identity/v1/role-bindings/{role_binding_id}\x12\xa7\x01\n\x04list\x12*.spaceone.api.identity.v1.RoleBindingQuery\x1a*.spaceone.api.identity.v1.RoleBindingsInfo\"G\x82\xd3\xe4\x93\x02\x41\x12\x1a/identity/v1/role-bindingsZ#\"!/identity/v1/role-bindings/search\x12p\n\x04stat\x12..spaceone.api.identity.v1.RoleBindingStatQuery\x1a\x17.google.protobuf.Struct\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/identity/v1/roles/statb\x06proto3')



_CREATEROLEBINDINGREQUEST = DESCRIPTOR.message_types_by_name['CreateRoleBindingRequest']
_UPDATEROLEBINDINGREQUEST = DESCRIPTOR.message_types_by_name['UpdateRoleBindingRequest']
_ROLEBINDINGREQUEST = DESCRIPTOR.message_types_by_name['RoleBindingRequest']
_GETROLEBINDINGREQUEST = DESCRIPTOR.message_types_by_name['GetRoleBindingRequest']
_ROLEBINDINGINFO = DESCRIPTOR.message_types_by_name['RoleBindingInfo']
_ROLEBINDINGQUERY = DESCRIPTOR.message_types_by_name['RoleBindingQuery']
_ROLEBINDINGSINFO = DESCRIPTOR.message_types_by_name['RoleBindingsInfo']
_ROLEBINDINGSTATQUERY = DESCRIPTOR.message_types_by_name['RoleBindingStatQuery']
CreateRoleBindingRequest = _reflection.GeneratedProtocolMessageType('CreateRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEROLEBINDINGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateRoleBindingRequest)
  })
_sym_db.RegisterMessage(CreateRoleBindingRequest)

UpdateRoleBindingRequest = _reflection.GeneratedProtocolMessageType('UpdateRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROLEBINDINGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateRoleBindingRequest)
  })
_sym_db.RegisterMessage(UpdateRoleBindingRequest)

RoleBindingRequest = _reflection.GeneratedProtocolMessageType('RoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleBindingRequest)
  })
_sym_db.RegisterMessage(RoleBindingRequest)

GetRoleBindingRequest = _reflection.GeneratedProtocolMessageType('GetRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETROLEBINDINGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetRoleBindingRequest)
  })
_sym_db.RegisterMessage(GetRoleBindingRequest)

RoleBindingInfo = _reflection.GeneratedProtocolMessageType('RoleBindingInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGINFO,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleBindingInfo)
  })
_sym_db.RegisterMessage(RoleBindingInfo)

RoleBindingQuery = _reflection.GeneratedProtocolMessageType('RoleBindingQuery', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGQUERY,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleBindingQuery)
  })
_sym_db.RegisterMessage(RoleBindingQuery)

RoleBindingsInfo = _reflection.GeneratedProtocolMessageType('RoleBindingsInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGSINFO,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleBindingsInfo)
  })
_sym_db.RegisterMessage(RoleBindingsInfo)

RoleBindingStatQuery = _reflection.GeneratedProtocolMessageType('RoleBindingStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.role_binding_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleBindingStatQuery)
  })
_sym_db.RegisterMessage(RoleBindingStatQuery)

_ROLEBINDING = DESCRIPTOR.services_by_name['RoleBinding']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROLEBINDING.methods_by_name['create']._options = None
  _ROLEBINDING.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\034\"\032/identity/v1/role-bindings'
  _ROLEBINDING.methods_by_name['update']._options = None
  _ROLEBINDING.methods_by_name['update']._serialized_options = b'\202\323\344\223\002.\032,/identity/v1/role-bindings/{role_binding_id}'
  _ROLEBINDING.methods_by_name['delete']._options = None
  _ROLEBINDING.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002.*,/identity/v1/role-bindings/{role_binding_id}'
  _ROLEBINDING.methods_by_name['get']._options = None
  _ROLEBINDING.methods_by_name['get']._serialized_options = b'\202\323\344\223\002.\022,/identity/v1/role-bindings/{role_binding_id}'
  _ROLEBINDING.methods_by_name['list']._options = None
  _ROLEBINDING.methods_by_name['list']._serialized_options = b'\202\323\344\223\002A\022\032/identity/v1/role-bindingsZ#\"!/identity/v1/role-bindings/search'
  _ROLEBINDING.methods_by_name['stat']._options = None
  _ROLEBINDING.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\031\"\027/identity/v1/roles/stat'
  _CREATEROLEBINDINGREQUEST._serialized_start=320
  _CREATEROLEBINDINGREQUEST._serialized_end=555
  _UPDATEROLEBINDINGREQUEST._serialized_start=558
  _UPDATEROLEBINDINGREQUEST._serialized_end=711
  _ROLEBINDINGREQUEST._serialized_start=713
  _ROLEBINDINGREQUEST._serialized_end=777
  _GETROLEBINDINGREQUEST._serialized_start=779
  _GETROLEBINDINGREQUEST._serialized_end=860
  _ROLEBINDINGINFO._serialized_start=863
  _ROLEBINDINGINFO._serialized_end=1259
  _ROLEBINDINGQUERY._serialized_start=1262
  _ROLEBINDINGQUERY._serialized_end=1494
  _ROLEBINDINGSINFO._serialized_start=1496
  _ROLEBINDINGSINFO._serialized_end=1595
  _ROLEBINDINGSTATQUERY._serialized_start=1597
  _ROLEBINDINGSTATQUERY._serialized_end=1692
  _ROLEBINDING._serialized_start=1695
  _ROLEBINDING._serialized_end=2583
# @@protoc_insertion_point(module_scope)
