# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/anomaly_cost_detection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:spaceone/api/cost_analysis/v1/anomaly_cost_detection.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"V\n\x1eGetAnomalyCostDetectionRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12!\n\x19\x61nomaly_cost_detection_id\x18\x02 \x01(\t\"D\n\nSearchData\x12\x12\n\nstart_date\x18\x01 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x02 \x01(\t\x12\x10\n\x08operator\x18\x03 \x01(\t\"Z\n\x19\x41nomalyCostDetectionQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x9f\x03\n\x18\x41nomalyCostDetectionInfo\x12!\n\x19\x61nomaly_cost_detection_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x0f\n\x07product\x18\x07 \x01(\t\x12\x19\n\x11original_currency\x18\x08 \x01(\t\x12\x14\n\x0csum_usd_cost\x18\t \x01(\x01\x12\x19\n\x11sum_original_cost\x18\n \x01(\x01\x12\x14\n\x0c\x61vg_usd_cost\x18\x0b \x01(\x01\x12\x19\n\x11\x61vg_original_cost\x18\x0c \x01(\x01\x12\x15\n\rexchange_rate\x18\r \x01(\x01\x12\x19\n\x11\x61nomaly_cost_date\x18\x0e \x01(\t\x12\x13\n\x0b\x62illed_date\x18\x0f \x01(\t\x12\x11\n\tbilled_at\x18\x10 \x01(\t\x12\x12\n\ncreated_at\x18\x11 \x01(\t\"z\n\x19\x41nomalyCostDetectionsInfo\x12H\n\x07results\x18\x01 \x03(\x0b\x32\x37.spaceone.api.cost_analysis.v1.AnomalyCostDetectionInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"h\n\x1d\x41nomalyCostDetectionStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x87\x02\n(AnomalyCostDetectionCompareStatDiffQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12<\n\tpast_data\x18\x03 \x01(\x0b\x32).spaceone.api.cost_analysis.v1.SearchData\x12?\n\x0c\x63urrent_data\x18\x04 \x01(\x0b\x32).spaceone.api.cost_analysis.v1.SearchData\x12\x13\n\x0bsearch_type\x18\x05 \x01(\t2\xc3\x05\n\x14\x41nomalyCostDetection\x12\xaf\x01\n\x03get\x12=.spaceone.api.cost_analysis.v1.GetAnomalyCostDetectionRequest\x1a\x37.spaceone.api.cost_analysis.v1.AnomalyCostDetectionInfo\"0\x82\xd3\xe4\x93\x02*\"(/inventory/v1/anomaly-cost-detection/get\x12\xad\x01\n\x04list\x12\x38.spaceone.api.cost_analysis.v1.AnomalyCostDetectionQuery\x1a\x38.spaceone.api.cost_analysis.v1.AnomalyCostDetectionsInfo\"1\x82\xd3\xe4\x93\x02+\")/inventory/v1/anomaly-cost-detection/list\x12\x90\x01\n\x04stat\x12<.spaceone.api.cost_analysis.v1.AnomalyCostDetectionStatQuery\x1a\x17.google.protobuf.Struct\"1\x82\xd3\xe4\x93\x02+\")/inventory/v1/anomaly-cost-detection/stat\x12\xb5\x01\n\x11\x63ompare_stat_diff\x12G.spaceone.api.cost_analysis.v1.AnomalyCostDetectionCompareStatDiffQuery\x1a\x17.google.protobuf.Struct\">\x82\xd3\xe4\x93\x02\x38\"6/inventory/v1/anomaly-cost-detection/compare-stat-diffb\x06proto3')



_GETANOMALYCOSTDETECTIONREQUEST = DESCRIPTOR.message_types_by_name['GetAnomalyCostDetectionRequest']
_SEARCHDATA = DESCRIPTOR.message_types_by_name['SearchData']
_ANOMALYCOSTDETECTIONQUERY = DESCRIPTOR.message_types_by_name['AnomalyCostDetectionQuery']
_ANOMALYCOSTDETECTIONINFO = DESCRIPTOR.message_types_by_name['AnomalyCostDetectionInfo']
_ANOMALYCOSTDETECTIONSINFO = DESCRIPTOR.message_types_by_name['AnomalyCostDetectionsInfo']
_ANOMALYCOSTDETECTIONSTATQUERY = DESCRIPTOR.message_types_by_name['AnomalyCostDetectionStatQuery']
_ANOMALYCOSTDETECTIONCOMPARESTATDIFFQUERY = DESCRIPTOR.message_types_by_name['AnomalyCostDetectionCompareStatDiffQuery']
GetAnomalyCostDetectionRequest = _reflection.GeneratedProtocolMessageType('GetAnomalyCostDetectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETANOMALYCOSTDETECTIONREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetAnomalyCostDetectionRequest)
  })
_sym_db.RegisterMessage(GetAnomalyCostDetectionRequest)

SearchData = _reflection.GeneratedProtocolMessageType('SearchData', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHDATA,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SearchData)
  })
_sym_db.RegisterMessage(SearchData)

AnomalyCostDetectionQuery = _reflection.GeneratedProtocolMessageType('AnomalyCostDetectionQuery', (_message.Message,), {
  'DESCRIPTOR' : _ANOMALYCOSTDETECTIONQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.AnomalyCostDetectionQuery)
  })
_sym_db.RegisterMessage(AnomalyCostDetectionQuery)

AnomalyCostDetectionInfo = _reflection.GeneratedProtocolMessageType('AnomalyCostDetectionInfo', (_message.Message,), {
  'DESCRIPTOR' : _ANOMALYCOSTDETECTIONINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.AnomalyCostDetectionInfo)
  })
_sym_db.RegisterMessage(AnomalyCostDetectionInfo)

AnomalyCostDetectionsInfo = _reflection.GeneratedProtocolMessageType('AnomalyCostDetectionsInfo', (_message.Message,), {
  'DESCRIPTOR' : _ANOMALYCOSTDETECTIONSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.AnomalyCostDetectionsInfo)
  })
_sym_db.RegisterMessage(AnomalyCostDetectionsInfo)

AnomalyCostDetectionStatQuery = _reflection.GeneratedProtocolMessageType('AnomalyCostDetectionStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _ANOMALYCOSTDETECTIONSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.AnomalyCostDetectionStatQuery)
  })
_sym_db.RegisterMessage(AnomalyCostDetectionStatQuery)

AnomalyCostDetectionCompareStatDiffQuery = _reflection.GeneratedProtocolMessageType('AnomalyCostDetectionCompareStatDiffQuery', (_message.Message,), {
  'DESCRIPTOR' : _ANOMALYCOSTDETECTIONCOMPARESTATDIFFQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.anomaly_cost_detection_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.AnomalyCostDetectionCompareStatDiffQuery)
  })
_sym_db.RegisterMessage(AnomalyCostDetectionCompareStatDiffQuery)

_ANOMALYCOSTDETECTION = DESCRIPTOR.services_by_name['AnomalyCostDetection']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ANOMALYCOSTDETECTION.methods_by_name['get']._options = None
  _ANOMALYCOSTDETECTION.methods_by_name['get']._serialized_options = b'\202\323\344\223\002*\"(/inventory/v1/anomaly-cost-detection/get'
  _ANOMALYCOSTDETECTION.methods_by_name['list']._options = None
  _ANOMALYCOSTDETECTION.methods_by_name['list']._serialized_options = b'\202\323\344\223\002+\")/inventory/v1/anomaly-cost-detection/list'
  _ANOMALYCOSTDETECTION.methods_by_name['stat']._options = None
  _ANOMALYCOSTDETECTION.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002+\")/inventory/v1/anomaly-cost-detection/stat'
  _ANOMALYCOSTDETECTION.methods_by_name['compare_stat_diff']._options = None
  _ANOMALYCOSTDETECTION.methods_by_name['compare_stat_diff']._serialized_options = b'\202\323\344\223\0028\"6/inventory/v1/anomaly-cost-detection/compare-stat-diff'
  _GETANOMALYCOSTDETECTIONREQUEST._serialized_start=187
  _GETANOMALYCOSTDETECTIONREQUEST._serialized_end=273
  _SEARCHDATA._serialized_start=275
  _SEARCHDATA._serialized_end=343
  _ANOMALYCOSTDETECTIONQUERY._serialized_start=345
  _ANOMALYCOSTDETECTIONQUERY._serialized_end=435
  _ANOMALYCOSTDETECTIONINFO._serialized_start=438
  _ANOMALYCOSTDETECTIONINFO._serialized_end=853
  _ANOMALYCOSTDETECTIONSINFO._serialized_start=855
  _ANOMALYCOSTDETECTIONSINFO._serialized_end=977
  _ANOMALYCOSTDETECTIONSTATQUERY._serialized_start=979
  _ANOMALYCOSTDETECTIONSTATQUERY._serialized_end=1083
  _ANOMALYCOSTDETECTIONCOMPARESTATDIFFQUERY._serialized_start=1086
  _ANOMALYCOSTDETECTIONCOMPARESTATDIFFQUERY._serialized_end=1349
  _ANOMALYCOSTDETECTION._serialized_start=1352
  _ANOMALYCOSTDETECTION._serialized_end=2059
# @@protoc_insertion_point(module_scope)
