# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/right_size.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*spaceone/api/inventory/v1/right_size.proto\x12\x19spaceone.api.inventory.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"?\n\x13GetRightSizeRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x15\n\rright_size_id\x18\x02 \x01(\t\"O\n\x0eRightSizeQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"]\n\x12RightSizeStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xab\x01\n\x0fRightSizeDetail\x12\x15\n\rdefinition_id\x18\x01 \x01(\t\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x15\n\rsetting_value\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65tail_description\x18\x04 \x01(\t\x12\x39\n\x18metric_stat_result_value\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xdb\x03\n\rRightSizeInfo\x12\x15\n\rright_size_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x0c\n\x04\x66lag\x18\x06 \x01(\t\x12\x17\n\x0fright_size_type\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x15\n\rresource_name\x18\t \x01(\t\x12\x13\n\x0bresource_id\x18\n \x01(\t\x12\x33\n\x12\x63loud_service_info\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nsetting_id\x18\x0c \x01(\t\x12\x39\n\x18recommendation_cost_info\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x11right_size_detail\x18\x0e \x03(\x0b\x32*.spaceone.api.inventory.v1.RightSizeDetail\x12\x12\n\ncreated_at\x18\x0f \x01(\t\x12\x12\n\nupdated_at\x18\x10 \x01(\t\x12\x13\n\x0b\x61nalyzed_at\x18\x11 \x01(\t\"`\n\x0eRightSizesInfo\x12\x39\n\x07results\x18\x01 \x03(\x0b\x32(.spaceone.api.inventory.v1.RightSizeInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x90\x03\n\tRightSize\x12\x85\x01\n\x03get\x12..spaceone.api.inventory.v1.GetRightSizeRequest\x1a(.spaceone.api.inventory.v1.RightSizeInfo\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/inventory/v1/right-size/get\x12\x83\x01\n\x04list\x12).spaceone.api.inventory.v1.RightSizeQuery\x1a).spaceone.api.inventory.v1.RightSizesInfo\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/inventory/v1/right-size/list\x12u\n\x04stat\x12-.spaceone.api.inventory.v1.RightSizeStatQuery\x1a\x17.google.protobuf.Struct\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/inventory/v1/right-size/statb\x06proto3')



_GETRIGHTSIZEREQUEST = DESCRIPTOR.message_types_by_name['GetRightSizeRequest']
_RIGHTSIZEQUERY = DESCRIPTOR.message_types_by_name['RightSizeQuery']
_RIGHTSIZESTATQUERY = DESCRIPTOR.message_types_by_name['RightSizeStatQuery']
_RIGHTSIZEDETAIL = DESCRIPTOR.message_types_by_name['RightSizeDetail']
_RIGHTSIZEINFO = DESCRIPTOR.message_types_by_name['RightSizeInfo']
_RIGHTSIZESINFO = DESCRIPTOR.message_types_by_name['RightSizesInfo']
GetRightSizeRequest = _reflection.GeneratedProtocolMessageType('GetRightSizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRIGHTSIZEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetRightSizeRequest)
  })
_sym_db.RegisterMessage(GetRightSizeRequest)

RightSizeQuery = _reflection.GeneratedProtocolMessageType('RightSizeQuery', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTSIZEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RightSizeQuery)
  })
_sym_db.RegisterMessage(RightSizeQuery)

RightSizeStatQuery = _reflection.GeneratedProtocolMessageType('RightSizeStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTSIZESTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RightSizeStatQuery)
  })
_sym_db.RegisterMessage(RightSizeStatQuery)

RightSizeDetail = _reflection.GeneratedProtocolMessageType('RightSizeDetail', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTSIZEDETAIL,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RightSizeDetail)
  })
_sym_db.RegisterMessage(RightSizeDetail)

RightSizeInfo = _reflection.GeneratedProtocolMessageType('RightSizeInfo', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTSIZEINFO,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RightSizeInfo)
  })
_sym_db.RegisterMessage(RightSizeInfo)

RightSizesInfo = _reflection.GeneratedProtocolMessageType('RightSizesInfo', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTSIZESINFO,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RightSizesInfo)
  })
_sym_db.RegisterMessage(RightSizesInfo)

_RIGHTSIZE = DESCRIPTOR.services_by_name['RightSize']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RIGHTSIZE.methods_by_name['get']._options = None
  _RIGHTSIZE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\036\"\034/inventory/v1/right-size/get'
  _RIGHTSIZE.methods_by_name['list']._options = None
  _RIGHTSIZE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002\037\"\035/inventory/v1/right-size/list'
  _RIGHTSIZE.methods_by_name['stat']._options = None
  _RIGHTSIZE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\037\"\035/inventory/v1/right-size/stat'
  _GETRIGHTSIZEREQUEST._serialized_start=167
  _GETRIGHTSIZEREQUEST._serialized_end=230
  _RIGHTSIZEQUERY._serialized_start=232
  _RIGHTSIZEQUERY._serialized_end=311
  _RIGHTSIZESTATQUERY._serialized_start=313
  _RIGHTSIZESTATQUERY._serialized_end=406
  _RIGHTSIZEDETAIL._serialized_start=409
  _RIGHTSIZEDETAIL._serialized_end=580
  _RIGHTSIZEINFO._serialized_start=583
  _RIGHTSIZEINFO._serialized_end=1058
  _RIGHTSIZESINFO._serialized_start=1060
  _RIGHTSIZESINFO._serialized_end=1156
  _RIGHTSIZE._serialized_start=1159
  _RIGHTSIZE._serialized_end=1559
# @@protoc_insertion_point(module_scope)
