# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/v1/notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spaceone/api/notification/v1/notification.proto\x12\x1cspaceone.api.notification.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x93\x04\n\x19\x43reateNotificationRequest\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12(\n\x07message\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x63\n\x11notification_type\x18\x05 \x01(\x0e\x32H.spaceone.api.notification.v1.CreateNotificationRequest.NotificationType\x12\x65\n\x12notification_level\x18\x07 \x01(\x0e\x32I.spaceone.api.notification.v1.CreateNotificationRequest.NotificationLEVEL\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"]\n\x10NotificationType\x12\x1a\n\x16NOTIFICATION_TYPE_NONE\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07WARNING\x10\x04\"S\n\x11NotificationLEVEL\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03LV1\x10\x02\x12\x07\n\x03LV2\x10\x03\x12\x07\n\x03LV3\x10\x04\x12\x07\n\x03LV4\x10\x05\x12\x07\n\x03LV5\x10\x06\"\xc9\x01\n\x17PushNotificationRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07message\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x19\n\x11notification_type\x18\x04 \x01(\t\x12\x1a\n\x12notification_level\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"?\n\x13NotificationRequest\x12\x15\n\rnotifications\x18\x01 \x03(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"F\n\x1aSetReadNotificationRequest\x12\x15\n\rnotifications\x18\x01 \x03(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"R\n\x16GetNotificationRequest\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xc0\x04\n\x11NotificationQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x17\n\x0fnotification_id\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12[\n\x11notification_type\x18\x04 \x01(\x0e\x32@.spaceone.api.notification.v1.NotificationQuery.NotificationType\x12]\n\x12notification_level\x18\x05 \x01(\x0e\x32\x41.spaceone.api.notification.v1.NotificationQuery.NotificationLEVEL\x12\x0f\n\x07is_read\x18\x06 \x01(\x08\x12\x1e\n\x16parent_notification_id\x18\x07 \x01(\t\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12\x0f\n\x07user_id\x18\t \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"]\n\x10NotificationType\x12\x1a\n\x16NOTIFICATION_TYPE_NONE\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07WARNING\x10\x04\"S\n\x11NotificationLEVEL\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03LV1\x10\x02\x12\x07\n\x03LV2\x10\x03\x12\x07\n\x03LV3\x10\x04\x12\x07\n\x03LV4\x10\x05\x12\x07\n\x03LV5\x10\x06\"\x9b\x04\n\x10NotificationInfo\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12(\n\x07message\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Z\n\x11notification_type\x18\x04 \x01(\x0e\x32?.spaceone.api.notification.v1.NotificationInfo.NotificationType\x12\\\n\x12notification_level\x18\x05 \x01(\x0e\x32@.spaceone.api.notification.v1.NotificationInfo.NotificationLEVEL\x12\x0f\n\x07is_read\x18\x06 \x01(\x08\x12\x0f\n\x07user_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"]\n\x10NotificationType\x12\x1a\n\x16NOTIFICATION_TYPE_NONE\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07WARNING\x10\x04\"S\n\x11NotificationLEVEL\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03LV1\x10\x02\x12\x07\n\x03LV2\x10\x03\x12\x07\n\x03LV3\x10\x04\x12\x07\n\x03LV4\x10\x05\x12\x07\n\x03LV5\x10\x06\"i\n\x11NotificationsInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.notification.v1.NotificationInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"`\n\x15NotificationStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x97\x08\n\x0cNotification\x12\x81\x01\n\x06\x63reate\x12\x37.spaceone.api.notification.v1.CreateNotificationRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1e/notification/v1/notifications\x12\x82\x01\n\x04push\x12\x35.spaceone.api.notification.v1.PushNotificationRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%\"#/notification/v1/notifications/push\x12\x8a\x01\n\x06\x64\x65lete\x12\x31.spaceone.api.notification.v1.NotificationRequest\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/*-/notification/v1/notification/{notifications}\x12\x89\x01\n\x08set_read\x12\x38.spaceone.api.notification.v1.SetReadNotificationRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%\"#/notification/v1/notifications/read\x12\xa4\x01\n\x03get\x12\x34.spaceone.api.notification.v1.GetNotificationRequest\x1a..spaceone.api.notification.v1.NotificationInfo\"7\x82\xd3\xe4\x93\x02\x31\x12//notification/v1/notification/{notification_id}\x12\xb9\x01\n\x04list\x12/.spaceone.api.notification.v1.NotificationQuery\x1a/.spaceone.api.notification.v1.NotificationsInfo\"O\x82\xd3\xe4\x93\x02I\x12\x1e/notification/v1/notificationsZ\'\"%/notification/v1/notifications/search\x12\x81\x01\n\x04stat\x12\x33.spaceone.api.notification.v1.NotificationStatQuery\x1a\x17.google.protobuf.Struct\"+\x82\xd3\xe4\x93\x02%\"#/notification/v1/notifications/statb\x06proto3')



_CREATENOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['CreateNotificationRequest']
_PUSHNOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['PushNotificationRequest']
_NOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['NotificationRequest']
_SETREADNOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['SetReadNotificationRequest']
_GETNOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['GetNotificationRequest']
_NOTIFICATIONQUERY = DESCRIPTOR.message_types_by_name['NotificationQuery']
_NOTIFICATIONINFO = DESCRIPTOR.message_types_by_name['NotificationInfo']
_NOTIFICATIONSINFO = DESCRIPTOR.message_types_by_name['NotificationsInfo']
_NOTIFICATIONSTATQUERY = DESCRIPTOR.message_types_by_name['NotificationStatQuery']
_CREATENOTIFICATIONREQUEST_NOTIFICATIONTYPE = _CREATENOTIFICATIONREQUEST.enum_types_by_name['NotificationType']
_CREATENOTIFICATIONREQUEST_NOTIFICATIONLEVEL = _CREATENOTIFICATIONREQUEST.enum_types_by_name['NotificationLEVEL']
_NOTIFICATIONQUERY_NOTIFICATIONTYPE = _NOTIFICATIONQUERY.enum_types_by_name['NotificationType']
_NOTIFICATIONQUERY_NOTIFICATIONLEVEL = _NOTIFICATIONQUERY.enum_types_by_name['NotificationLEVEL']
_NOTIFICATIONINFO_NOTIFICATIONTYPE = _NOTIFICATIONINFO.enum_types_by_name['NotificationType']
_NOTIFICATIONINFO_NOTIFICATIONLEVEL = _NOTIFICATIONINFO.enum_types_by_name['NotificationLEVEL']
CreateNotificationRequest = _reflection.GeneratedProtocolMessageType('CreateNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.CreateNotificationRequest)
  })
_sym_db.RegisterMessage(CreateNotificationRequest)

PushNotificationRequest = _reflection.GeneratedProtocolMessageType('PushNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUSHNOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.PushNotificationRequest)
  })
_sym_db.RegisterMessage(PushNotificationRequest)

NotificationRequest = _reflection.GeneratedProtocolMessageType('NotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationRequest)
  })
_sym_db.RegisterMessage(NotificationRequest)

SetReadNotificationRequest = _reflection.GeneratedProtocolMessageType('SetReadNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETREADNOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.SetReadNotificationRequest)
  })
_sym_db.RegisterMessage(SetReadNotificationRequest)

GetNotificationRequest = _reflection.GeneratedProtocolMessageType('GetNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.GetNotificationRequest)
  })
_sym_db.RegisterMessage(GetNotificationRequest)

NotificationQuery = _reflection.GeneratedProtocolMessageType('NotificationQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONQUERY,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationQuery)
  })
_sym_db.RegisterMessage(NotificationQuery)

NotificationInfo = _reflection.GeneratedProtocolMessageType('NotificationInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONINFO,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationInfo)
  })
_sym_db.RegisterMessage(NotificationInfo)

NotificationsInfo = _reflection.GeneratedProtocolMessageType('NotificationsInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONSINFO,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationsInfo)
  })
_sym_db.RegisterMessage(NotificationsInfo)

NotificationStatQuery = _reflection.GeneratedProtocolMessageType('NotificationStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONSTATQUERY,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationStatQuery)
  })
_sym_db.RegisterMessage(NotificationStatQuery)

_NOTIFICATION = DESCRIPTOR.services_by_name['Notification']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTIFICATION.methods_by_name['create']._options = None
  _NOTIFICATION.methods_by_name['create']._serialized_options = b'\202\323\344\223\002 \"\036/notification/v1/notifications'
  _NOTIFICATION.methods_by_name['push']._options = None
  _NOTIFICATION.methods_by_name['push']._serialized_options = b'\202\323\344\223\002%\"#/notification/v1/notifications/push'
  _NOTIFICATION.methods_by_name['delete']._options = None
  _NOTIFICATION.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002/*-/notification/v1/notification/{notifications}'
  _NOTIFICATION.methods_by_name['set_read']._options = None
  _NOTIFICATION.methods_by_name['set_read']._serialized_options = b'\202\323\344\223\002%\"#/notification/v1/notifications/read'
  _NOTIFICATION.methods_by_name['get']._options = None
  _NOTIFICATION.methods_by_name['get']._serialized_options = b'\202\323\344\223\0021\022//notification/v1/notification/{notification_id}'
  _NOTIFICATION.methods_by_name['list']._options = None
  _NOTIFICATION.methods_by_name['list']._serialized_options = b'\202\323\344\223\002I\022\036/notification/v1/notificationsZ\'\"%/notification/v1/notifications/search'
  _NOTIFICATION.methods_by_name['stat']._options = None
  _NOTIFICATION.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002%\"#/notification/v1/notifications/stat'
  _CREATENOTIFICATIONREQUEST._serialized_start=205
  _CREATENOTIFICATIONREQUEST._serialized_end=736
  _CREATENOTIFICATIONREQUEST_NOTIFICATIONTYPE._serialized_start=558
  _CREATENOTIFICATIONREQUEST_NOTIFICATIONTYPE._serialized_end=651
  _CREATENOTIFICATIONREQUEST_NOTIFICATIONLEVEL._serialized_start=653
  _CREATENOTIFICATIONREQUEST_NOTIFICATIONLEVEL._serialized_end=736
  _PUSHNOTIFICATIONREQUEST._serialized_start=739
  _PUSHNOTIFICATIONREQUEST._serialized_end=940
  _NOTIFICATIONREQUEST._serialized_start=942
  _NOTIFICATIONREQUEST._serialized_end=1005
  _SETREADNOTIFICATIONREQUEST._serialized_start=1007
  _SETREADNOTIFICATIONREQUEST._serialized_end=1077
  _GETNOTIFICATIONREQUEST._serialized_start=1079
  _GETNOTIFICATIONREQUEST._serialized_end=1161
  _NOTIFICATIONQUERY._serialized_start=1164
  _NOTIFICATIONQUERY._serialized_end=1740
  _NOTIFICATIONQUERY_NOTIFICATIONTYPE._serialized_start=558
  _NOTIFICATIONQUERY_NOTIFICATIONTYPE._serialized_end=651
  _NOTIFICATIONQUERY_NOTIFICATIONLEVEL._serialized_start=653
  _NOTIFICATIONQUERY_NOTIFICATIONLEVEL._serialized_end=736
  _NOTIFICATIONINFO._serialized_start=1743
  _NOTIFICATIONINFO._serialized_end=2282
  _NOTIFICATIONINFO_NOTIFICATIONTYPE._serialized_start=558
  _NOTIFICATIONINFO_NOTIFICATIONTYPE._serialized_end=651
  _NOTIFICATIONINFO_NOTIFICATIONLEVEL._serialized_start=653
  _NOTIFICATIONINFO_NOTIFICATIONLEVEL._serialized_end=736
  _NOTIFICATIONSINFO._serialized_start=2284
  _NOTIFICATIONSINFO._serialized_end=2389
  _NOTIFICATIONSTATQUERY._serialized_start=2391
  _NOTIFICATIONSTATQUERY._serialized_end=2487
  _NOTIFICATION._serialized_start=2490
  _NOTIFICATION._serialized_end=3537
# @@protoc_insertion_point(module_scope)
