# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/budget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*spaceone/api/cost_analysis/v1/budget.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"+\n\x0cPlannedLimit\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x02\"\xe3\x02\n\x12\x42udgetNotification\x12\x11\n\tthreshold\x18\x01 \x01(\x02\x12\x44\n\x04unit\x18\x02 \x01(\x0e\x32\x36.spaceone.api.cost_analysis.v1.BudgetNotification.Unit\x12]\n\x11notification_type\x18\x03 \x01(\x0e\x32\x42.spaceone.api.cost_analysis.v1.BudgetNotification.NotificationType\x12\x15\n\rused_channels\x18\x04 \x03(\t\"3\n\x04Unit\x12\r\n\tUNIT_NONE\x10\x00\x12\x0b\n\x07PERCENT\x10\x01\x12\x0f\n\x0b\x41\x43TUAL_COST\x10\x02\"I\n\x10NotificationType\x12\x1a\n\x16NOTIFICATION_TYPE_NONE\x10\x00\x12\x0c\n\x08\x43RITICAL\x10\x01\x12\x0b\n\x07WARNING\x10\x02\"\x95\x04\n\x13\x43reateBudgetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x02\x12\x43\n\x0eplanned_limits\x18\x03 \x03(\x0b\x32+.spaceone.api.cost_analysis.v1.PlannedLimit\x12+\n\ncost_types\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12N\n\ttime_unit\x18\x05 \x01(\x0e\x32;.spaceone.api.cost_analysis.v1.CreateBudgetRequest.TimeUnit\x12\r\n\x05start\x18\x06 \x01(\t\x12\x0b\n\x03\x65nd\x18\x07 \x01(\t\x12H\n\rnotifications\x18\x08 \x03(\x0b\x32\x31.spaceone.api.cost_analysis.v1.BudgetNotification\x12%\n\x04tags\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x18\n\x10project_group_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\"Q\n\x08TimeUnit\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05TOTAL\x10\x01\x12\x0b\n\x07MONTHLY\x10\x02\x12\n\n\x06YEARLY\x10\x03\x12\x17\n\x13\x43ONSISTENCY_MONTHLY\x10\x04\"\xd1\x01\n\x13UpdateBudgetRequest\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x02\x12\x43\n\x0eplanned_limits\x18\x04 \x03(\x0b\x32+.spaceone.api.cost_analysis.v1.PlannedLimit\x12\x0b\n\x03\x65nd\x18\x05 \x01(\t\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x8e\x01\n\x1cSetBudgetNotificationRequest\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12H\n\rnotifications\x18\x02 \x03(\x0b\x32\x31.spaceone.api.cost_analysis.v1.BudgetNotification\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"5\n\rBudgetRequest\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"F\n\x10GetBudgetRequest\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb6\x02\n\x0b\x42udgetQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tbudget_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x18\n\x10project_group_id\x18\x05 \x01(\t\x12\x46\n\ttime_unit\x18\x06 \x01(\x0e\x32\x33.spaceone.api.cost_analysis.v1.BudgetQuery.TimeUnit\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"Q\n\x08TimeUnit\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05TOTAL\x10\x01\x12\x0b\n\x07MONTHLY\x10\x02\x12\n\n\x06YEARLY\x10\x03\x12\x17\n\x13\x43ONSISTENCY_MONTHLY\x10\x04\"\xdc\x04\n\nBudgetInfo\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x02\x12\x43\n\x0eplanned_limits\x18\x04 \x03(\x0b\x32+.spaceone.api.cost_analysis.v1.PlannedLimit\x12\x1c\n\x14total_usage_usd_cost\x18\x05 \x01(\x02\x12+\n\ncost_types\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\ttime_unit\x18\x07 \x01(\x0e\x32\x32.spaceone.api.cost_analysis.v1.BudgetInfo.TimeUnit\x12\r\n\x05start\x18\x08 \x01(\t\x12\x0b\n\x03\x65nd\x18\t \x01(\t\x12H\n\rnotifications\x18\n \x03(\x0b\x32\x31.spaceone.api.cost_analysis.v1.BudgetNotification\x12%\n\x04tags\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x1f \x01(\t\x12\x18\n\x10project_group_id\x18  \x01(\t\x12\x11\n\tdomain_id\x18! \x01(\t\x12\x12\n\ncreated_at\x18) \x01(\t\x12\x12\n\nupdated_at\x18* \x01(\t\"Q\n\x08TimeUnit\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05TOTAL\x10\x01\x12\x0b\n\x07MONTHLY\x10\x02\x12\n\n\x06YEARLY\x10\x03\x12\x17\n\x13\x43ONSISTENCY_MONTHLY\x10\x04\"^\n\x0b\x42udgetsInfo\x12:\n\x07results\x18\x01 \x03(\x0b\x32).spaceone.api.cost_analysis.v1.BudgetInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Z\n\x0f\x42udgetStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x96\x08\n\x06\x42udget\x12\x8a\x01\n\x06\x63reate\x12\x32.spaceone.api.cost_analysis.v1.CreateBudgetRequest\x1a).spaceone.api.cost_analysis.v1.BudgetInfo\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/cost-analysis/v1/budgets\x12\x95\x01\n\x06update\x12\x32.spaceone.api.cost_analysis.v1.UpdateBudgetRequest\x1a).spaceone.api.cost_analysis.v1.BudgetInfo\",\x82\xd3\xe4\x93\x02&\x1a$/cost-analysis/v1/budget/{budget_id}\x12\xb5\x01\n\x10set_notification\x12;.spaceone.api.cost_analysis.v1.SetBudgetNotificationRequest\x1a).spaceone.api.cost_analysis.v1.BudgetInfo\"9\x82\xd3\xe4\x93\x02\x33\x1a\x31/cost-analysis/v1/budget/{budget_id}/notification\x12|\n\x06\x64\x65lete\x12,.spaceone.api.cost_analysis.v1.BudgetRequest\x1a\x16.google.protobuf.Empty\",\x82\xd3\xe4\x93\x02&*$/cost-analysis/v1/budget/{budget_id}\x12\x8f\x01\n\x03get\x12/.spaceone.api.cost_analysis.v1.GetBudgetRequest\x1a).spaceone.api.cost_analysis.v1.BudgetInfo\",\x82\xd3\xe4\x93\x02&\x12$/cost-analysis/v1/budget/{budget_id}\x12\xa5\x01\n\x04list\x12*.spaceone.api.cost_analysis.v1.BudgetQuery\x1a*.spaceone.api.cost_analysis.v1.BudgetsInfo\"E\x82\xd3\xe4\x93\x02?\x12\x19/cost-analysis/v1/budgetsZ\"\" /cost-analysis/v1/budgets/search\x12w\n\x04stat\x12..spaceone.api.cost_analysis.v1.BudgetStatQuery\x1a\x17.google.protobuf.Struct\"&\x82\xd3\xe4\x93\x02 \"\x1e/cost-analysis/v1/budgets/statb\x06proto3')



_PLANNEDLIMIT = DESCRIPTOR.message_types_by_name['PlannedLimit']
_BUDGETNOTIFICATION = DESCRIPTOR.message_types_by_name['BudgetNotification']
_CREATEBUDGETREQUEST = DESCRIPTOR.message_types_by_name['CreateBudgetRequest']
_UPDATEBUDGETREQUEST = DESCRIPTOR.message_types_by_name['UpdateBudgetRequest']
_SETBUDGETNOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['SetBudgetNotificationRequest']
_BUDGETREQUEST = DESCRIPTOR.message_types_by_name['BudgetRequest']
_GETBUDGETREQUEST = DESCRIPTOR.message_types_by_name['GetBudgetRequest']
_BUDGETQUERY = DESCRIPTOR.message_types_by_name['BudgetQuery']
_BUDGETINFO = DESCRIPTOR.message_types_by_name['BudgetInfo']
_BUDGETSINFO = DESCRIPTOR.message_types_by_name['BudgetsInfo']
_BUDGETSTATQUERY = DESCRIPTOR.message_types_by_name['BudgetStatQuery']
_BUDGETNOTIFICATION_UNIT = _BUDGETNOTIFICATION.enum_types_by_name['Unit']
_BUDGETNOTIFICATION_NOTIFICATIONTYPE = _BUDGETNOTIFICATION.enum_types_by_name['NotificationType']
_CREATEBUDGETREQUEST_TIMEUNIT = _CREATEBUDGETREQUEST.enum_types_by_name['TimeUnit']
_BUDGETQUERY_TIMEUNIT = _BUDGETQUERY.enum_types_by_name['TimeUnit']
_BUDGETINFO_TIMEUNIT = _BUDGETINFO.enum_types_by_name['TimeUnit']
PlannedLimit = _reflection.GeneratedProtocolMessageType('PlannedLimit', (_message.Message,), {
  'DESCRIPTOR' : _PLANNEDLIMIT,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PlannedLimit)
  })
_sym_db.RegisterMessage(PlannedLimit)

BudgetNotification = _reflection.GeneratedProtocolMessageType('BudgetNotification', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETNOTIFICATION,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetNotification)
  })
_sym_db.RegisterMessage(BudgetNotification)

CreateBudgetRequest = _reflection.GeneratedProtocolMessageType('CreateBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBUDGETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreateBudgetRequest)
  })
_sym_db.RegisterMessage(CreateBudgetRequest)

UpdateBudgetRequest = _reflection.GeneratedProtocolMessageType('UpdateBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBUDGETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateBudgetRequest)
  })
_sym_db.RegisterMessage(UpdateBudgetRequest)

SetBudgetNotificationRequest = _reflection.GeneratedProtocolMessageType('SetBudgetNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETBUDGETNOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SetBudgetNotificationRequest)
  })
_sym_db.RegisterMessage(SetBudgetNotificationRequest)

BudgetRequest = _reflection.GeneratedProtocolMessageType('BudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetRequest)
  })
_sym_db.RegisterMessage(BudgetRequest)

GetBudgetRequest = _reflection.GeneratedProtocolMessageType('GetBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUDGETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetBudgetRequest)
  })
_sym_db.RegisterMessage(GetBudgetRequest)

BudgetQuery = _reflection.GeneratedProtocolMessageType('BudgetQuery', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetQuery)
  })
_sym_db.RegisterMessage(BudgetQuery)

BudgetInfo = _reflection.GeneratedProtocolMessageType('BudgetInfo', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetInfo)
  })
_sym_db.RegisterMessage(BudgetInfo)

BudgetsInfo = _reflection.GeneratedProtocolMessageType('BudgetsInfo', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetsInfo)
  })
_sym_db.RegisterMessage(BudgetsInfo)

BudgetStatQuery = _reflection.GeneratedProtocolMessageType('BudgetStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetStatQuery)
  })
_sym_db.RegisterMessage(BudgetStatQuery)

_BUDGET = DESCRIPTOR.services_by_name['Budget']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUDGET.methods_by_name['create']._options = None
  _BUDGET.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\033\"\031/cost-analysis/v1/budgets'
  _BUDGET.methods_by_name['update']._options = None
  _BUDGET.methods_by_name['update']._serialized_options = b'\202\323\344\223\002&\032$/cost-analysis/v1/budget/{budget_id}'
  _BUDGET.methods_by_name['set_notification']._options = None
  _BUDGET.methods_by_name['set_notification']._serialized_options = b'\202\323\344\223\0023\0321/cost-analysis/v1/budget/{budget_id}/notification'
  _BUDGET.methods_by_name['delete']._options = None
  _BUDGET.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002&*$/cost-analysis/v1/budget/{budget_id}'
  _BUDGET.methods_by_name['get']._options = None
  _BUDGET.methods_by_name['get']._serialized_options = b'\202\323\344\223\002&\022$/cost-analysis/v1/budget/{budget_id}'
  _BUDGET.methods_by_name['list']._options = None
  _BUDGET.methods_by_name['list']._serialized_options = b'\202\323\344\223\002?\022\031/cost-analysis/v1/budgetsZ\"\" /cost-analysis/v1/budgets/search'
  _BUDGET.methods_by_name['stat']._options = None
  _BUDGET.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002 \"\036/cost-analysis/v1/budgets/stat'
  _PLANNEDLIMIT._serialized_start=200
  _PLANNEDLIMIT._serialized_end=243
  _BUDGETNOTIFICATION._serialized_start=246
  _BUDGETNOTIFICATION._serialized_end=601
  _BUDGETNOTIFICATION_UNIT._serialized_start=475
  _BUDGETNOTIFICATION_UNIT._serialized_end=526
  _BUDGETNOTIFICATION_NOTIFICATIONTYPE._serialized_start=528
  _BUDGETNOTIFICATION_NOTIFICATIONTYPE._serialized_end=601
  _CREATEBUDGETREQUEST._serialized_start=604
  _CREATEBUDGETREQUEST._serialized_end=1137
  _CREATEBUDGETREQUEST_TIMEUNIT._serialized_start=1056
  _CREATEBUDGETREQUEST_TIMEUNIT._serialized_end=1137
  _UPDATEBUDGETREQUEST._serialized_start=1140
  _UPDATEBUDGETREQUEST._serialized_end=1349
  _SETBUDGETNOTIFICATIONREQUEST._serialized_start=1352
  _SETBUDGETNOTIFICATIONREQUEST._serialized_end=1494
  _BUDGETREQUEST._serialized_start=1496
  _BUDGETREQUEST._serialized_end=1549
  _GETBUDGETREQUEST._serialized_start=1551
  _GETBUDGETREQUEST._serialized_end=1621
  _BUDGETQUERY._serialized_start=1624
  _BUDGETQUERY._serialized_end=1934
  _BUDGETQUERY_TIMEUNIT._serialized_start=1056
  _BUDGETQUERY_TIMEUNIT._serialized_end=1137
  _BUDGETINFO._serialized_start=1937
  _BUDGETINFO._serialized_end=2541
  _BUDGETINFO_TIMEUNIT._serialized_start=1056
  _BUDGETINFO_TIMEUNIT._serialized_end=1137
  _BUDGETSINFO._serialized_start=2543
  _BUDGETSINFO._serialized_end=2637
  _BUDGETSTATQUERY._serialized_start=2639
  _BUDGETSTATQUERY._serialized_end=2729
  _BUDGET._serialized_start=2732
  _BUDGET._serialized_end=3778
# @@protoc_insertion_point(module_scope)
