# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/plugin/protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spaceone/api/notification/plugin/protocol.proto\x12 spaceone.api.notification.plugin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"7\n\x0bInitRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"m\n\x13PluginVerifyRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"7\n\nPluginInfo\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xcc\x01\n\x08Protocol\x12\x65\n\x04init\x12-.spaceone.api.notification.plugin.InitRequest\x1a,.spaceone.api.notification.plugin.PluginInfo\"\x00\x12Y\n\x06verify\x12\x35.spaceone.api.notification.plugin.PluginVerifyRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')



_INITREQUEST = DESCRIPTOR.message_types_by_name['InitRequest']
_PLUGINVERIFYREQUEST = DESCRIPTOR.message_types_by_name['PluginVerifyRequest']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
InitRequest = _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITREQUEST,
  '__module__' : 'spaceone.api.notification.plugin.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.plugin.InitRequest)
  })
_sym_db.RegisterMessage(InitRequest)

PluginVerifyRequest = _reflection.GeneratedProtocolMessageType('PluginVerifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINVERIFYREQUEST,
  '__module__' : 'spaceone.api.notification.plugin.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.plugin.PluginVerifyRequest)
  })
_sym_db.RegisterMessage(PluginVerifyRequest)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.notification.plugin.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.plugin.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

_PROTOCOL = DESCRIPTOR.services_by_name['Protocol']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INITREQUEST._serialized_start=144
  _INITREQUEST._serialized_end=199
  _PLUGINVERIFYREQUEST._serialized_start=201
  _PLUGINVERIFYREQUEST._serialized_end=310
  _PLUGININFO._serialized_start=312
  _PLUGININFO._serialized_end=367
  _PROTOCOL._serialized_start=370
  _PROTOCOL._serialized_end=574
# @@protoc_insertion_point(module_scope)
