# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/catalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.provisioning.v1 import catalog_resource_pb2 as spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__resource__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.provisioning.v1 import catalog_group_pb2 as spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*spaceone/api/provisioning/v1/catalog.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x33spaceone/api/provisioning/v1/catalog_resource.proto\x1a spaceone/api/core/v1/query.proto\x1a\x30spaceone/api/provisioning/v1/catalog_group.proto\"\xb9\x01\n\x15PublishCatalogRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\x12\x13\n\x0bplan_status\x18\x07 \x01(\t\x12\x14\n\x0cpublish_type\x18\x08 \x01(\t\"\x85\x03\n\x14\x43reateCatalogRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x02 \x01(\t\x12\x16\n\x0eterraform_code\x18\x03 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x13\n\x0bplan_status\x18\n \x01(\t\x12\x0f\n\x07opinion\x18\x0b \x01(\t\x12\x17\n\x0f\x63\x61talog_summary\x18\x0c \x01(\t\x12\x14\n\x0c\x63\x61talog_desc\x18\r \x01(\t\x12\x44\n\tresources\x18\x0e \x03(\x0b\x32\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\x12\x18\n\x10\x63\x61talog_group_id\x18\x0f \x01(\t\"7\n\x0e\x43\x61talogRequest\x12\x12\n\ncatalog_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"H\n\x11GetCatalogRequest\x12\x12\n\ncatalog_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x99\x03\n\x14UpdateCatalogRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x03 \x01(\t\x12\x16\n\x0eterraform_code\x18\x04 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12\x0e\n\x06status\x18\t \x01(\t\x12\x10\n\x08provider\x18\n \x01(\t\x12\x13\n\x0bplan_status\x18\x0b \x01(\t\x12\x0f\n\x07opinion\x18\x0c \x01(\t\x12\x17\n\x0f\x63\x61talog_summary\x18\r \x01(\t\x12\x14\n\x0c\x63\x61talog_desc\x18\x0e \x01(\t\x12\x44\n\tresources\x18\x0f \x03(\x0b\x32\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\x12\x18\n\x10\x63\x61talog_group_id\x18\x10 \x01(\t\"\x84\x04\n\x0b\x43\x61talogInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x03 \x01(\t\x12\x16\n\x0eterraform_code\x18\x04 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x12\n\nupdated_at\x18\n \x01(\t\x12\x0e\n\x06status\x18\x0b \x01(\t\x12\x10\n\x08provider\x18\x0c \x01(\t\x12\x13\n\x0bplan_status\x18\r \x01(\t\x12\x0f\n\x07opinion\x18\x0e \x01(\t\x12\x17\n\x0f\x63\x61talog_summary\x18\x0f \x01(\t\x12\x14\n\x0c\x63\x61talog_desc\x18\x10 \x01(\t\x12\x44\n\tresources\x18\x11 \x03(\x0b\x32\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\x12\x18\n\x10\x63\x61talog_group_id\x18\x12 \x01(\t\x12J\n\x12\x63\x61talog_group_info\x18\x13 \x01(\x0b\x32..spaceone.api.provisioning.v1.CatalogGroupInfo\"_\n\x0c\x43\x61talogsInfo\x12:\n\x07results\x18\x01 \x03(\x0b\x32).spaceone.api.provisioning.v1.CatalogInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xaf\x01\n\x0c\x43\x61talogQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x12\n\nupdated_by\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\t\"[\n\x10\x43\x61talogStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xb6\n\n\x07\x43\x61talog\x12\x91\x01\n\x0e\x63reate_catalog\x12\x32.spaceone.api.provisioning.v1.CreateCatalogRequest\x1a).spaceone.api.provisioning.v1.CatalogInfo\" \x82\xd3\xe4\x93\x02\x1a\"\x18/provisioning/v1/catalog\x12\xad\x01\n\x0cget_catalogs\x12*.spaceone.api.provisioning.v1.CatalogQuery\x1a*.spaceone.api.provisioning.v1.CatalogsInfo\"E\x82\xd3\xe4\x93\x02?\x12\x19/provisioning/v1/catalogsZ\"\" /provisioning/v1/catalogs/search\x12\x98\x01\n\x0bget_catalog\x12/.spaceone.api.provisioning.v1.GetCatalogRequest\x1a).spaceone.api.provisioning.v1.CatalogInfo\"-\x82\xd3\xe4\x93\x02\'\x12%/provisioning/v1/catalog/{catalog_id}\x12\x91\x01\n\x0eupdate_catalog\x12\x32.spaceone.api.provisioning.v1.UpdateCatalogRequest\x1a).spaceone.api.provisioning.v1.CatalogInfo\" \x82\xd3\xe4\x93\x02\x1a\x1a\x18/provisioning/v1/catalog\x12\x85\x01\n\x0e\x64\x65lete_catalog\x12,.spaceone.api.provisioning.v1.CatalogRequest\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'*%/provisioning/v1/catalog/{catalog_id}\x12\x88\x01\n\x0fpublish_catalog\x12\x33.spaceone.api.provisioning.v1.PublishCatalogRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"\" /provisioning/v1/catalog/publish\x12v\n\x04stat\x12..spaceone.api.provisioning.v1.CatalogStatQuery\x1a\x17.google.protobuf.Struct\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/provisioning/v1/catalog/stat\x12\x85\x01\n\x0cplan_catalog\x12\x33.spaceone.api.provisioning.v1.PublishCatalogRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"\" /provisioning/v1/catalog/publish\x12\xa4\x01\n\x10\x61pproval_process\x12\x32.spaceone.api.provisioning.v1.UpdateCatalogRequest\x1a).spaceone.api.provisioning.v1.CatalogInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/provisioning/v1/catalog/approval-processb\x06proto3')



_PUBLISHCATALOGREQUEST = DESCRIPTOR.message_types_by_name['PublishCatalogRequest']
_CREATECATALOGREQUEST = DESCRIPTOR.message_types_by_name['CreateCatalogRequest']
_CATALOGREQUEST = DESCRIPTOR.message_types_by_name['CatalogRequest']
_GETCATALOGREQUEST = DESCRIPTOR.message_types_by_name['GetCatalogRequest']
_UPDATECATALOGREQUEST = DESCRIPTOR.message_types_by_name['UpdateCatalogRequest']
_CATALOGINFO = DESCRIPTOR.message_types_by_name['CatalogInfo']
_CATALOGSINFO = DESCRIPTOR.message_types_by_name['CatalogsInfo']
_CATALOGQUERY = DESCRIPTOR.message_types_by_name['CatalogQuery']
_CATALOGSTATQUERY = DESCRIPTOR.message_types_by_name['CatalogStatQuery']
PublishCatalogRequest = _reflection.GeneratedProtocolMessageType('PublishCatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHCATALOGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.PublishCatalogRequest)
  })
_sym_db.RegisterMessage(PublishCatalogRequest)

CreateCatalogRequest = _reflection.GeneratedProtocolMessageType('CreateCatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECATALOGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateCatalogRequest)
  })
_sym_db.RegisterMessage(CreateCatalogRequest)

CatalogRequest = _reflection.GeneratedProtocolMessageType('CatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogRequest)
  })
_sym_db.RegisterMessage(CatalogRequest)

GetCatalogRequest = _reflection.GeneratedProtocolMessageType('GetCatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCATALOGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetCatalogRequest)
  })
_sym_db.RegisterMessage(GetCatalogRequest)

UpdateCatalogRequest = _reflection.GeneratedProtocolMessageType('UpdateCatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECATALOGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateCatalogRequest)
  })
_sym_db.RegisterMessage(UpdateCatalogRequest)

CatalogInfo = _reflection.GeneratedProtocolMessageType('CatalogInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogInfo)
  })
_sym_db.RegisterMessage(CatalogInfo)

CatalogsInfo = _reflection.GeneratedProtocolMessageType('CatalogsInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogsInfo)
  })
_sym_db.RegisterMessage(CatalogsInfo)

CatalogQuery = _reflection.GeneratedProtocolMessageType('CatalogQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogQuery)
  })
_sym_db.RegisterMessage(CatalogQuery)

CatalogStatQuery = _reflection.GeneratedProtocolMessageType('CatalogStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogStatQuery)
  })
_sym_db.RegisterMessage(CatalogStatQuery)

_CATALOG = DESCRIPTOR.services_by_name['Catalog']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CATALOG.methods_by_name['create_catalog']._options = None
  _CATALOG.methods_by_name['create_catalog']._serialized_options = b'\202\323\344\223\002\032\"\030/provisioning/v1/catalog'
  _CATALOG.methods_by_name['get_catalogs']._options = None
  _CATALOG.methods_by_name['get_catalogs']._serialized_options = b'\202\323\344\223\002?\022\031/provisioning/v1/catalogsZ\"\" /provisioning/v1/catalogs/search'
  _CATALOG.methods_by_name['get_catalog']._options = None
  _CATALOG.methods_by_name['get_catalog']._serialized_options = b'\202\323\344\223\002\'\022%/provisioning/v1/catalog/{catalog_id}'
  _CATALOG.methods_by_name['update_catalog']._options = None
  _CATALOG.methods_by_name['update_catalog']._serialized_options = b'\202\323\344\223\002\032\032\030/provisioning/v1/catalog'
  _CATALOG.methods_by_name['delete_catalog']._options = None
  _CATALOG.methods_by_name['delete_catalog']._serialized_options = b'\202\323\344\223\002\'*%/provisioning/v1/catalog/{catalog_id}'
  _CATALOG.methods_by_name['publish_catalog']._options = None
  _CATALOG.methods_by_name['publish_catalog']._serialized_options = b'\202\323\344\223\002\"\" /provisioning/v1/catalog/publish'
  _CATALOG.methods_by_name['stat']._options = None
  _CATALOG.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\037\"\035/provisioning/v1/catalog/stat'
  _CATALOG.methods_by_name['plan_catalog']._options = None
  _CATALOG.methods_by_name['plan_catalog']._serialized_options = b'\202\323\344\223\002\"\" /provisioning/v1/catalog/publish'
  _CATALOG.methods_by_name['approval_process']._options = None
  _CATALOG.methods_by_name['approval_process']._serialized_options = b'\202\323\344\223\002+\032)/provisioning/v1/catalog/approval-process'
  _PUBLISHCATALOGREQUEST._serialized_start=303
  _PUBLISHCATALOGREQUEST._serialized_end=488
  _CREATECATALOGREQUEST._serialized_start=491
  _CREATECATALOGREQUEST._serialized_end=880
  _CATALOGREQUEST._serialized_start=882
  _CATALOGREQUEST._serialized_end=937
  _GETCATALOGREQUEST._serialized_start=939
  _GETCATALOGREQUEST._serialized_end=1011
  _UPDATECATALOGREQUEST._serialized_start=1014
  _UPDATECATALOGREQUEST._serialized_end=1423
  _CATALOGINFO._serialized_start=1426
  _CATALOGINFO._serialized_end=1942
  _CATALOGSINFO._serialized_start=1944
  _CATALOGSINFO._serialized_end=2039
  _CATALOGQUERY._serialized_start=2042
  _CATALOGQUERY._serialized_end=2217
  _CATALOGSTATQUERY._serialized_start=2219
  _CATALOGSTATQUERY._serialized_end=2310
  _CATALOG._serialized_start=2313
  _CATALOG._serialized_end=3647
# @@protoc_insertion_point(module_scope)
