# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/dashboard/v1/project_dashboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1spaceone/api/dashboard/v1/project_dashboard.proto\x12\x19spaceone.api.dashboard.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\",\n\x19ProjectDashboardDateRange\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"+\n\x18ProjectDashboardCurrency\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\xab\x01\n\x18ProjectDashboardSettings\x12H\n\ndate_range\x18\x01 \x01(\x0b\x32\x34.spaceone.api.dashboard.v1.ProjectDashboardDateRange\x12\x45\n\x08\x63urrency\x18\x02 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.ProjectDashboardCurrency\"\x93\x04\n\x1d\x43reateProjectDashboardRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Q\n\x07viewers\x18\x03 \x01(\x0e\x32@.spaceone.api.dashboard.v1.CreateProjectDashboardRequest.Viewers\x12+\n\x07layouts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x08settings\x18\x06 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.ProjectDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"4\n\x07Viewers\x12\x10\n\x0cVIEWERS_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"\x94\x03\n\x1dUpdateProjectDashboardRequest\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12+\n\x07layouts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x08settings\x18\x06 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.ProjectDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"J\n\x17ProjectDashboardRequest\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"[\n\x1aGetProjectDashboardRequest\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"b\n\x1eProjectDashboardVersionRequest\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"s\n!GetProjectDashboardVersionRequest\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x11\n\tdomain_id\x18\n \x01(\t\x12\x0c\n\x04only\x18\x0b \x03(\t\"\x8c\x01\n\x1cProjectDashboardVersionQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1c\n\x14project_dashboard_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x11\n\tdomain_id\x18\n \x01(\t\"\xa8\x02\n\x15ProjectDashboardQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1c\n\x14project_dashboard_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12I\n\x07viewers\x18\x05 \x01(\x0e\x32\x38.spaceone.api.dashboard.v1.ProjectDashboardQuery.Viewers\x12\x0f\n\x07user_id\x18\n \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"4\n\x07Viewers\x12\x10\n\x0cVIEWERS_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"\xe9\x04\n\x14ProjectDashboardInfo\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12H\n\x07viewers\x18\x04 \x01(\x0e\x32\x37.spaceone.api.dashboard.v1.ProjectDashboardInfo.Viewers\x12\x0f\n\x07version\x18\x05 \x01(\x05\x12+\n\x07layouts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x08settings\x18\x08 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.ProjectDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x14 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\x12\x12\n\ncreated_at\x18\x17 \x01(\t\x12\x12\n\nupdated_at\x18\x18 \x01(\t\"4\n\x07Viewers\x12\x10\n\x0cVIEWERS_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"n\n\x15ProjectDashboardsInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.dashboard.v1.ProjectDashboardInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"d\n\x19ProjectDashboardStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xe6\x02\n\x1bProjectDashboardVersionInfo\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x0e\n\x06latest\x18\x03 \x01(\x08\x12+\n\x07layouts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x08settings\x18\x07 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.ProjectDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\"|\n\x1cProjectDashboardVersionsInfo\x12G\n\x07results\x18\x01 \x03(\x0b\x32\x36.spaceone.api.dashboard.v1.ProjectDashboardVersionInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xf9\x0e\n\x10ProjectDashboard\x12\x9d\x01\n\x06\x63reate\x12\x38.spaceone.api.dashboard.v1.CreateProjectDashboardRequest\x1a/.spaceone.api.dashboard.v1.ProjectDashboardInfo\"(\x82\xd3\xe4\x93\x02\"\" /dashboard/v1/project-dashboards\x12\xb3\x01\n\x06update\x12\x38.spaceone.api.dashboard.v1.UpdateProjectDashboardRequest\x1a/.spaceone.api.dashboard.v1.ProjectDashboardInfo\">\x82\xd3\xe4\x93\x02\x38\x1a\x36/dashboard/v1/project-dashboard/{project_dashboard_id}\x12\x94\x01\n\x06\x64\x65lete\x12\x32.spaceone.api.dashboard.v1.ProjectDashboardRequest\x1a\x16.google.protobuf.Empty\">\x82\xd3\xe4\x93\x02\x38*6/dashboard/v1/project-dashboard/{project_dashboard_id}\x12\xad\x01\n\x03get\x12\x35.spaceone.api.dashboard.v1.GetProjectDashboardRequest\x1a/.spaceone.api.dashboard.v1.ProjectDashboardInfo\">\x82\xd3\xe4\x93\x02\x38\x12\x36/dashboard/v1/project-dashboard/{project_dashboard_id}\x12\xb5\x01\n\x0e\x64\x65lete_version\x12\x39.spaceone.api.dashboard.v1.ProjectDashboardVersionRequest\x1a\x16.google.protobuf.Empty\"P\x82\xd3\xe4\x93\x02J*H/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}\x12\xd5\x01\n\x0erevert_version\x12\x39.spaceone.api.dashboard.v1.ProjectDashboardVersionRequest\x1a/.spaceone.api.dashboard.v1.ProjectDashboardInfo\"W\x82\xd3\xe4\x93\x02Q\"O/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}/revert\x12\xd5\x01\n\x0bget_version\x12<.spaceone.api.dashboard.v1.GetProjectDashboardVersionRequest\x1a\x36.spaceone.api.dashboard.v1.ProjectDashboardVersionInfo\"P\x82\xd3\xe4\x93\x02J\x12H/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}\x12\x96\x02\n\rlist_versions\x12\x37.spaceone.api.dashboard.v1.ProjectDashboardVersionQuery\x1a\x37.spaceone.api.dashboard.v1.ProjectDashboardVersionsInfo\"\x92\x01\x82\xd3\xe4\x93\x02\x8b\x01\x12?/dashboard/v1/project-dashboard/{project_dashboard_id}/versionsZH\"F/dashboard/v1/project-dashboard/{project_dashboard_id}/versions/search\x12\xbf\x01\n\x04list\x12\x30.spaceone.api.dashboard.v1.ProjectDashboardQuery\x1a\x30.spaceone.api.dashboard.v1.ProjectDashboardsInfo\"S\x82\xd3\xe4\x93\x02M\x12 /dashboard/v1/project-dashboardsZ)\"\'/dashboard/v1/project-dashboards/search\x12\x84\x01\n\x04stat\x12\x34.spaceone.api.dashboard.v1.ProjectDashboardStatQuery\x1a\x17.google.protobuf.Struct\"-\x82\xd3\xe4\x93\x02\'\"%/dashboard/v1/project-dashboards/statb\x06proto3')



_PROJECTDASHBOARDDATERANGE = DESCRIPTOR.message_types_by_name['ProjectDashboardDateRange']
_PROJECTDASHBOARDCURRENCY = DESCRIPTOR.message_types_by_name['ProjectDashboardCurrency']
_PROJECTDASHBOARDSETTINGS = DESCRIPTOR.message_types_by_name['ProjectDashboardSettings']
_CREATEPROJECTDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectDashboardRequest']
_UPDATEPROJECTDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectDashboardRequest']
_PROJECTDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['ProjectDashboardRequest']
_GETPROJECTDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['GetProjectDashboardRequest']
_PROJECTDASHBOARDVERSIONREQUEST = DESCRIPTOR.message_types_by_name['ProjectDashboardVersionRequest']
_GETPROJECTDASHBOARDVERSIONREQUEST = DESCRIPTOR.message_types_by_name['GetProjectDashboardVersionRequest']
_PROJECTDASHBOARDVERSIONQUERY = DESCRIPTOR.message_types_by_name['ProjectDashboardVersionQuery']
_PROJECTDASHBOARDQUERY = DESCRIPTOR.message_types_by_name['ProjectDashboardQuery']
_PROJECTDASHBOARDINFO = DESCRIPTOR.message_types_by_name['ProjectDashboardInfo']
_PROJECTDASHBOARDSINFO = DESCRIPTOR.message_types_by_name['ProjectDashboardsInfo']
_PROJECTDASHBOARDSTATQUERY = DESCRIPTOR.message_types_by_name['ProjectDashboardStatQuery']
_PROJECTDASHBOARDVERSIONINFO = DESCRIPTOR.message_types_by_name['ProjectDashboardVersionInfo']
_PROJECTDASHBOARDVERSIONSINFO = DESCRIPTOR.message_types_by_name['ProjectDashboardVersionsInfo']
_CREATEPROJECTDASHBOARDREQUEST_VIEWERS = _CREATEPROJECTDASHBOARDREQUEST.enum_types_by_name['Viewers']
_PROJECTDASHBOARDQUERY_VIEWERS = _PROJECTDASHBOARDQUERY.enum_types_by_name['Viewers']
_PROJECTDASHBOARDINFO_VIEWERS = _PROJECTDASHBOARDINFO.enum_types_by_name['Viewers']
ProjectDashboardDateRange = _reflection.GeneratedProtocolMessageType('ProjectDashboardDateRange', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDDATERANGE,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardDateRange)
  })
_sym_db.RegisterMessage(ProjectDashboardDateRange)

ProjectDashboardCurrency = _reflection.GeneratedProtocolMessageType('ProjectDashboardCurrency', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDCURRENCY,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardCurrency)
  })
_sym_db.RegisterMessage(ProjectDashboardCurrency)

ProjectDashboardSettings = _reflection.GeneratedProtocolMessageType('ProjectDashboardSettings', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDSETTINGS,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardSettings)
  })
_sym_db.RegisterMessage(ProjectDashboardSettings)

CreateProjectDashboardRequest = _reflection.GeneratedProtocolMessageType('CreateProjectDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.CreateProjectDashboardRequest)
  })
_sym_db.RegisterMessage(CreateProjectDashboardRequest)

UpdateProjectDashboardRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.UpdateProjectDashboardRequest)
  })
_sym_db.RegisterMessage(UpdateProjectDashboardRequest)

ProjectDashboardRequest = _reflection.GeneratedProtocolMessageType('ProjectDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardRequest)
  })
_sym_db.RegisterMessage(ProjectDashboardRequest)

GetProjectDashboardRequest = _reflection.GeneratedProtocolMessageType('GetProjectDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.GetProjectDashboardRequest)
  })
_sym_db.RegisterMessage(GetProjectDashboardRequest)

ProjectDashboardVersionRequest = _reflection.GeneratedProtocolMessageType('ProjectDashboardVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDVERSIONREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardVersionRequest)
  })
_sym_db.RegisterMessage(ProjectDashboardVersionRequest)

GetProjectDashboardVersionRequest = _reflection.GeneratedProtocolMessageType('GetProjectDashboardVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTDASHBOARDVERSIONREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.GetProjectDashboardVersionRequest)
  })
_sym_db.RegisterMessage(GetProjectDashboardVersionRequest)

ProjectDashboardVersionQuery = _reflection.GeneratedProtocolMessageType('ProjectDashboardVersionQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDVERSIONQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardVersionQuery)
  })
_sym_db.RegisterMessage(ProjectDashboardVersionQuery)

ProjectDashboardQuery = _reflection.GeneratedProtocolMessageType('ProjectDashboardQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardQuery)
  })
_sym_db.RegisterMessage(ProjectDashboardQuery)

ProjectDashboardInfo = _reflection.GeneratedProtocolMessageType('ProjectDashboardInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDINFO,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardInfo)
  })
_sym_db.RegisterMessage(ProjectDashboardInfo)

ProjectDashboardsInfo = _reflection.GeneratedProtocolMessageType('ProjectDashboardsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDSINFO,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardsInfo)
  })
_sym_db.RegisterMessage(ProjectDashboardsInfo)

ProjectDashboardStatQuery = _reflection.GeneratedProtocolMessageType('ProjectDashboardStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDSTATQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardStatQuery)
  })
_sym_db.RegisterMessage(ProjectDashboardStatQuery)

ProjectDashboardVersionInfo = _reflection.GeneratedProtocolMessageType('ProjectDashboardVersionInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDVERSIONINFO,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardVersionInfo)
  })
_sym_db.RegisterMessage(ProjectDashboardVersionInfo)

ProjectDashboardVersionsInfo = _reflection.GeneratedProtocolMessageType('ProjectDashboardVersionsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDVERSIONSINFO,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardVersionsInfo)
  })
_sym_db.RegisterMessage(ProjectDashboardVersionsInfo)

_PROJECTDASHBOARD = DESCRIPTOR.services_by_name['ProjectDashboard']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECTDASHBOARD.methods_by_name['create']._options = None
  _PROJECTDASHBOARD.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\"\" /dashboard/v1/project-dashboards'
  _PROJECTDASHBOARD.methods_by_name['update']._options = None
  _PROJECTDASHBOARD.methods_by_name['update']._serialized_options = b'\202\323\344\223\0028\0326/dashboard/v1/project-dashboard/{project_dashboard_id}'
  _PROJECTDASHBOARD.methods_by_name['delete']._options = None
  _PROJECTDASHBOARD.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0028*6/dashboard/v1/project-dashboard/{project_dashboard_id}'
  _PROJECTDASHBOARD.methods_by_name['get']._options = None
  _PROJECTDASHBOARD.methods_by_name['get']._serialized_options = b'\202\323\344\223\0028\0226/dashboard/v1/project-dashboard/{project_dashboard_id}'
  _PROJECTDASHBOARD.methods_by_name['delete_version']._options = None
  _PROJECTDASHBOARD.methods_by_name['delete_version']._serialized_options = b'\202\323\344\223\002J*H/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}'
  _PROJECTDASHBOARD.methods_by_name['revert_version']._options = None
  _PROJECTDASHBOARD.methods_by_name['revert_version']._serialized_options = b'\202\323\344\223\002Q\"O/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}/revert'
  _PROJECTDASHBOARD.methods_by_name['get_version']._options = None
  _PROJECTDASHBOARD.methods_by_name['get_version']._serialized_options = b'\202\323\344\223\002J\022H/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}'
  _PROJECTDASHBOARD.methods_by_name['list_versions']._options = None
  _PROJECTDASHBOARD.methods_by_name['list_versions']._serialized_options = b'\202\323\344\223\002\213\001\022?/dashboard/v1/project-dashboard/{project_dashboard_id}/versionsZH\"F/dashboard/v1/project-dashboard/{project_dashboard_id}/versions/search'
  _PROJECTDASHBOARD.methods_by_name['list']._options = None
  _PROJECTDASHBOARD.methods_by_name['list']._serialized_options = b'\202\323\344\223\002M\022 /dashboard/v1/project-dashboardsZ)\"\'/dashboard/v1/project-dashboards/search'
  _PROJECTDASHBOARD.methods_by_name['stat']._options = None
  _PROJECTDASHBOARD.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\'\"%/dashboard/v1/project-dashboards/stat'
  _PROJECTDASHBOARDDATERANGE._serialized_start=203
  _PROJECTDASHBOARDDATERANGE._serialized_end=247
  _PROJECTDASHBOARDCURRENCY._serialized_start=249
  _PROJECTDASHBOARDCURRENCY._serialized_end=292
  _PROJECTDASHBOARDSETTINGS._serialized_start=295
  _PROJECTDASHBOARDSETTINGS._serialized_end=466
  _CREATEPROJECTDASHBOARDREQUEST._serialized_start=469
  _CREATEPROJECTDASHBOARDREQUEST._serialized_end=1000
  _CREATEPROJECTDASHBOARDREQUEST_VIEWERS._serialized_start=948
  _CREATEPROJECTDASHBOARDREQUEST_VIEWERS._serialized_end=1000
  _UPDATEPROJECTDASHBOARDREQUEST._serialized_start=1003
  _UPDATEPROJECTDASHBOARDREQUEST._serialized_end=1407
  _PROJECTDASHBOARDREQUEST._serialized_start=1409
  _PROJECTDASHBOARDREQUEST._serialized_end=1483
  _GETPROJECTDASHBOARDREQUEST._serialized_start=1485
  _GETPROJECTDASHBOARDREQUEST._serialized_end=1576
  _PROJECTDASHBOARDVERSIONREQUEST._serialized_start=1578
  _PROJECTDASHBOARDVERSIONREQUEST._serialized_end=1676
  _GETPROJECTDASHBOARDVERSIONREQUEST._serialized_start=1678
  _GETPROJECTDASHBOARDVERSIONREQUEST._serialized_end=1793
  _PROJECTDASHBOARDVERSIONQUERY._serialized_start=1796
  _PROJECTDASHBOARDVERSIONQUERY._serialized_end=1936
  _PROJECTDASHBOARDQUERY._serialized_start=1939
  _PROJECTDASHBOARDQUERY._serialized_end=2235
  _PROJECTDASHBOARDQUERY_VIEWERS._serialized_start=948
  _PROJECTDASHBOARDQUERY_VIEWERS._serialized_end=1000
  _PROJECTDASHBOARDINFO._serialized_start=2238
  _PROJECTDASHBOARDINFO._serialized_end=2855
  _PROJECTDASHBOARDINFO_VIEWERS._serialized_start=948
  _PROJECTDASHBOARDINFO_VIEWERS._serialized_end=1000
  _PROJECTDASHBOARDSINFO._serialized_start=2857
  _PROJECTDASHBOARDSINFO._serialized_end=2967
  _PROJECTDASHBOARDSTATQUERY._serialized_start=2969
  _PROJECTDASHBOARDSTATQUERY._serialized_end=3069
  _PROJECTDASHBOARDVERSIONINFO._serialized_start=3072
  _PROJECTDASHBOARDVERSIONINFO._serialized_end=3430
  _PROJECTDASHBOARDVERSIONSINFO._serialized_start=3432
  _PROJECTDASHBOARDVERSIONSINFO._serialized_end=3556
  _PROJECTDASHBOARD._serialized_start=3559
  _PROJECTDASHBOARD._serialized_end=5472
# @@protoc_insertion_point(module_scope)
