# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/monitoring/v1/metric.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\"M\n\rMetricRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\"\xb7\x01\n\x11MetricDataRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12-\n\x0cmetric_query\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06metric\x18\x03 \x01(\t\x12\r\n\x05start\x18\n \x01(\t\x12\x0b\n\x03\x65nd\x18\x0b \x01(\t\x12\x0e\n\x06period\x18\x0c \x01(\x05\x12\x0c\n\x04stat\x18\r \x01(\t\x12\x11\n\tdomain_id\x18\x14 \x01(\t\"\x8c\x01\n\nMetricInfo\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12%\n\x04unit\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12-\n\x0cmetric_query\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x8f\x01\n\x0bMetricsInfo\x12\x37\n\x07metrics\x18\x01 \x03(\x0b\x32&.spaceone.api.monitoring.v1.MetricInfo\x12\x34\n\x13\x61vailable_resources\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"x\n\x0eMetricDataInfo\x12*\n\x06labels\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\'\n\x06values\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x03 \x01(\t2\xcb\x02\n\x06Metric\x12\x97\x01\n\x04list\x12).spaceone.api.monitoring.v1.MetricRequest\x1a\'.spaceone.api.monitoring.v1.MetricsInfo\";\x82\xd3\xe4\x93\x02\x35\x12\x33/monitoring/v1/data-source/{data_source_id}/metrics\x12\xa6\x01\n\x08get_data\x12-.spaceone.api.monitoring.v1.MetricDataRequest\x1a*.spaceone.api.monitoring.v1.MetricDataInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/monitoring/v1/data-source/{data_source_id}/metric-datab\x06proto3')



_METRICREQUEST = DESCRIPTOR.message_types_by_name['MetricRequest']
_METRICDATAREQUEST = DESCRIPTOR.message_types_by_name['MetricDataRequest']
_METRICINFO = DESCRIPTOR.message_types_by_name['MetricInfo']
_METRICSINFO = DESCRIPTOR.message_types_by_name['MetricsInfo']
_METRICDATAINFO = DESCRIPTOR.message_types_by_name['MetricDataInfo']
MetricRequest = _reflection.GeneratedProtocolMessageType('MetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _METRICREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MetricRequest)
  })
_sym_db.RegisterMessage(MetricRequest)

MetricDataRequest = _reflection.GeneratedProtocolMessageType('MetricDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _METRICDATAREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MetricDataRequest)
  })
_sym_db.RegisterMessage(MetricDataRequest)

MetricInfo = _reflection.GeneratedProtocolMessageType('MetricInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICINFO,
  '__module__' : 'spaceone.api.monitoring.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MetricInfo)
  })
_sym_db.RegisterMessage(MetricInfo)

MetricsInfo = _reflection.GeneratedProtocolMessageType('MetricsInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICSINFO,
  '__module__' : 'spaceone.api.monitoring.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MetricsInfo)
  })
_sym_db.RegisterMessage(MetricsInfo)

MetricDataInfo = _reflection.GeneratedProtocolMessageType('MetricDataInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICDATAINFO,
  '__module__' : 'spaceone.api.monitoring.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MetricDataInfo)
  })
_sym_db.RegisterMessage(MetricDataInfo)

_METRIC = DESCRIPTOR.services_by_name['Metric']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _METRIC.methods_by_name['list']._options = None
  _METRIC.methods_by_name['list']._serialized_options = b'\202\323\344\223\0025\0223/monitoring/v1/data-source/{data_source_id}/metrics'
  _METRIC.methods_by_name['get_data']._options = None
  _METRIC.methods_by_name['get_data']._serialized_options = b'\202\323\344\223\0029\0227/monitoring/v1/data-source/{data_source_id}/metric-data'
  _METRICREQUEST._serialized_start=131
  _METRICREQUEST._serialized_end=208
  _METRICDATAREQUEST._serialized_start=211
  _METRICDATAREQUEST._serialized_end=394
  _METRICINFO._serialized_start=397
  _METRICINFO._serialized_end=537
  _METRICSINFO._serialized_start=540
  _METRICSINFO._serialized_end=683
  _METRICDATAINFO._serialized_start=685
  _METRICDATAINFO._serialized_end=805
  _METRIC._serialized_start=808
  _METRIC._serialized_end=1139
# @@protoc_insertion_point(module_scope)
