# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/savings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/inventory/v1/savings.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"C\n\x15GetPlInventoryRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x17\n\x0fpl_inventory_id\x18\x02 \x01(\t\"\x81\x02\n\x0fPlInventoryInfo\x12\x17\n\x0fpl_inventory_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x11\n\tsale_type\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\t\x12%\n\x04\x64\x61ta\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\"Q\n\x10PlInventoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"d\n\x10PlInventorysInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.inventory.v1.PlInventoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"_\n\x14PlInventoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"I\n\x19GetPlSavingsDetailRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11savings_detail_id\x18\x02 \x01(\t\"\x8a\x02\n\x13PlSavingsDetailInfo\x12\x19\n\x11savings_detail_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x11\n\tsale_type\x18\x07 \x01(\t\x12\x10\n\x08\x66or_date\x18\x08 \x01(\t\x12%\n\x04info\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\"U\n\x14PlSavingsDetailQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"l\n\x14PlSavingsDetailsInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.inventory.v1.PlSavingsDetailInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"c\n\x18PlSavingsDetailStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"<\n\x13GetPlSummaryRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nsummary_id\x18\x02 \x01(\t\"\xc6\x01\n\rPlSummaryInfo\x12\x12\n\nsummary_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x11\n\tsale_type\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12%\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_at\x18\x08 \x01(\t\"\xe2\x01\n\x0ePlSummaryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11savings_detail_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\x11\n\tsale_type\x18\x08 \x01(\t\x12\x10\n\x08\x66or_date\x18\t \x01(\t\"a\n\x0fPlSummariesInfo\x12\x39\n\x07results\x18\x01 \x03(\x0b\x32(.spaceone.api.inventory.v1.PlSummaryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"]\n\x12PlSummaryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa5\x0b\n\x07Savings\x12\xa0\x01\n\x10get_pl_inventory\x12\x30.spaceone.api.inventory.v1.GetPlInventoryRequest\x1a*.spaceone.api.inventory.v1.PlInventoryInfo\".\x82\xd3\xe4\x93\x02(\"&/inventory/v1/savings/pl-inventory/get\x12\x9e\x01\n\x11list_pl_inventory\x12+.spaceone.api.inventory.v1.PlInventoryQuery\x1a+.spaceone.api.inventory.v1.PlInventorysInfo\"/\x82\xd3\xe4\x93\x02)\"\'/inventory/v1/savings/pl-inventory/list\x12\x8e\x01\n\x11stat_pl_inventory\x12/.spaceone.api.inventory.v1.PlInventoryStatQuery\x1a\x17.google.protobuf.Struct\"/\x82\xd3\xe4\x93\x02)\"\'/inventory/v1/savings/pl-inventory/stat\x12\xb2\x01\n\x15get_pl_savings_detail\x12\x34.spaceone.api.inventory.v1.GetPlSavingsDetailRequest\x1a..spaceone.api.inventory.v1.PlSavingsDetailInfo\"3\x82\xd3\xe4\x93\x02-\"+/inventory/v1/savings/pl-savings-detail/get\x12\xb0\x01\n\x16list_pl_savings_detail\x12/.spaceone.api.inventory.v1.PlSavingsDetailQuery\x1a/.spaceone.api.inventory.v1.PlSavingsDetailsInfo\"4\x82\xd3\xe4\x93\x02.\",/inventory/v1/savings/pl-savings-detail/list\x12\x9c\x01\n\x16stat_pl_savings_detail\x12\x33.spaceone.api.inventory.v1.PlSavingsDetailStatQuery\x1a\x17.google.protobuf.Struct\"4\x82\xd3\xe4\x93\x02.\",/inventory/v1/savings/pl-savings-detail/stat\x12\x98\x01\n\x0eget_pl_summary\x12..spaceone.api.inventory.v1.GetPlSummaryRequest\x1a(.spaceone.api.inventory.v1.PlSummaryInfo\",\x82\xd3\xe4\x93\x02&\"$/inventory/v1/savings/pl-summary/get\x12\x97\x01\n\x0flist_pl_summary\x12).spaceone.api.inventory.v1.PlSummaryQuery\x1a*.spaceone.api.inventory.v1.PlSummariesInfo\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/savings/pl-summary/list\x12\x88\x01\n\x0fstat_pl_summary\x12-.spaceone.api.inventory.v1.PlSummaryStatQuery\x1a\x17.google.protobuf.Struct\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/savings/pl-summary/statb\x06proto3')



_GETPLINVENTORYREQUEST = DESCRIPTOR.message_types_by_name['GetPlInventoryRequest']
_PLINVENTORYINFO = DESCRIPTOR.message_types_by_name['PlInventoryInfo']
_PLINVENTORYQUERY = DESCRIPTOR.message_types_by_name['PlInventoryQuery']
_PLINVENTORYSINFO = DESCRIPTOR.message_types_by_name['PlInventorysInfo']
_PLINVENTORYSTATQUERY = DESCRIPTOR.message_types_by_name['PlInventoryStatQuery']
_GETPLSAVINGSDETAILREQUEST = DESCRIPTOR.message_types_by_name['GetPlSavingsDetailRequest']
_PLSAVINGSDETAILINFO = DESCRIPTOR.message_types_by_name['PlSavingsDetailInfo']
_PLSAVINGSDETAILQUERY = DESCRIPTOR.message_types_by_name['PlSavingsDetailQuery']
_PLSAVINGSDETAILSINFO = DESCRIPTOR.message_types_by_name['PlSavingsDetailsInfo']
_PLSAVINGSDETAILSTATQUERY = DESCRIPTOR.message_types_by_name['PlSavingsDetailStatQuery']
_GETPLSUMMARYREQUEST = DESCRIPTOR.message_types_by_name['GetPlSummaryRequest']
_PLSUMMARYINFO = DESCRIPTOR.message_types_by_name['PlSummaryInfo']
_PLSUMMARYQUERY = DESCRIPTOR.message_types_by_name['PlSummaryQuery']
_PLSUMMARIESINFO = DESCRIPTOR.message_types_by_name['PlSummariesInfo']
_PLSUMMARYSTATQUERY = DESCRIPTOR.message_types_by_name['PlSummaryStatQuery']
GetPlInventoryRequest = _reflection.GeneratedProtocolMessageType('GetPlInventoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLINVENTORYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetPlInventoryRequest)
  })
_sym_db.RegisterMessage(GetPlInventoryRequest)

PlInventoryInfo = _reflection.GeneratedProtocolMessageType('PlInventoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLINVENTORYINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlInventoryInfo)
  })
_sym_db.RegisterMessage(PlInventoryInfo)

PlInventoryQuery = _reflection.GeneratedProtocolMessageType('PlInventoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLINVENTORYQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlInventoryQuery)
  })
_sym_db.RegisterMessage(PlInventoryQuery)

PlInventorysInfo = _reflection.GeneratedProtocolMessageType('PlInventorysInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLINVENTORYSINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlInventorysInfo)
  })
_sym_db.RegisterMessage(PlInventorysInfo)

PlInventoryStatQuery = _reflection.GeneratedProtocolMessageType('PlInventoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLINVENTORYSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlInventoryStatQuery)
  })
_sym_db.RegisterMessage(PlInventoryStatQuery)

GetPlSavingsDetailRequest = _reflection.GeneratedProtocolMessageType('GetPlSavingsDetailRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLSAVINGSDETAILREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetPlSavingsDetailRequest)
  })
_sym_db.RegisterMessage(GetPlSavingsDetailRequest)

PlSavingsDetailInfo = _reflection.GeneratedProtocolMessageType('PlSavingsDetailInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLSAVINGSDETAILINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSavingsDetailInfo)
  })
_sym_db.RegisterMessage(PlSavingsDetailInfo)

PlSavingsDetailQuery = _reflection.GeneratedProtocolMessageType('PlSavingsDetailQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLSAVINGSDETAILQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSavingsDetailQuery)
  })
_sym_db.RegisterMessage(PlSavingsDetailQuery)

PlSavingsDetailsInfo = _reflection.GeneratedProtocolMessageType('PlSavingsDetailsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLSAVINGSDETAILSINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSavingsDetailsInfo)
  })
_sym_db.RegisterMessage(PlSavingsDetailsInfo)

PlSavingsDetailStatQuery = _reflection.GeneratedProtocolMessageType('PlSavingsDetailStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLSAVINGSDETAILSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSavingsDetailStatQuery)
  })
_sym_db.RegisterMessage(PlSavingsDetailStatQuery)

GetPlSummaryRequest = _reflection.GeneratedProtocolMessageType('GetPlSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLSUMMARYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetPlSummaryRequest)
  })
_sym_db.RegisterMessage(GetPlSummaryRequest)

PlSummaryInfo = _reflection.GeneratedProtocolMessageType('PlSummaryInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLSUMMARYINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSummaryInfo)
  })
_sym_db.RegisterMessage(PlSummaryInfo)

PlSummaryQuery = _reflection.GeneratedProtocolMessageType('PlSummaryQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLSUMMARYQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSummaryQuery)
  })
_sym_db.RegisterMessage(PlSummaryQuery)

PlSummariesInfo = _reflection.GeneratedProtocolMessageType('PlSummariesInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLSUMMARIESINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSummariesInfo)
  })
_sym_db.RegisterMessage(PlSummariesInfo)

PlSummaryStatQuery = _reflection.GeneratedProtocolMessageType('PlSummaryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLSUMMARYSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSummaryStatQuery)
  })
_sym_db.RegisterMessage(PlSummaryStatQuery)

_SAVINGS = DESCRIPTOR.services_by_name['Savings']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SAVINGS.methods_by_name['get_pl_inventory']._options = None
  _SAVINGS.methods_by_name['get_pl_inventory']._serialized_options = b'\202\323\344\223\002(\"&/inventory/v1/savings/pl-inventory/get'
  _SAVINGS.methods_by_name['list_pl_inventory']._options = None
  _SAVINGS.methods_by_name['list_pl_inventory']._serialized_options = b'\202\323\344\223\002)\"\'/inventory/v1/savings/pl-inventory/list'
  _SAVINGS.methods_by_name['stat_pl_inventory']._options = None
  _SAVINGS.methods_by_name['stat_pl_inventory']._serialized_options = b'\202\323\344\223\002)\"\'/inventory/v1/savings/pl-inventory/stat'
  _SAVINGS.methods_by_name['get_pl_savings_detail']._options = None
  _SAVINGS.methods_by_name['get_pl_savings_detail']._serialized_options = b'\202\323\344\223\002-\"+/inventory/v1/savings/pl-savings-detail/get'
  _SAVINGS.methods_by_name['list_pl_savings_detail']._options = None
  _SAVINGS.methods_by_name['list_pl_savings_detail']._serialized_options = b'\202\323\344\223\002.\",/inventory/v1/savings/pl-savings-detail/list'
  _SAVINGS.methods_by_name['stat_pl_savings_detail']._options = None
  _SAVINGS.methods_by_name['stat_pl_savings_detail']._serialized_options = b'\202\323\344\223\002.\",/inventory/v1/savings/pl-savings-detail/stat'
  _SAVINGS.methods_by_name['get_pl_summary']._options = None
  _SAVINGS.methods_by_name['get_pl_summary']._serialized_options = b'\202\323\344\223\002&\"$/inventory/v1/savings/pl-summary/get'
  _SAVINGS.methods_by_name['list_pl_summary']._options = None
  _SAVINGS.methods_by_name['list_pl_summary']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/savings/pl-summary/list'
  _SAVINGS.methods_by_name['stat_pl_summary']._options = None
  _SAVINGS.methods_by_name['stat_pl_summary']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/savings/pl-summary/stat'
  _GETPLINVENTORYREQUEST._serialized_start=193
  _GETPLINVENTORYREQUEST._serialized_end=260
  _PLINVENTORYINFO._serialized_start=263
  _PLINVENTORYINFO._serialized_end=520
  _PLINVENTORYQUERY._serialized_start=522
  _PLINVENTORYQUERY._serialized_end=603
  _PLINVENTORYSINFO._serialized_start=605
  _PLINVENTORYSINFO._serialized_end=705
  _PLINVENTORYSTATQUERY._serialized_start=707
  _PLINVENTORYSTATQUERY._serialized_end=802
  _GETPLSAVINGSDETAILREQUEST._serialized_start=804
  _GETPLSAVINGSDETAILREQUEST._serialized_end=877
  _PLSAVINGSDETAILINFO._serialized_start=880
  _PLSAVINGSDETAILINFO._serialized_end=1146
  _PLSAVINGSDETAILQUERY._serialized_start=1148
  _PLSAVINGSDETAILQUERY._serialized_end=1233
  _PLSAVINGSDETAILSINFO._serialized_start=1235
  _PLSAVINGSDETAILSINFO._serialized_end=1343
  _PLSAVINGSDETAILSTATQUERY._serialized_start=1345
  _PLSAVINGSDETAILSTATQUERY._serialized_end=1444
  _GETPLSUMMARYREQUEST._serialized_start=1446
  _GETPLSUMMARYREQUEST._serialized_end=1506
  _PLSUMMARYINFO._serialized_start=1509
  _PLSUMMARYINFO._serialized_end=1707
  _PLSUMMARYQUERY._serialized_start=1710
  _PLSUMMARYQUERY._serialized_end=1936
  _PLSUMMARIESINFO._serialized_start=1938
  _PLSUMMARIESINFO._serialized_end=2035
  _PLSUMMARYSTATQUERY._serialized_start=2037
  _PLSUMMARYSTATQUERY._serialized_end=2130
  _SAVINGS._serialized_start=2133
  _SAVINGS._serialized_end=3578
# @@protoc_insertion_point(module_scope)
