# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/resource_name_meta.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5spaceone/api/provisioning/v1/resource_name_meta.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a spaceone/api/core/v1/query.proto\"\xf7\x01\n\x14ResourceNameMetaInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x0c\n\x04\x61\x62\x62r\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x15\n\rresource_type\x18\x06 \x01(\t\x12\x0c\n\x04rank\x18\x07 \x01(\t\x12\x0c\n\x04regx\x18\x08 \x01(\t\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x12\n\ncreated_by\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\x12\x12\n\nupdated_by\x18\x0c \x01(\t\"q\n\x15ResourceNameMetasInfo\x12\x43\n\x07results\x18\x01 \x03(\x0b\x32\x32.spaceone.api.provisioning.v1.ResourceNameMetaInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"|\n\x15ResourceNameMetaQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t2\xf4\x01\n\x10ResourceNameMeta\x12\xdf\x01\n\x17get_resource_name_metas\x12\x33.spaceone.api.provisioning.v1.ResourceNameMetaQuery\x1a\x33.spaceone.api.provisioning.v1.ResourceNameMetasInfo\"Z\x82\xd3\xe4\x93\x02T\x12#/provisioning/v1/resource_name_metaZ-\"+/provisioning/v1/resource_name_metas/searchb\x06proto3')



_RESOURCENAMEMETAINFO = DESCRIPTOR.message_types_by_name['ResourceNameMetaInfo']
_RESOURCENAMEMETASINFO = DESCRIPTOR.message_types_by_name['ResourceNameMetasInfo']
_RESOURCENAMEMETAQUERY = DESCRIPTOR.message_types_by_name['ResourceNameMetaQuery']
ResourceNameMetaInfo = _reflection.GeneratedProtocolMessageType('ResourceNameMetaInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCENAMEMETAINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_name_meta_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceNameMetaInfo)
  })
_sym_db.RegisterMessage(ResourceNameMetaInfo)

ResourceNameMetasInfo = _reflection.GeneratedProtocolMessageType('ResourceNameMetasInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCENAMEMETASINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_name_meta_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceNameMetasInfo)
  })
_sym_db.RegisterMessage(ResourceNameMetasInfo)

ResourceNameMetaQuery = _reflection.GeneratedProtocolMessageType('ResourceNameMetaQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCENAMEMETAQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_name_meta_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceNameMetaQuery)
  })
_sym_db.RegisterMessage(ResourceNameMetaQuery)

_RESOURCENAMEMETA = DESCRIPTOR.services_by_name['ResourceNameMeta']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCENAMEMETA.methods_by_name['get_resource_name_metas']._options = None
  _RESOURCENAMEMETA.methods_by_name['get_resource_name_metas']._serialized_options = b'\202\323\344\223\002T\022#/provisioning/v1/resource_name_metaZ-\"+/provisioning/v1/resource_name_metas/search'
  _RESOURCENAMEMETAINFO._serialized_start=211
  _RESOURCENAMEMETAINFO._serialized_end=458
  _RESOURCENAMEMETASINFO._serialized_start=460
  _RESOURCENAMEMETASINFO._serialized_end=573
  _RESOURCENAMEMETAQUERY._serialized_start=575
  _RESOURCENAMEMETAQUERY._serialized_end=699
  _RESOURCENAMEMETA._serialized_start=702
  _RESOURCENAMEMETA._serialized_end=946
# @@protoc_insertion_point(module_scope)
