# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/unused_service_filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5spaceone/api/inventory/v1/unused_service_filter.proto\x12\x19spaceone.api.inventory.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a spaceone/api/core/v1/query.proto\"\xab\x02\n CreateUnusedServiceFilterRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tsub_title\x18\x02 \x01(\t\x12\x1d\n\x15required_weight_score\x18\x03 \x01(\x02\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x14\n\x0creplica_data\x18\x06 \x03(\t\x12\x13\n\x0bmatch_rules\x18\x07 \x03(\t\x12\x30\n\x0ftarget_resource\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x10target_condition\x18\t \x03(\x0b\x32*.spaceone.api.inventory.v1.TargetCondition\"\xcd\x02\n UpdateUnusedServiceFilterRequest\x12 \n\x18unused_service_filter_id\x18\x01 \x01(\t\x12\x11\n\tsub_title\x18\x02 \x01(\t\x12\x1d\n\x15required_weight_score\x18\x03 \x01(\x02\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x14\n\x0creplica_data\x18\x06 \x03(\t\x12\x13\n\x0bmatch_rules\x18\x07 \x03(\t\x12\x30\n\x0ftarget_resource\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x10target_condition\x18\t \x03(\x0b\x32*.spaceone.api.inventory.v1.TargetCondition\x12\r\n\x05title\x18\n \x01(\t\"T\n\x1dGetUnusedServiceFilterRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12 \n\x18unused_service_filter_id\x18\x02 \x01(\t\"Y\n\x18UnusedServiceFilterQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x94\x03\n\x17UnusedServiceFilterInfo\x12 \n\x18unused_service_filter_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\tsub_title\x18\x03 \x01(\t\x12\x1d\n\x15required_weight_score\x18\x04 \x01(\x02\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x30\n\x0ftarget_resource\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x10target_condition\x18\x08 \x03(\x0b\x32*.spaceone.api.inventory.v1.TargetCondition\x12\x14\n\x0creplica_data\x18\t \x03(\t\x12\x13\n\x0bmatch_rules\x18\n \x03(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x12\n\nupdated_by\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\r \x01(\t\x12\x12\n\nupdated_at\x18\x0e \x01(\t\"t\n\x18UnusedServiceFiltersInfo\x12\x43\n\x07results\x18\x01 \x03(\x0b\x32\x32.spaceone.api.inventory.v1.UnusedServiceFilterInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x97\x01\n\x15\x43onditionCloudService\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x0e\n\x06parser\x18\x03 \x01(\t\x12\x10\n\x08operator\x18\x04 \x01(\t\x12%\n\x05value\x18\x05 \x01(\x0b\x32\x16.google.protobuf.Value\x12\x0e\n\x06weight\x18\x06 \x01(\x05\"\xe2\x01\n\x0f\x43onditionMetric\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x0e\n\x06parser\x18\x03 \x01(\t\x12\x10\n\x08operator\x18\x04 \x01(\t\x12%\n\x05value\x18\x05 \x01(\x0b\x32\x16.google.protobuf.Value\x12\x0e\n\x06weight\x18\x06 \x01(\x05\x12\x13\n\x0bmetric_name\x18\x07 \x01(\t\x12\x0e\n\x06target\x18\x08 \x01(\t\x12\x1c\n\x14\x61ggregation_function\x18\t \x01(\t\x12\x0c\n\x04\x64\x61ys\x18\n \x01(\x05\"\xb2\x01\n\x0fTargetCondition\x12\x45\n\tcondition\x18\x01 \x01(\x0b\x32\x30.spaceone.api.inventory.v1.ConditionCloudServiceH\x00\x12\x46\n\x10\x63ondition_metric\x18\x02 \x01(\x0b\x32*.spaceone.api.inventory.v1.ConditionMetricH\x00\x42\x10\n\x0e\x63ondition_type2\xfa\x03\n\x13UnusedServiceFilter\x12{\n\x06\x63reate\x12;.spaceone.api.inventory.v1.CreateUnusedServiceFilterRequest\x1a\x32.spaceone.api.inventory.v1.UnusedServiceFilterInfo\"\x00\x12{\n\x06update\x12;.spaceone.api.inventory.v1.UpdateUnusedServiceFilterRequest\x1a\x32.spaceone.api.inventory.v1.UnusedServiceFilterInfo\"\x00\x12u\n\x03get\x12\x38.spaceone.api.inventory.v1.GetUnusedServiceFilterRequest\x1a\x32.spaceone.api.inventory.v1.UnusedServiceFilterInfo\"\x00\x12r\n\x04list\x12\x33.spaceone.api.inventory.v1.UnusedServiceFilterQuery\x1a\x33.spaceone.api.inventory.v1.UnusedServiceFiltersInfo\"\x00\x62\x06proto3')



_CREATEUNUSEDSERVICEFILTERREQUEST = DESCRIPTOR.message_types_by_name['CreateUnusedServiceFilterRequest']
_UPDATEUNUSEDSERVICEFILTERREQUEST = DESCRIPTOR.message_types_by_name['UpdateUnusedServiceFilterRequest']
_GETUNUSEDSERVICEFILTERREQUEST = DESCRIPTOR.message_types_by_name['GetUnusedServiceFilterRequest']
_UNUSEDSERVICEFILTERQUERY = DESCRIPTOR.message_types_by_name['UnusedServiceFilterQuery']
_UNUSEDSERVICEFILTERINFO = DESCRIPTOR.message_types_by_name['UnusedServiceFilterInfo']
_UNUSEDSERVICEFILTERSINFO = DESCRIPTOR.message_types_by_name['UnusedServiceFiltersInfo']
_CONDITIONCLOUDSERVICE = DESCRIPTOR.message_types_by_name['ConditionCloudService']
_CONDITIONMETRIC = DESCRIPTOR.message_types_by_name['ConditionMetric']
_TARGETCONDITION = DESCRIPTOR.message_types_by_name['TargetCondition']
CreateUnusedServiceFilterRequest = _reflection.GeneratedProtocolMessageType('CreateUnusedServiceFilterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUNUSEDSERVICEFILTERREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateUnusedServiceFilterRequest)
  })
_sym_db.RegisterMessage(CreateUnusedServiceFilterRequest)

UpdateUnusedServiceFilterRequest = _reflection.GeneratedProtocolMessageType('UpdateUnusedServiceFilterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUNUSEDSERVICEFILTERREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateUnusedServiceFilterRequest)
  })
_sym_db.RegisterMessage(UpdateUnusedServiceFilterRequest)

GetUnusedServiceFilterRequest = _reflection.GeneratedProtocolMessageType('GetUnusedServiceFilterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUNUSEDSERVICEFILTERREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetUnusedServiceFilterRequest)
  })
_sym_db.RegisterMessage(GetUnusedServiceFilterRequest)

UnusedServiceFilterQuery = _reflection.GeneratedProtocolMessageType('UnusedServiceFilterQuery', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICEFILTERQUERY,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceFilterQuery)
  })
_sym_db.RegisterMessage(UnusedServiceFilterQuery)

UnusedServiceFilterInfo = _reflection.GeneratedProtocolMessageType('UnusedServiceFilterInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICEFILTERINFO,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceFilterInfo)
  })
_sym_db.RegisterMessage(UnusedServiceFilterInfo)

UnusedServiceFiltersInfo = _reflection.GeneratedProtocolMessageType('UnusedServiceFiltersInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICEFILTERSINFO,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceFiltersInfo)
  })
_sym_db.RegisterMessage(UnusedServiceFiltersInfo)

ConditionCloudService = _reflection.GeneratedProtocolMessageType('ConditionCloudService', (_message.Message,), {
  'DESCRIPTOR' : _CONDITIONCLOUDSERVICE,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ConditionCloudService)
  })
_sym_db.RegisterMessage(ConditionCloudService)

ConditionMetric = _reflection.GeneratedProtocolMessageType('ConditionMetric', (_message.Message,), {
  'DESCRIPTOR' : _CONDITIONMETRIC,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ConditionMetric)
  })
_sym_db.RegisterMessage(ConditionMetric)

TargetCondition = _reflection.GeneratedProtocolMessageType('TargetCondition', (_message.Message,), {
  'DESCRIPTOR' : _TARGETCONDITION,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.TargetCondition)
  })
_sym_db.RegisterMessage(TargetCondition)

_UNUSEDSERVICEFILTER = DESCRIPTOR.services_by_name['UnusedServiceFilter']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CREATEUNUSEDSERVICEFILTERREQUEST._serialized_start=149
  _CREATEUNUSEDSERVICEFILTERREQUEST._serialized_end=448
  _UPDATEUNUSEDSERVICEFILTERREQUEST._serialized_start=451
  _UPDATEUNUSEDSERVICEFILTERREQUEST._serialized_end=784
  _GETUNUSEDSERVICEFILTERREQUEST._serialized_start=786
  _GETUNUSEDSERVICEFILTERREQUEST._serialized_end=870
  _UNUSEDSERVICEFILTERQUERY._serialized_start=872
  _UNUSEDSERVICEFILTERQUERY._serialized_end=961
  _UNUSEDSERVICEFILTERINFO._serialized_start=964
  _UNUSEDSERVICEFILTERINFO._serialized_end=1368
  _UNUSEDSERVICEFILTERSINFO._serialized_start=1370
  _UNUSEDSERVICEFILTERSINFO._serialized_end=1486
  _CONDITIONCLOUDSERVICE._serialized_start=1489
  _CONDITIONCLOUDSERVICE._serialized_end=1640
  _CONDITIONMETRIC._serialized_start=1643
  _CONDITIONMETRIC._serialized_end=1869
  _TARGETCONDITION._serialized_start=1872
  _TARGETCONDITION._serialized_end=2050
  _UNUSEDSERVICEFILTER._serialized_start=2053
  _UNUSEDSERVICEFILTER._serialized_end=2559
# @@protoc_insertion_point(module_scope)
