# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/public_dashboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4spaceone/api/cost_analysis/v1/public_dashboard.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"3\n\x15PublicDashboardPeriod\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\"\xb6\x03\n\x1c\x43reatePublicDashboardRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x02 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12[\n\x0bperiod_type\x18\x05 \x01(\x0e\x32\x46.spaceone.api.cost_analysis.v1.CreatePublicDashboardRequest.PeriodType\x12\x44\n\x06period\x18\x06 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.PublicDashboardPeriod\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"\xd3\x03\n\x1cUpdatePublicDashboardRequest\x12\x1b\n\x13public_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x03 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12[\n\x0bperiod_type\x18\x06 \x01(\x0e\x32\x46.spaceone.api.cost_analysis.v1.UpdatePublicDashboardRequest.PeriodType\x12\x44\n\x06period\x18\x07 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.PublicDashboardPeriod\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"H\n\x16PublicDashboardRequest\x12\x1b\n\x13public_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"Y\n\x19GetPublicDashboardRequest\x12\x1b\n\x13public_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x82\x02\n\x14PublicDashboardQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1b\n\x13public_dashboard_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12S\n\x0bperiod_type\x18\x04 \x01(\x0e\x32>.spaceone.api.cost_analysis.v1.PublicDashboardQuery.PeriodType\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"\xe9\x03\n\x13PublicDashboardInfo\x12\x1b\n\x13public_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x03 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12R\n\x0bperiod_type\x18\x06 \x01(\x0e\x32=.spaceone.api.cost_analysis.v1.PublicDashboardInfo.PeriodType\x12\x44\n\x06period\x18\x07 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.PublicDashboardPeriod\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nupdated_at\x18\x16 \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"p\n\x14PublicDashboardsInfo\x12\x43\n\x07results\x18\x01 \x03(\x0b\x32\x32.spaceone.api.cost_analysis.v1.PublicDashboardInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"c\n\x18PublicDashboardStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa7\x08\n\x0fPublicDashboard\x12\xa6\x01\n\x06\x63reate\x12;.spaceone.api.cost_analysis.v1.CreatePublicDashboardRequest\x1a\x32.spaceone.api.cost_analysis.v1.PublicDashboardInfo\"+\x82\xd3\xe4\x93\x02%\"#/cost-analysis/v1/public-dashboards\x12\xbb\x01\n\x06update\x12;.spaceone.api.cost_analysis.v1.UpdatePublicDashboardRequest\x1a\x32.spaceone.api.cost_analysis.v1.PublicDashboardInfo\"@\x82\xd3\xe4\x93\x02:\x1a\x38/cost-analysis/v1/public-dashboard/{public_dashboard_id}\x12\x99\x01\n\x06\x64\x65lete\x12\x35.spaceone.api.cost_analysis.v1.PublicDashboardRequest\x1a\x16.google.protobuf.Empty\"@\x82\xd3\xe4\x93\x02:*8/cost-analysis/v1/public-dashboard/{public_dashboard_id}\x12\xb5\x01\n\x03get\x12\x38.spaceone.api.cost_analysis.v1.GetPublicDashboardRequest\x1a\x32.spaceone.api.cost_analysis.v1.PublicDashboardInfo\"@\x82\xd3\xe4\x93\x02:\x12\x38/cost-analysis/v1/public-dashboard/{public_dashboard_id}\x12\xcb\x01\n\x04list\x12\x33.spaceone.api.cost_analysis.v1.PublicDashboardQuery\x1a\x33.spaceone.api.cost_analysis.v1.PublicDashboardsInfo\"Y\x82\xd3\xe4\x93\x02S\x12#/cost-analysis/v1/public-dashboardsZ,\"*/cost-analysis/v1/public-dashboards/search\x12\x8a\x01\n\x04stat\x12\x37.spaceone.api.cost_analysis.v1.PublicDashboardStatQuery\x1a\x17.google.protobuf.Struct\"0\x82\xd3\xe4\x93\x02*\"(/cost-analysis/v1/public-dashboards/statb\x06proto3')



_PUBLICDASHBOARDPERIOD = DESCRIPTOR.message_types_by_name['PublicDashboardPeriod']
_CREATEPUBLICDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['CreatePublicDashboardRequest']
_UPDATEPUBLICDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['UpdatePublicDashboardRequest']
_PUBLICDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['PublicDashboardRequest']
_GETPUBLICDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['GetPublicDashboardRequest']
_PUBLICDASHBOARDQUERY = DESCRIPTOR.message_types_by_name['PublicDashboardQuery']
_PUBLICDASHBOARDINFO = DESCRIPTOR.message_types_by_name['PublicDashboardInfo']
_PUBLICDASHBOARDSINFO = DESCRIPTOR.message_types_by_name['PublicDashboardsInfo']
_PUBLICDASHBOARDSTATQUERY = DESCRIPTOR.message_types_by_name['PublicDashboardStatQuery']
_CREATEPUBLICDASHBOARDREQUEST_PERIODTYPE = _CREATEPUBLICDASHBOARDREQUEST.enum_types_by_name['PeriodType']
_UPDATEPUBLICDASHBOARDREQUEST_PERIODTYPE = _UPDATEPUBLICDASHBOARDREQUEST.enum_types_by_name['PeriodType']
_PUBLICDASHBOARDQUERY_PERIODTYPE = _PUBLICDASHBOARDQUERY.enum_types_by_name['PeriodType']
_PUBLICDASHBOARDINFO_PERIODTYPE = _PUBLICDASHBOARDINFO.enum_types_by_name['PeriodType']
PublicDashboardPeriod = _reflection.GeneratedProtocolMessageType('PublicDashboardPeriod', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDPERIOD,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardPeriod)
  })
_sym_db.RegisterMessage(PublicDashboardPeriod)

CreatePublicDashboardRequest = _reflection.GeneratedProtocolMessageType('CreatePublicDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPUBLICDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreatePublicDashboardRequest)
  })
_sym_db.RegisterMessage(CreatePublicDashboardRequest)

UpdatePublicDashboardRequest = _reflection.GeneratedProtocolMessageType('UpdatePublicDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPUBLICDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdatePublicDashboardRequest)
  })
_sym_db.RegisterMessage(UpdatePublicDashboardRequest)

PublicDashboardRequest = _reflection.GeneratedProtocolMessageType('PublicDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardRequest)
  })
_sym_db.RegisterMessage(PublicDashboardRequest)

GetPublicDashboardRequest = _reflection.GeneratedProtocolMessageType('GetPublicDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetPublicDashboardRequest)
  })
_sym_db.RegisterMessage(GetPublicDashboardRequest)

PublicDashboardQuery = _reflection.GeneratedProtocolMessageType('PublicDashboardQuery', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardQuery)
  })
_sym_db.RegisterMessage(PublicDashboardQuery)

PublicDashboardInfo = _reflection.GeneratedProtocolMessageType('PublicDashboardInfo', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardInfo)
  })
_sym_db.RegisterMessage(PublicDashboardInfo)

PublicDashboardsInfo = _reflection.GeneratedProtocolMessageType('PublicDashboardsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardsInfo)
  })
_sym_db.RegisterMessage(PublicDashboardsInfo)

PublicDashboardStatQuery = _reflection.GeneratedProtocolMessageType('PublicDashboardStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardStatQuery)
  })
_sym_db.RegisterMessage(PublicDashboardStatQuery)

_PUBLICDASHBOARD = DESCRIPTOR.services_by_name['PublicDashboard']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBLICDASHBOARD.methods_by_name['create']._options = None
  _PUBLICDASHBOARD.methods_by_name['create']._serialized_options = b'\202\323\344\223\002%\"#/cost-analysis/v1/public-dashboards'
  _PUBLICDASHBOARD.methods_by_name['update']._options = None
  _PUBLICDASHBOARD.methods_by_name['update']._serialized_options = b'\202\323\344\223\002:\0328/cost-analysis/v1/public-dashboard/{public_dashboard_id}'
  _PUBLICDASHBOARD.methods_by_name['delete']._options = None
  _PUBLICDASHBOARD.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002:*8/cost-analysis/v1/public-dashboard/{public_dashboard_id}'
  _PUBLICDASHBOARD.methods_by_name['get']._options = None
  _PUBLICDASHBOARD.methods_by_name['get']._serialized_options = b'\202\323\344\223\002:\0228/cost-analysis/v1/public-dashboard/{public_dashboard_id}'
  _PUBLICDASHBOARD.methods_by_name['list']._options = None
  _PUBLICDASHBOARD.methods_by_name['list']._serialized_options = b'\202\323\344\223\002S\022#/cost-analysis/v1/public-dashboardsZ,\"*/cost-analysis/v1/public-dashboards/search'
  _PUBLICDASHBOARD.methods_by_name['stat']._options = None
  _PUBLICDASHBOARD.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002*\"(/cost-analysis/v1/public-dashboards/stat'
  _PUBLICDASHBOARDPERIOD._serialized_start=210
  _PUBLICDASHBOARDPERIOD._serialized_end=261
  _CREATEPUBLICDASHBOARDREQUEST._serialized_start=264
  _CREATEPUBLICDASHBOARDREQUEST._serialized_end=702
  _CREATEPUBLICDASHBOARDREQUEST_PERIODTYPE._serialized_start=659
  _CREATEPUBLICDASHBOARDREQUEST_PERIODTYPE._serialized_end=702
  _UPDATEPUBLICDASHBOARDREQUEST._serialized_start=705
  _UPDATEPUBLICDASHBOARDREQUEST._serialized_end=1172
  _UPDATEPUBLICDASHBOARDREQUEST_PERIODTYPE._serialized_start=659
  _UPDATEPUBLICDASHBOARDREQUEST_PERIODTYPE._serialized_end=702
  _PUBLICDASHBOARDREQUEST._serialized_start=1174
  _PUBLICDASHBOARDREQUEST._serialized_end=1246
  _GETPUBLICDASHBOARDREQUEST._serialized_start=1248
  _GETPUBLICDASHBOARDREQUEST._serialized_end=1337
  _PUBLICDASHBOARDQUERY._serialized_start=1340
  _PUBLICDASHBOARDQUERY._serialized_end=1598
  _PUBLICDASHBOARDQUERY_PERIODTYPE._serialized_start=659
  _PUBLICDASHBOARDQUERY_PERIODTYPE._serialized_end=702
  _PUBLICDASHBOARDINFO._serialized_start=1601
  _PUBLICDASHBOARDINFO._serialized_end=2090
  _PUBLICDASHBOARDINFO_PERIODTYPE._serialized_start=659
  _PUBLICDASHBOARDINFO_PERIODTYPE._serialized_end=702
  _PUBLICDASHBOARDSINFO._serialized_start=2092
  _PUBLICDASHBOARDSINFO._serialized_end=2204
  _PUBLICDASHBOARDSTATQUERY._serialized_start=2206
  _PUBLICDASHBOARDSTATQUERY._serialized_end=2305
  _PUBLICDASHBOARD._serialized_start=2308
  _PUBLICDASHBOARD._serialized_end=3371
# @@protoc_insertion_point(module_scope)
