# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/consumers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/provisioning/v1/consumers.proto\x12\x1cspaceone.api.provisioning.v12\x0b\n\tConsumersb\x06proto3')



_CONSUMERS = DESCRIPTOR.services_by_name['Consumers']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONSUMERS._serialized_start=78
  _CONSUMERS._serialized_end=89
# @@protoc_insertion_point(module_scope)
