# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/savings_recommendation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6spaceone/api/inventory/v1/savings_recommendation.proto\x12\x19spaceone.api.inventory.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"O\n\x1fGetSavingsRecommendationRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11recommendation_id\x18\x02 \x01(\t\"\xd6\x04\n\x19SavingsRecommendationInfo\x12\x19\n\x11recommendation_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x1b\n\x13recommendation_type\x18\x07 \x01(\t\x12\x0f\n\x07service\x18\x08 \x01(\t\x12\x15\n\rinstance_type\x18\t \x01(\t\x12\x1c\n\x14\x61nalysis_period_code\x18\n \x01(\t\x12\x1c\n\x14\x61nalysis_period_name\x18\x0b \x01(\t\x12\x17\n\x0fpurchase_period\x18\x0c \x01(\t\x12\x16\n\x0epayment_option\x18\r \x01(\t\x12\x1c\n\x14recommended_quantity\x18\x0e \x01(\x05\x12\x13\n\x0b\x66lexibility\x18\x0f \x01(\t\x12\x0e\n\x06region\x18\x10 \x01(\t\x12\x10\n\x08platform\x18\x11 \x01(\t\x12\x1a\n\x12savings_percentage\x18\x12 \x01(\x01\x12\x1b\n\x13month_ondemand_cost\x18\x13 \x01(\x01\x12\x1a\n\x12month_savings_cost\x18\x14 \x01(\x01\x12\x34\n\x13recommendation_info\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x16 \x01(\t\x12\x12\n\nupdated_at\x18\x17 \x01(\t\"\xba\x01\n\x1aSavingsRecommendationQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x1b\n\x13recommendation_type\x18\x06 \x01(\t\"x\n\x1aSavingsRecommendationsInfo\x12\x45\n\x07results\x18\x01 \x03(\x0b\x32\x34.spaceone.api.inventory.v1.SavingsRecommendationInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"i\n\x1eSavingsRecommendationStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xfd\x03\n\x15SavingsRecommendation\x12\xa9\x01\n\x03get\x12:.spaceone.api.inventory.v1.GetSavingsRecommendationRequest\x1a\x34.spaceone.api.inventory.v1.SavingsRecommendationInfo\"0\x82\xd3\xe4\x93\x02*\"(/inventory/v1/savings-recommendation/get\x12\xa7\x01\n\x04list\x12\x35.spaceone.api.inventory.v1.SavingsRecommendationQuery\x1a\x35.spaceone.api.inventory.v1.SavingsRecommendationsInfo\"1\x82\xd3\xe4\x93\x02+\")/inventory/v1/savings-recommendation/list\x12\x8d\x01\n\x04stat\x12\x39.spaceone.api.inventory.v1.SavingsRecommendationStatQuery\x1a\x17.google.protobuf.Struct\"1\x82\xd3\xe4\x93\x02+\")/inventory/v1/savings-recommendation/statb\x06proto3')



_GETSAVINGSRECOMMENDATIONREQUEST = DESCRIPTOR.message_types_by_name['GetSavingsRecommendationRequest']
_SAVINGSRECOMMENDATIONINFO = DESCRIPTOR.message_types_by_name['SavingsRecommendationInfo']
_SAVINGSRECOMMENDATIONQUERY = DESCRIPTOR.message_types_by_name['SavingsRecommendationQuery']
_SAVINGSRECOMMENDATIONSINFO = DESCRIPTOR.message_types_by_name['SavingsRecommendationsInfo']
_SAVINGSRECOMMENDATIONSTATQUERY = DESCRIPTOR.message_types_by_name['SavingsRecommendationStatQuery']
GetSavingsRecommendationRequest = _reflection.GeneratedProtocolMessageType('GetSavingsRecommendationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSAVINGSRECOMMENDATIONREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_recommendation_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetSavingsRecommendationRequest)
  })
_sym_db.RegisterMessage(GetSavingsRecommendationRequest)

SavingsRecommendationInfo = _reflection.GeneratedProtocolMessageType('SavingsRecommendationInfo', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSRECOMMENDATIONINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_recommendation_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsRecommendationInfo)
  })
_sym_db.RegisterMessage(SavingsRecommendationInfo)

SavingsRecommendationQuery = _reflection.GeneratedProtocolMessageType('SavingsRecommendationQuery', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSRECOMMENDATIONQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_recommendation_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsRecommendationQuery)
  })
_sym_db.RegisterMessage(SavingsRecommendationQuery)

SavingsRecommendationsInfo = _reflection.GeneratedProtocolMessageType('SavingsRecommendationsInfo', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSRECOMMENDATIONSINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_recommendation_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsRecommendationsInfo)
  })
_sym_db.RegisterMessage(SavingsRecommendationsInfo)

SavingsRecommendationStatQuery = _reflection.GeneratedProtocolMessageType('SavingsRecommendationStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSRECOMMENDATIONSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_recommendation_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsRecommendationStatQuery)
  })
_sym_db.RegisterMessage(SavingsRecommendationStatQuery)

_SAVINGSRECOMMENDATION = DESCRIPTOR.services_by_name['SavingsRecommendation']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SAVINGSRECOMMENDATION.methods_by_name['get']._options = None
  _SAVINGSRECOMMENDATION.methods_by_name['get']._serialized_options = b'\202\323\344\223\002*\"(/inventory/v1/savings-recommendation/get'
  _SAVINGSRECOMMENDATION.methods_by_name['list']._options = None
  _SAVINGSRECOMMENDATION.methods_by_name['list']._serialized_options = b'\202\323\344\223\002+\")/inventory/v1/savings-recommendation/list'
  _SAVINGSRECOMMENDATION.methods_by_name['stat']._options = None
  _SAVINGSRECOMMENDATION.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002+\")/inventory/v1/savings-recommendation/stat'
  _GETSAVINGSRECOMMENDATIONREQUEST._serialized_start=179
  _GETSAVINGSRECOMMENDATIONREQUEST._serialized_end=258
  _SAVINGSRECOMMENDATIONINFO._serialized_start=261
  _SAVINGSRECOMMENDATIONINFO._serialized_end=859
  _SAVINGSRECOMMENDATIONQUERY._serialized_start=862
  _SAVINGSRECOMMENDATIONQUERY._serialized_end=1048
  _SAVINGSRECOMMENDATIONSINFO._serialized_start=1050
  _SAVINGSRECOMMENDATIONSINFO._serialized_end=1170
  _SAVINGSRECOMMENDATIONSTATQUERY._serialized_start=1172
  _SAVINGSRECOMMENDATIONSTATQUERY._serialized_end=1277
  _SAVINGSRECOMMENDATION._serialized_start=1280
  _SAVINGSRECOMMENDATION._serialized_end=1789
# @@protoc_insertion_point(module_scope)
