# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/monitoring/v1/data_source.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xcc\x02\n\x14\x44\x61taSourcePluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12R\n\x0cupgrade_mode\x18\x07 \x01(\x0e\x32<.spaceone.api.monitoring.v1.DataSourcePluginInfo.UpgradeMode\x12\x13\n\tsecret_id\x18\x04 \x01(\tH\x00\x12\x12\n\x08provider\x18\x05 \x01(\tH\x00\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\x42\x0f\n\rplugin_secret\"\xaa\x01\n\x19RegisterDataSourceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x0bplugin_info\x18\x03 \x01(\x0b\x32\x30.spaceone.api.monitoring.v1.DataSourcePluginInfo\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x08 \x01(\t\"y\n\x17UpdateDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"\x91\x02\n\x1dUpdateDataSourcePluginRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12[\n\x0cupgrade_mode\x18\x04 \x01(\x0e\x32\x45.spaceone.api.monitoring.v1.UpdateDataSourcePluginRequest.UpgradeMode\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\">\n\x11\x44\x61taSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"O\n\x14GetDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xdc\x01\n\x0f\x44\x61taSourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x16\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x43\n\x0fmonitoring_type\x18\x05 \x01(\x0e\x32*.spaceone.api.monitoring.v1.MonitoringType\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"\xbe\x03\n\x0e\x44\x61taSourceInfo\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12?\n\x05state\x18\x03 \x01(\x0e\x32\x30.spaceone.api.monitoring.v1.DataSourceInfo.State\x12\x43\n\x0fmonitoring_type\x18\x04 \x01(\x0e\x32*.spaceone.api.monitoring.v1.MonitoringType\x12\x10\n\x08provider\x18\x05 \x01(\t\x12+\n\ncapability\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x0bplugin_info\x18\x07 \x01(\x0b\x32\x30.spaceone.api.monitoring.v1.DataSourcePluginInfo\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\t \x01(\t\x12\x12\n\ncreated_at\x18\n \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"c\n\x0f\x44\x61taSourcesInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.monitoring.v1.DataSourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"^\n\x13\x44\x61taSourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*/\n\x0eMonitoringType\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06METRIC\x10\x01\x12\x07\n\x03LOG\x10\x02\x32\xa9\x0c\n\nDataSource\x12\x92\x01\n\x08register\x12\x35.spaceone.api.monitoring.v1.RegisterDataSourceRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/monitoring/v1/data-sources\x12\x9e\x01\n\x06update\x12\x33.spaceone.api.monitoring.v1.UpdateDataSourceRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\"3\x82\xd3\xe4\x93\x02-\x1a+/monitoring/v1/data-source/{data_source_id}\x12\x9f\x01\n\x06\x65nable\x12-.spaceone.api.monitoring.v1.DataSourceRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\":\x82\xd3\xe4\x93\x02\x34\x1a\x32/monitoring/v1/data-source/{data_source_id}/enable\x12\xa1\x01\n\x07\x64isable\x12-.spaceone.api.monitoring.v1.DataSourceRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\";\x82\xd3\xe4\x93\x02\x35\x1a\x33/monitoring/v1/data-source/{data_source_id}/disable\x12\x88\x01\n\nderegister\x12-.spaceone.api.monitoring.v1.DataSourceRequest\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-*+/monitoring/v1/data-source/{data_source_id}\x12\xb2\x01\n\rupdate_plugin\x12\x39.spaceone.api.monitoring.v1.UpdateDataSourcePluginRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\":\x82\xd3\xe4\x93\x02\x34\x1a\x32/monitoring/v1/data-source/{data_source_id}/plugin\x12\x99\x01\n\rverify_plugin\x12-.spaceone.api.monitoring.v1.DataSourceRequest\x1a\x16.google.protobuf.Empty\"A\x82\xd3\xe4\x93\x02;\x1a\x39/monitoring/v1/data-source/{data_source_id}/plugin/verify\x12\x98\x01\n\x03get\x12\x30.spaceone.api.monitoring.v1.GetDataSourceRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\"3\x82\xd3\xe4\x93\x02-\x12+/monitoring/v1/data-source/{data_source_id}\x12\xab\x01\n\x04list\x12+.spaceone.api.monitoring.v1.DataSourceQuery\x1a+.spaceone.api.monitoring.v1.DataSourcesInfo\"I\x82\xd3\xe4\x93\x02\x43\x12\x1b/monitoring/v1/data-sourcesZ$\"\"/monitoring/v1/data-sources/search\x12z\n\x04stat\x12/.spaceone.api.monitoring.v1.DataSourceStatQuery\x1a\x17.google.protobuf.Struct\"(\x82\xd3\xe4\x93\x02\"\" /monitoring/v1/data-sources/statb\x06proto3')

_MONITORINGTYPE = DESCRIPTOR.enum_types_by_name['MonitoringType']
MonitoringType = enum_type_wrapper.EnumTypeWrapper(_MONITORINGTYPE)
NONE = 0
METRIC = 1
LOG = 2


_DATASOURCEPLUGININFO = DESCRIPTOR.message_types_by_name['DataSourcePluginInfo']
_REGISTERDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['RegisterDataSourceRequest']
_UPDATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourceRequest']
_UPDATEDATASOURCEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourcePluginRequest']
_DATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DataSourceRequest']
_GETDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetDataSourceRequest']
_DATASOURCEQUERY = DESCRIPTOR.message_types_by_name['DataSourceQuery']
_DATASOURCEINFO = DESCRIPTOR.message_types_by_name['DataSourceInfo']
_DATASOURCESINFO = DESCRIPTOR.message_types_by_name['DataSourcesInfo']
_DATASOURCESTATQUERY = DESCRIPTOR.message_types_by_name['DataSourceStatQuery']
_DATASOURCEPLUGININFO_UPGRADEMODE = _DATASOURCEPLUGININFO.enum_types_by_name['UpgradeMode']
_UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE = _UPDATEDATASOURCEPLUGINREQUEST.enum_types_by_name['UpgradeMode']
_DATASOURCEINFO_STATE = _DATASOURCEINFO.enum_types_by_name['State']
DataSourcePluginInfo = _reflection.GeneratedProtocolMessageType('DataSourcePluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEPLUGININFO,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourcePluginInfo)
  })
_sym_db.RegisterMessage(DataSourcePluginInfo)

RegisterDataSourceRequest = _reflection.GeneratedProtocolMessageType('RegisterDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.RegisterDataSourceRequest)
  })
_sym_db.RegisterMessage(RegisterDataSourceRequest)

UpdateDataSourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateDataSourceRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRequest)

UpdateDataSourcePluginRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourcePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEPLUGINREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateDataSourcePluginRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourcePluginRequest)

DataSourceRequest = _reflection.GeneratedProtocolMessageType('DataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourceRequest)
  })
_sym_db.RegisterMessage(DataSourceRequest)

GetDataSourceRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetDataSourceRequest)
  })
_sym_db.RegisterMessage(GetDataSourceRequest)

DataSourceQuery = _reflection.GeneratedProtocolMessageType('DataSourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourceQuery)
  })
_sym_db.RegisterMessage(DataSourceQuery)

DataSourceInfo = _reflection.GeneratedProtocolMessageType('DataSourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEINFO,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourceInfo)
  })
_sym_db.RegisterMessage(DataSourceInfo)

DataSourcesInfo = _reflection.GeneratedProtocolMessageType('DataSourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESINFO,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourcesInfo)
  })
_sym_db.RegisterMessage(DataSourcesInfo)

DataSourceStatQuery = _reflection.GeneratedProtocolMessageType('DataSourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourceStatQuery)
  })
_sym_db.RegisterMessage(DataSourceStatQuery)

_DATASOURCE = DESCRIPTOR.services_by_name['DataSource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATASOURCE.methods_by_name['register']._options = None
  _DATASOURCE.methods_by_name['register']._serialized_options = b'\202\323\344\223\002\035\"\033/monitoring/v1/data-sources'
  _DATASOURCE.methods_by_name['update']._options = None
  _DATASOURCE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002-\032+/monitoring/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['enable']._options = None
  _DATASOURCE.methods_by_name['enable']._serialized_options = b'\202\323\344\223\0024\0322/monitoring/v1/data-source/{data_source_id}/enable'
  _DATASOURCE.methods_by_name['disable']._options = None
  _DATASOURCE.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0025\0323/monitoring/v1/data-source/{data_source_id}/disable'
  _DATASOURCE.methods_by_name['deregister']._options = None
  _DATASOURCE.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\002-*+/monitoring/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['update_plugin']._options = None
  _DATASOURCE.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\0024\0322/monitoring/v1/data-source/{data_source_id}/plugin'
  _DATASOURCE.methods_by_name['verify_plugin']._options = None
  _DATASOURCE.methods_by_name['verify_plugin']._serialized_options = b'\202\323\344\223\002;\0329/monitoring/v1/data-source/{data_source_id}/plugin/verify'
  _DATASOURCE.methods_by_name['get']._options = None
  _DATASOURCE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002-\022+/monitoring/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['list']._options = None
  _DATASOURCE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002C\022\033/monitoring/v1/data-sourcesZ$\"\"/monitoring/v1/data-sources/search'
  _DATASOURCE.methods_by_name['stat']._options = None
  _DATASOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\"\" /monitoring/v1/data-sources/stat'
  _MONITORINGTYPE._serialized_start=2120
  _MONITORINGTYPE._serialized_end=2167
  _DATASOURCEPLUGININFO._serialized_start=200
  _DATASOURCEPLUGININFO._serialized_end=532
  _DATASOURCEPLUGININFO_UPGRADEMODE._serialized_start=470
  _DATASOURCEPLUGININFO_UPGRADEMODE._serialized_end=515
  _REGISTERDATASOURCEREQUEST._serialized_start=535
  _REGISTERDATASOURCEREQUEST._serialized_end=705
  _UPDATEDATASOURCEREQUEST._serialized_start=707
  _UPDATEDATASOURCEREQUEST._serialized_end=828
  _UPDATEDATASOURCEPLUGINREQUEST._serialized_start=831
  _UPDATEDATASOURCEPLUGINREQUEST._serialized_end=1104
  _UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE._serialized_start=470
  _UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE._serialized_end=515
  _DATASOURCEREQUEST._serialized_start=1106
  _DATASOURCEREQUEST._serialized_end=1168
  _GETDATASOURCEREQUEST._serialized_start=1170
  _GETDATASOURCEREQUEST._serialized_end=1249
  _DATASOURCEQUERY._serialized_start=1252
  _DATASOURCEQUERY._serialized_end=1472
  _DATASOURCEINFO._serialized_start=1475
  _DATASOURCEINFO._serialized_end=1921
  _DATASOURCEINFO_STATE._serialized_start=1877
  _DATASOURCEINFO_STATE._serialized_end=1921
  _DATASOURCESINFO._serialized_start=1923
  _DATASOURCESINFO._serialized_end=2022
  _DATASOURCESTATQUERY._serialized_start=2024
  _DATASOURCESTATQUERY._serialized_end=2118
  _DATASOURCE._serialized_start=2170
  _DATASOURCE._serialized_end=3747
# @@protoc_insertion_point(module_scope)
