# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/project_alert_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.monitoring.v1 import escalation_policy_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5spaceone/api/monitoring/v1/project_alert_config.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a\x32spaceone/api/monitoring/v1/escalation_policy.proto\"\xaa\x02\n\x0c\x41lertOptions\x12T\n\x14notification_urgency\x18\x01 \x01(\x0e\x32\x36.spaceone.api.monitoring.v1.AlertOptions.UrgencyOption\x12N\n\rrecovery_mode\x18\x02 \x01(\x0e\x32\x37.spaceone.api.monitoring.v1.AlertOptions.RecoveryOption\"9\n\rUrgencyOption\x12\x10\n\x0cURGENCY_NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\r\n\tHIGH_ONLY\x10\x02\"9\n\x0eRecoveryOption\x12\x11\n\rRECOVERY_NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\n\n\x06MANUAL\x10\x02\"\xa1\x01\n\x1f\x43reateProjectAlertConfigRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x1c\n\x14\x65scalation_policy_id\x18\x02 \x01(\t\x12\x39\n\x07options\x18\x03 \x01(\x0b\x32(.spaceone.api.monitoring.v1.AlertOptions\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xa1\x01\n\x1fUpdateProjectAlertConfigRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x1c\n\x14\x65scalation_policy_id\x18\x02 \x01(\t\x12\x39\n\x07options\x18\x03 \x01(\x0b\x32(.spaceone.api.monitoring.v1.AlertOptions\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"B\n\x19ProjectAlertConfigRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"S\n\x1cGetProjectAlertConfigRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x8a\x01\n\x17ProjectAlertConfigQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x1c\n\x14\x65scalation_policy_id\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xe0\x01\n\x16ProjectAlertConfigInfo\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x39\n\x07options\x18\x02 \x01(\x0b\x32(.spaceone.api.monitoring.v1.AlertOptions\x12P\n\x16\x65scalation_policy_info\x18\x03 \x01(\x0b\x32\x30.spaceone.api.monitoring.v1.EscalationPolicyInfo\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"s\n\x17ProjectAlertConfigsInfo\x12\x43\n\x07results\x18\x01 \x03(\x0b\x32\x32.spaceone.api.monitoring.v1.ProjectAlertConfigInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"f\n\x1bProjectAlertConfigStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xbd\x08\n\x12ProjectAlertConfig\x12\xa7\x01\n\x06\x63reate\x12;.spaceone.api.monitoring.v1.CreateProjectAlertConfigRequest\x1a\x32.spaceone.api.monitoring.v1.ProjectAlertConfigInfo\",\x82\xd3\xe4\x93\x02&\"$/monitoring/v1/project-alert-configs\x12\xc0\x01\n\x06update\x12;.spaceone.api.monitoring.v1.UpdateProjectAlertConfigRequest\x1a\x32.spaceone.api.monitoring.v1.ProjectAlertConfigInfo\"E\x82\xd3\xe4\x93\x02?\x1a=/monitoring/v1/project-alert-config/{project_alert_config_id}\x12\x9e\x01\n\x06\x64\x65lete\x12\x35.spaceone.api.monitoring.v1.ProjectAlertConfigRequest\x1a\x16.google.protobuf.Empty\"E\x82\xd3\xe4\x93\x02?*=/monitoring/v1/project-alert-config/{project_alert_config_id}\x12\xba\x01\n\x03get\x12\x38.spaceone.api.monitoring.v1.GetProjectAlertConfigRequest\x1a\x32.spaceone.api.monitoring.v1.ProjectAlertConfigInfo\"E\x82\xd3\xe4\x93\x02?\x12=/monitoring/v1/project-alert-config/{project_alert_config_id}\x12\xcd\x01\n\x04list\x12\x33.spaceone.api.monitoring.v1.ProjectAlertConfigQuery\x1a\x33.spaceone.api.monitoring.v1.ProjectAlertConfigsInfo\"[\x82\xd3\xe4\x93\x02U\x12$/monitoring/v1/project-alert-configsZ-\"+/monitoring/v1/project-alert-configs/search\x12\x8b\x01\n\x04stat\x12\x37.spaceone.api.monitoring.v1.ProjectAlertConfigStatQuery\x1a\x17.google.protobuf.Struct\"1\x82\xd3\xe4\x93\x02+\")/monitoring/v1/project-alert-configs/statb\x06proto3')



_ALERTOPTIONS = DESCRIPTOR.message_types_by_name['AlertOptions']
_CREATEPROJECTALERTCONFIGREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectAlertConfigRequest']
_UPDATEPROJECTALERTCONFIGREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectAlertConfigRequest']
_PROJECTALERTCONFIGREQUEST = DESCRIPTOR.message_types_by_name['ProjectAlertConfigRequest']
_GETPROJECTALERTCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetProjectAlertConfigRequest']
_PROJECTALERTCONFIGQUERY = DESCRIPTOR.message_types_by_name['ProjectAlertConfigQuery']
_PROJECTALERTCONFIGINFO = DESCRIPTOR.message_types_by_name['ProjectAlertConfigInfo']
_PROJECTALERTCONFIGSINFO = DESCRIPTOR.message_types_by_name['ProjectAlertConfigsInfo']
_PROJECTALERTCONFIGSTATQUERY = DESCRIPTOR.message_types_by_name['ProjectAlertConfigStatQuery']
_ALERTOPTIONS_URGENCYOPTION = _ALERTOPTIONS.enum_types_by_name['UrgencyOption']
_ALERTOPTIONS_RECOVERYOPTION = _ALERTOPTIONS.enum_types_by_name['RecoveryOption']
AlertOptions = _reflection.GeneratedProtocolMessageType('AlertOptions', (_message.Message,), {
  'DESCRIPTOR' : _ALERTOPTIONS,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertOptions)
  })
_sym_db.RegisterMessage(AlertOptions)

CreateProjectAlertConfigRequest = _reflection.GeneratedProtocolMessageType('CreateProjectAlertConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTALERTCONFIGREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateProjectAlertConfigRequest)
  })
_sym_db.RegisterMessage(CreateProjectAlertConfigRequest)

UpdateProjectAlertConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectAlertConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTALERTCONFIGREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateProjectAlertConfigRequest)
  })
_sym_db.RegisterMessage(UpdateProjectAlertConfigRequest)

ProjectAlertConfigRequest = _reflection.GeneratedProtocolMessageType('ProjectAlertConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTALERTCONFIGREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ProjectAlertConfigRequest)
  })
_sym_db.RegisterMessage(ProjectAlertConfigRequest)

GetProjectAlertConfigRequest = _reflection.GeneratedProtocolMessageType('GetProjectAlertConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTALERTCONFIGREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetProjectAlertConfigRequest)
  })
_sym_db.RegisterMessage(GetProjectAlertConfigRequest)

ProjectAlertConfigQuery = _reflection.GeneratedProtocolMessageType('ProjectAlertConfigQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTALERTCONFIGQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ProjectAlertConfigQuery)
  })
_sym_db.RegisterMessage(ProjectAlertConfigQuery)

ProjectAlertConfigInfo = _reflection.GeneratedProtocolMessageType('ProjectAlertConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTALERTCONFIGINFO,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ProjectAlertConfigInfo)
  })
_sym_db.RegisterMessage(ProjectAlertConfigInfo)

ProjectAlertConfigsInfo = _reflection.GeneratedProtocolMessageType('ProjectAlertConfigsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTALERTCONFIGSINFO,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ProjectAlertConfigsInfo)
  })
_sym_db.RegisterMessage(ProjectAlertConfigsInfo)

ProjectAlertConfigStatQuery = _reflection.GeneratedProtocolMessageType('ProjectAlertConfigStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTALERTCONFIGSTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ProjectAlertConfigStatQuery)
  })
_sym_db.RegisterMessage(ProjectAlertConfigStatQuery)

_PROJECTALERTCONFIG = DESCRIPTOR.services_by_name['ProjectAlertConfig']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECTALERTCONFIG.methods_by_name['create']._options = None
  _PROJECTALERTCONFIG.methods_by_name['create']._serialized_options = b'\202\323\344\223\002&\"$/monitoring/v1/project-alert-configs'
  _PROJECTALERTCONFIG.methods_by_name['update']._options = None
  _PROJECTALERTCONFIG.methods_by_name['update']._serialized_options = b'\202\323\344\223\002?\032=/monitoring/v1/project-alert-config/{project_alert_config_id}'
  _PROJECTALERTCONFIG.methods_by_name['delete']._options = None
  _PROJECTALERTCONFIG.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002?*=/monitoring/v1/project-alert-config/{project_alert_config_id}'
  _PROJECTALERTCONFIG.methods_by_name['get']._options = None
  _PROJECTALERTCONFIG.methods_by_name['get']._serialized_options = b'\202\323\344\223\002?\022=/monitoring/v1/project-alert-config/{project_alert_config_id}'
  _PROJECTALERTCONFIG.methods_by_name['list']._options = None
  _PROJECTALERTCONFIG.methods_by_name['list']._serialized_options = b'\202\323\344\223\002U\022$/monitoring/v1/project-alert-configsZ-\"+/monitoring/v1/project-alert-configs/search'
  _PROJECTALERTCONFIG.methods_by_name['stat']._options = None
  _PROJECTALERTCONFIG.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002+\")/monitoring/v1/project-alert-configs/stat'
  _ALERTOPTIONS._serialized_start=261
  _ALERTOPTIONS._serialized_end=559
  _ALERTOPTIONS_URGENCYOPTION._serialized_start=443
  _ALERTOPTIONS_URGENCYOPTION._serialized_end=500
  _ALERTOPTIONS_RECOVERYOPTION._serialized_start=502
  _ALERTOPTIONS_RECOVERYOPTION._serialized_end=559
  _CREATEPROJECTALERTCONFIGREQUEST._serialized_start=562
  _CREATEPROJECTALERTCONFIGREQUEST._serialized_end=723
  _UPDATEPROJECTALERTCONFIGREQUEST._serialized_start=726
  _UPDATEPROJECTALERTCONFIGREQUEST._serialized_end=887
  _PROJECTALERTCONFIGREQUEST._serialized_start=889
  _PROJECTALERTCONFIGREQUEST._serialized_end=955
  _GETPROJECTALERTCONFIGREQUEST._serialized_start=957
  _GETPROJECTALERTCONFIGREQUEST._serialized_end=1040
  _PROJECTALERTCONFIGQUERY._serialized_start=1043
  _PROJECTALERTCONFIGQUERY._serialized_end=1181
  _PROJECTALERTCONFIGINFO._serialized_start=1184
  _PROJECTALERTCONFIGINFO._serialized_end=1408
  _PROJECTALERTCONFIGSINFO._serialized_start=1410
  _PROJECTALERTCONFIGSINFO._serialized_end=1525
  _PROJECTALERTCONFIGSTATQUERY._serialized_start=1527
  _PROJECTALERTCONFIGSTATQUERY._serialized_end=1629
  _PROJECTALERTCONFIG._serialized_start=1632
  _PROJECTALERTCONFIG._serialized_end=2717
# @@protoc_insertion_point(module_scope)
