# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/provider.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/identity/v1/provider.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xf4\x01\n\x15\x43reateProviderRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x08template\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"\xf4\x01\n\x15UpdateProviderRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x08template\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"6\n\x0fProviderRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"G\n\x12GetProviderRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04only\x18\x02 \x03(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"n\n\rProviderQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xec\x01\n\x0cProviderInfo\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x08template\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x07 \x01(\t\"]\n\rProvidersInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.identity.v1.ProviderInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\\\n\x11ProviderStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xb3\x06\n\x08Provider\x12\x81\x01\n\x06\x63reate\x12/.spaceone.api.identity.v1.CreateProviderRequest\x1a&.spaceone.api.identity.v1.ProviderInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/identity/v1/providers\x12\x8e\x01\n\x06update\x12/.spaceone.api.identity.v1.UpdateProviderRequest\x1a&.spaceone.api.identity.v1.ProviderInfo\"+\x82\xd3\xe4\x93\x02%\x1a#/identity/v1/provider/{provider_id}\x12x\n\x06\x64\x65lete\x12).spaceone.api.identity.v1.ProviderRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%*#/identity/v1/provider/{provider_id}\x12\x88\x01\n\x03get\x12,.spaceone.api.identity.v1.GetProviderRequest\x1a&.spaceone.api.identity.v1.ProviderInfo\"+\x82\xd3\xe4\x93\x02%\x12#/identity/v1/provider/{provider_id}\x12\x99\x01\n\x04list\x12\'.spaceone.api.identity.v1.ProviderQuery\x1a\'.spaceone.api.identity.v1.ProvidersInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/identity/v1/providersZ\x1f\"\x1d/identity/v1/providers/search\x12q\n\x04stat\x12+.spaceone.api.identity.v1.ProviderStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/identity/v1/providers/statb\x06proto3')



_CREATEPROVIDERREQUEST = DESCRIPTOR.message_types_by_name['CreateProviderRequest']
_UPDATEPROVIDERREQUEST = DESCRIPTOR.message_types_by_name['UpdateProviderRequest']
_PROVIDERREQUEST = DESCRIPTOR.message_types_by_name['ProviderRequest']
_GETPROVIDERREQUEST = DESCRIPTOR.message_types_by_name['GetProviderRequest']
_PROVIDERQUERY = DESCRIPTOR.message_types_by_name['ProviderQuery']
_PROVIDERINFO = DESCRIPTOR.message_types_by_name['ProviderInfo']
_PROVIDERSINFO = DESCRIPTOR.message_types_by_name['ProvidersInfo']
_PROVIDERSTATQUERY = DESCRIPTOR.message_types_by_name['ProviderStatQuery']
CreateProviderRequest = _reflection.GeneratedProtocolMessageType('CreateProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROVIDERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateProviderRequest)
  })
_sym_db.RegisterMessage(CreateProviderRequest)

UpdateProviderRequest = _reflection.GeneratedProtocolMessageType('UpdateProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROVIDERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateProviderRequest)
  })
_sym_db.RegisterMessage(UpdateProviderRequest)

ProviderRequest = _reflection.GeneratedProtocolMessageType('ProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProviderRequest)
  })
_sym_db.RegisterMessage(ProviderRequest)

GetProviderRequest = _reflection.GeneratedProtocolMessageType('GetProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROVIDERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetProviderRequest)
  })
_sym_db.RegisterMessage(GetProviderRequest)

ProviderQuery = _reflection.GeneratedProtocolMessageType('ProviderQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERQUERY,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProviderQuery)
  })
_sym_db.RegisterMessage(ProviderQuery)

ProviderInfo = _reflection.GeneratedProtocolMessageType('ProviderInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERINFO,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProviderInfo)
  })
_sym_db.RegisterMessage(ProviderInfo)

ProvidersInfo = _reflection.GeneratedProtocolMessageType('ProvidersInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERSINFO,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProvidersInfo)
  })
_sym_db.RegisterMessage(ProvidersInfo)

ProviderStatQuery = _reflection.GeneratedProtocolMessageType('ProviderStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProviderStatQuery)
  })
_sym_db.RegisterMessage(ProviderStatQuery)

_PROVIDER = DESCRIPTOR.services_by_name['Provider']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROVIDER.methods_by_name['create']._options = None
  _PROVIDER.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\030\"\026/identity/v1/providers'
  _PROVIDER.methods_by_name['update']._options = None
  _PROVIDER.methods_by_name['update']._serialized_options = b'\202\323\344\223\002%\032#/identity/v1/provider/{provider_id}'
  _PROVIDER.methods_by_name['delete']._options = None
  _PROVIDER.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002%*#/identity/v1/provider/{provider_id}'
  _PROVIDER.methods_by_name['get']._options = None
  _PROVIDER.methods_by_name['get']._serialized_options = b'\202\323\344\223\002%\022#/identity/v1/provider/{provider_id}'
  _PROVIDER.methods_by_name['list']._options = None
  _PROVIDER.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/identity/v1/providersZ\037\"\035/identity/v1/providers/search'
  _PROVIDER.methods_by_name['stat']._options = None
  _PROVIDER.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/identity/v1/providers/stat'
  _CREATEPROVIDERREQUEST._serialized_start=193
  _CREATEPROVIDERREQUEST._serialized_end=437
  _UPDATEPROVIDERREQUEST._serialized_start=440
  _UPDATEPROVIDERREQUEST._serialized_end=684
  _PROVIDERREQUEST._serialized_start=686
  _PROVIDERREQUEST._serialized_end=740
  _GETPROVIDERREQUEST._serialized_start=742
  _GETPROVIDERREQUEST._serialized_end=813
  _PROVIDERQUERY._serialized_start=815
  _PROVIDERQUERY._serialized_end=925
  _PROVIDERINFO._serialized_start=928
  _PROVIDERINFO._serialized_end=1164
  _PROVIDERSINFO._serialized_start=1166
  _PROVIDERSINFO._serialized_end=1259
  _PROVIDERSTATQUERY._serialized_start=1261
  _PROVIDERSTATQUERY._serialized_end=1353
  _PROVIDER._serialized_start=1356
  _PROVIDER._serialized_end=2175
# @@protoc_insertion_point(module_scope)
