# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/repository/v1/plugin.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.repository.v1 import repository_pb2 as spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/repository/v1/plugin.proto\x12\x1aspaceone.api.repository.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a+spaceone/api/repository/v1/repository.proto\"\xa5\x03\n\x13\x43reatePluginRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cservice_type\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x45\n\rregistry_type\x18\x05 \x01(\x0e\x32..spaceone.api.repository.v1.PublicRegistryType\x12\x30\n\x0fregistry_config\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08template\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\r \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\"\xf4\x01\n\x13UpdatePluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12+\n\ncapability\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08template\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\r \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"5\n\rPluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"V\n\x17RepositoryPluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x15\n\rrepository_id\x18\x03 \x01(\t\"g\n\x1aGetRepositoryPluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x15\n\rrepository_id\x18\x03 \x01(\t\x12\x0c\n\x04only\x18\x04 \x03(\t\"\xdf\x02\n\x0bPluginQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tplugin_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12<\n\x05state\x18\x04 \x01(\x0e\x32-.spaceone.api.repository.v1.PluginQuery.State\x12\x14\n\x0cservice_type\x18\x05 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x15\n\rrepository_id\x18\x07 \x01(\t\x12\x11\n\tdomain_id\x18\x08 \x01(\t\x12\x45\n\rregistry_type\x18\t \x01(\x0e\x32..spaceone.api.repository.v1.PublicRegistryType\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\x9d\x05\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x14\n\x0cregistry_url\x18\x04 \x01(\t\x12;\n\x05state\x18\x05 \x01(\x0e\x32,.spaceone.api.repository.v1.PluginInfo.State\x12\x14\n\x0cservice_type\x18\x06 \x01(\t\x12\x10\n\x08provider\x18\x07 \x01(\t\x12\x45\n\rregistry_type\x18\x08 \x01(\x0e\x32..spaceone.api.repository.v1.PublicRegistryType\x12\x30\n\x0fregistry_config\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08template\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\r \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\x0frepository_info\x18\x15 \x01(\x0b\x32*.spaceone.api.repository.v1.RepositoryInfo\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"[\n\x0bPluginsInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.repository.v1.PluginInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"E\n\x0cVersionsInfo\x12\x0f\n\x07version\x18\x01 \x03(\t\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x0f\n\x07results\x18\x03 \x03(\t\"q\n\x0fPluginStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x15\n\rrepository_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t*\\\n\x12PublicRegistryType\x12\x16\n\x12NONE_REGISTRY_TYPE\x10\x00\x12\x0e\n\nDOCKER_HUB\x10\x01\x12\x12\n\x0e\x41WS_PUBLIC_ECR\x10\x02\x12\n\n\x06HARBOR\x10\x03\x32\x83\n\n\x06Plugin\x12\x83\x01\n\x08register\x12/.spaceone.api.repository.v1.CreatePluginRequest\x1a&.spaceone.api.repository.v1.PluginInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/repository/v1/plugins\x12\x8c\x01\n\x06update\x12/.spaceone.api.repository.v1.UpdatePluginRequest\x1a&.spaceone.api.repository.v1.PluginInfo\")\x82\xd3\xe4\x93\x02#\x1a!/repository/v1/plugin/{plugin_id}\x12z\n\nderegister\x12).spaceone.api.repository.v1.PluginRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/repository/v1/plugin/{plugin_id}\x12\x8d\x01\n\x06\x65nable\x12).spaceone.api.repository.v1.PluginRequest\x1a&.spaceone.api.repository.v1.PluginInfo\"0\x82\xd3\xe4\x93\x02*\x1a(/repository/v1/plugin/{plugin_id}/enable\x12\x8f\x01\n\x07\x64isable\x12).spaceone.api.repository.v1.PluginRequest\x1a&.spaceone.api.repository.v1.PluginInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/repository/v1/plugin/{plugin_id}/disable\x12\xa2\x01\n\x0cget_versions\x12\x33.spaceone.api.repository.v1.RepositoryPluginRequest\x1a(.spaceone.api.repository.v1.VersionsInfo\"3\x82\xd3\xe4\x93\x02-\x12+/repository/v1/plugins/{plugin_id}/versions\x12\x91\x01\n\x03get\x12\x36.spaceone.api.repository.v1.GetRepositoryPluginRequest\x1a&.spaceone.api.repository.v1.PluginInfo\"*\x82\xd3\xe4\x93\x02$\x12\"/repository/v1/plugins/{plugin_id}\x12\x99\x01\n\x04list\x12\'.spaceone.api.repository.v1.PluginQuery\x1a\'.spaceone.api.repository.v1.PluginsInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/repository/v1/pluginsZ\x1f\"\x1d/repository/v1/plugins/search\x12q\n\x04stat\x12+.spaceone.api.repository.v1.PluginStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/repository/v1/plugins/statb\x06proto3')

_PUBLICREGISTRYTYPE = DESCRIPTOR.enum_types_by_name['PublicRegistryType']
PublicRegistryType = enum_type_wrapper.EnumTypeWrapper(_PUBLICREGISTRYTYPE)
NONE_REGISTRY_TYPE = 0
DOCKER_HUB = 1
AWS_PUBLIC_ECR = 2
HARBOR = 3


_CREATEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['CreatePluginRequest']
_UPDATEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdatePluginRequest']
_PLUGINREQUEST = DESCRIPTOR.message_types_by_name['PluginRequest']
_REPOSITORYPLUGINREQUEST = DESCRIPTOR.message_types_by_name['RepositoryPluginRequest']
_GETREPOSITORYPLUGINREQUEST = DESCRIPTOR.message_types_by_name['GetRepositoryPluginRequest']
_PLUGINQUERY = DESCRIPTOR.message_types_by_name['PluginQuery']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_PLUGINSINFO = DESCRIPTOR.message_types_by_name['PluginsInfo']
_VERSIONSINFO = DESCRIPTOR.message_types_by_name['VersionsInfo']
_PLUGINSTATQUERY = DESCRIPTOR.message_types_by_name['PluginStatQuery']
_PLUGINQUERY_STATE = _PLUGINQUERY.enum_types_by_name['State']
_PLUGININFO_STATE = _PLUGININFO.enum_types_by_name['State']
CreatePluginRequest = _reflection.GeneratedProtocolMessageType('CreatePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLUGINREQUEST,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.CreatePluginRequest)
  })
_sym_db.RegisterMessage(CreatePluginRequest)

UpdatePluginRequest = _reflection.GeneratedProtocolMessageType('UpdatePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPLUGINREQUEST,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.UpdatePluginRequest)
  })
_sym_db.RegisterMessage(UpdatePluginRequest)

PluginRequest = _reflection.GeneratedProtocolMessageType('PluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINREQUEST,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PluginRequest)
  })
_sym_db.RegisterMessage(PluginRequest)

RepositoryPluginRequest = _reflection.GeneratedProtocolMessageType('RepositoryPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPOSITORYPLUGINREQUEST,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.RepositoryPluginRequest)
  })
_sym_db.RegisterMessage(RepositoryPluginRequest)

GetRepositoryPluginRequest = _reflection.GeneratedProtocolMessageType('GetRepositoryPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPOSITORYPLUGINREQUEST,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.GetRepositoryPluginRequest)
  })
_sym_db.RegisterMessage(GetRepositoryPluginRequest)

PluginQuery = _reflection.GeneratedProtocolMessageType('PluginQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINQUERY,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PluginQuery)
  })
_sym_db.RegisterMessage(PluginQuery)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

PluginsInfo = _reflection.GeneratedProtocolMessageType('PluginsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINSINFO,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PluginsInfo)
  })
_sym_db.RegisterMessage(PluginsInfo)

VersionsInfo = _reflection.GeneratedProtocolMessageType('VersionsInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONSINFO,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.VersionsInfo)
  })
_sym_db.RegisterMessage(VersionsInfo)

PluginStatQuery = _reflection.GeneratedProtocolMessageType('PluginStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINSTATQUERY,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PluginStatQuery)
  })
_sym_db.RegisterMessage(PluginStatQuery)

_PLUGIN = DESCRIPTOR.services_by_name['Plugin']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLUGIN.methods_by_name['register']._options = None
  _PLUGIN.methods_by_name['register']._serialized_options = b'\202\323\344\223\002\030\"\026/repository/v1/plugins'
  _PLUGIN.methods_by_name['update']._options = None
  _PLUGIN.methods_by_name['update']._serialized_options = b'\202\323\344\223\002#\032!/repository/v1/plugin/{plugin_id}'
  _PLUGIN.methods_by_name['deregister']._options = None
  _PLUGIN.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\002#*!/repository/v1/plugin/{plugin_id}'
  _PLUGIN.methods_by_name['enable']._options = None
  _PLUGIN.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002*\032(/repository/v1/plugin/{plugin_id}/enable'
  _PLUGIN.methods_by_name['disable']._options = None
  _PLUGIN.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002+\032)/repository/v1/plugin/{plugin_id}/disable'
  _PLUGIN.methods_by_name['get_versions']._options = None
  _PLUGIN.methods_by_name['get_versions']._serialized_options = b'\202\323\344\223\002-\022+/repository/v1/plugins/{plugin_id}/versions'
  _PLUGIN.methods_by_name['get']._options = None
  _PLUGIN.methods_by_name['get']._serialized_options = b'\202\323\344\223\002$\022\"/repository/v1/plugins/{plugin_id}'
  _PLUGIN.methods_by_name['list']._options = None
  _PLUGIN.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/repository/v1/pluginsZ\037\"\035/repository/v1/plugins/search'
  _PLUGIN.methods_by_name['stat']._options = None
  _PLUGIN.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/repository/v1/plugins/stat'
  _PUBLICREGISTRYTYPE._serialized_start=2463
  _PUBLICREGISTRYTYPE._serialized_end=2555
  _CREATEPLUGINREQUEST._serialized_start=240
  _CREATEPLUGINREQUEST._serialized_end=661
  _UPDATEPLUGINREQUEST._serialized_start=664
  _UPDATEPLUGINREQUEST._serialized_end=908
  _PLUGINREQUEST._serialized_start=910
  _PLUGINREQUEST._serialized_end=963
  _REPOSITORYPLUGINREQUEST._serialized_start=965
  _REPOSITORYPLUGINREQUEST._serialized_end=1051
  _GETREPOSITORYPLUGINREQUEST._serialized_start=1053
  _GETREPOSITORYPLUGINREQUEST._serialized_end=1156
  _PLUGINQUERY._serialized_start=1159
  _PLUGINQUERY._serialized_end=1510
  _PLUGINQUERY_STATE._serialized_start=1466
  _PLUGINQUERY_STATE._serialized_end=1510
  _PLUGININFO._serialized_start=1513
  _PLUGININFO._serialized_end=2182
  _PLUGININFO_STATE._serialized_start=1466
  _PLUGININFO_STATE._serialized_end=1510
  _PLUGINSINFO._serialized_start=2184
  _PLUGINSINFO._serialized_end=2275
  _VERSIONSINFO._serialized_start=2277
  _VERSIONSINFO._serialized_end=2346
  _PLUGINSTATQUERY._serialized_start=2348
  _PLUGINSTATQUERY._serialized_end=2461
  _PLUGIN._serialized_start=2558
  _PLUGIN._serialized_end=3841
# @@protoc_insertion_point(module_scope)
