# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/cost_analysis/v1/job.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"/\n\nJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"@\n\rGetJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x91\x02\n\x08JobQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12>\n\x06status\x18\x03 \x01(\x0e\x32..spaceone.api.cost_analysis.v1.JobQuery.Status\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"^\n\x06Status\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x0b\n\x07\x46\x41ILURE\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08\x43\x41NCELED\x10\x05\"R\n\x0b\x43hangedInfo\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\x12\'\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xdf\x03\n\x07JobInfo\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12=\n\x06status\x18\x02 \x01(\x0e\x32-.spaceone.api.cost_analysis.v1.JobInfo.Status\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nerror_code\x18\x04 \x01(\t\x12\x15\n\rerror_message\x18\x05 \x01(\t\x12\x13\n\x0btotal_tasks\x18\x06 \x01(\x05\x12\x16\n\x0eremained_tasks\x18\x07 \x01(\x05\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nupdated_at\x18\x16 \x01(\t\x12\x13\n\x0b\x66inished_at\x18\x17 \x01(\t\x12;\n\x07\x63hanged\x18\x18 \x03(\x0b\x32*.spaceone.api.cost_analysis.v1.ChangedInfo\"^\n\x06Status\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x0b\n\x07\x46\x41ILURE\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08\x43\x41NCELED\x10\x05\"X\n\x08JobsInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.cost_analysis.v1.JobInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"W\n\x0cJobStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa7\x04\n\x03Job\x12\x8a\x01\n\x06\x63\x61ncel\x12).spaceone.api.cost_analysis.v1.JobRequest\x1a&.spaceone.api.cost_analysis.v1.JobInfo\"-\x82\xd3\xe4\x93\x02\'\"%/cost-analysis/v1/job/{job_id}/cancel\x12\x83\x01\n\x03get\x12,.spaceone.api.cost_analysis.v1.GetJobRequest\x1a&.spaceone.api.cost_analysis.v1.JobInfo\"&\x82\xd3\xe4\x93\x02 \x12\x1e/cost-analysis/v1/job/{job_id}\x12\x99\x01\n\x04list\x12\'.spaceone.api.cost_analysis.v1.JobQuery\x1a\'.spaceone.api.cost_analysis.v1.JobsInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/cost-analysis/v1/jobsZ\x1f\"\x1d/cost-analysis/v1/jobs/search\x12q\n\x04stat\x12+.spaceone.api.cost_analysis.v1.JobStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/cost-analysis/v1/jobs/statb\x06proto3')



_JOBREQUEST = DESCRIPTOR.message_types_by_name['JobRequest']
_GETJOBREQUEST = DESCRIPTOR.message_types_by_name['GetJobRequest']
_JOBQUERY = DESCRIPTOR.message_types_by_name['JobQuery']
_CHANGEDINFO = DESCRIPTOR.message_types_by_name['ChangedInfo']
_JOBINFO = DESCRIPTOR.message_types_by_name['JobInfo']
_JOBSINFO = DESCRIPTOR.message_types_by_name['JobsInfo']
_JOBSTATQUERY = DESCRIPTOR.message_types_by_name['JobStatQuery']
_JOBQUERY_STATUS = _JOBQUERY.enum_types_by_name['Status']
_JOBINFO_STATUS = _JOBINFO.enum_types_by_name['Status']
JobRequest = _reflection.GeneratedProtocolMessageType('JobRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobRequest)
  })
_sym_db.RegisterMessage(JobRequest)

GetJobRequest = _reflection.GeneratedProtocolMessageType('GetJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetJobRequest)
  })
_sym_db.RegisterMessage(GetJobRequest)

JobQuery = _reflection.GeneratedProtocolMessageType('JobQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobQuery)
  })
_sym_db.RegisterMessage(JobQuery)

ChangedInfo = _reflection.GeneratedProtocolMessageType('ChangedInfo', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEDINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ChangedInfo)
  })
_sym_db.RegisterMessage(ChangedInfo)

JobInfo = _reflection.GeneratedProtocolMessageType('JobInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobInfo)
  })
_sym_db.RegisterMessage(JobInfo)

JobsInfo = _reflection.GeneratedProtocolMessageType('JobsInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobsInfo)
  })
_sym_db.RegisterMessage(JobsInfo)

JobStatQuery = _reflection.GeneratedProtocolMessageType('JobStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobStatQuery)
  })
_sym_db.RegisterMessage(JobStatQuery)

_JOB = DESCRIPTOR.services_by_name['Job']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOB.methods_by_name['cancel']._options = None
  _JOB.methods_by_name['cancel']._serialized_options = b'\202\323\344\223\002\'\"%/cost-analysis/v1/job/{job_id}/cancel'
  _JOB.methods_by_name['get']._options = None
  _JOB.methods_by_name['get']._serialized_options = b'\202\323\344\223\002 \022\036/cost-analysis/v1/job/{job_id}'
  _JOB.methods_by_name['list']._options = None
  _JOB.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/cost-analysis/v1/jobsZ\037\"\035/cost-analysis/v1/jobs/search'
  _JOB.methods_by_name['stat']._options = None
  _JOB.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/cost-analysis/v1/jobs/stat'
  _JOBREQUEST._serialized_start=168
  _JOBREQUEST._serialized_end=215
  _GETJOBREQUEST._serialized_start=217
  _GETJOBREQUEST._serialized_end=281
  _JOBQUERY._serialized_start=284
  _JOBQUERY._serialized_end=557
  _JOBQUERY_STATUS._serialized_start=463
  _JOBQUERY_STATUS._serialized_end=557
  _CHANGEDINFO._serialized_start=559
  _CHANGEDINFO._serialized_end=641
  _JOBINFO._serialized_start=644
  _JOBINFO._serialized_end=1123
  _JOBINFO_STATUS._serialized_start=463
  _JOBINFO_STATUS._serialized_end=557
  _JOBSINFO._serialized_start=1125
  _JOBSINFO._serialized_end=1213
  _JOBSTATQUERY._serialized_start=1215
  _JOBSTATQUERY._serialized_end=1302
  _JOB._serialized_start=1305
  _JOB._serialized_end=1856
# @@protoc_insertion_point(module_scope)
