# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/core/v1/server_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/core/v1/server_info.proto\x12\x14spaceone.api.core.v1\x1a\x1bgoogle/protobuf/empty.proto\"\x1e\n\x0bVersionInfo\x12\x0f\n\x07version\x18\x01 \x01(\t2X\n\nServerInfo\x12J\n\x0bget_version\x12\x16.google.protobuf.Empty\x1a!.spaceone.api.core.v1.VersionInfo\"\x00\x62\x06proto3')



_VERSIONINFO = DESCRIPTOR.message_types_by_name['VersionInfo']
VersionInfo = _reflection.GeneratedProtocolMessageType('VersionInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONINFO,
  '__module__' : 'spaceone.api.core.v1.server_info_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.VersionInfo)
  })
_sym_db.RegisterMessage(VersionInfo)

_SERVERINFO = DESCRIPTOR.services_by_name['ServerInfo']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VERSIONINFO._serialized_start=93
  _VERSIONINFO._serialized_end=123
  _SERVERINFO._serialized_start=125
  _SERVERINFO._serialized_end=213
# @@protoc_insertion_point(module_scope)
