# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/provisioning/v1/resource.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a spaceone/api/core/v1/query.proto\"\x83\x02\n\rResourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12\x11\n\tdomain_id\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x15\n\rresource_type\x18\n \x01(\t\"\x81\x04\n\x15\x43reateResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11resource_group_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\x16\n\x0eterraform_code\x18\x05 \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x0f\n\x07img_src\x18\n \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x12\n\nupdated_by\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\r \x01(\t\x12\x12\n\nupdated_at\x18\x0e \x01(\t\x12\x12\n\nsort_order\x18\x0f \x01(\x05\x12\x15\n\rresource_type\x18\x10 \x01(\t\x12\x39\n\x18resource_type_properties\x18\x11 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x14terraform_properties\x18\x12 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x33\n\x12\x61nsible_properties\x18\x13 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xee\x03\n\x15UpdateResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x07 \x01(\t\x12\x13\n\x0bvalid_value\x18\x08 \x03(\t\x12\x10\n\x08provider\x18\n \x01(\t\x12\x0f\n\x07img_src\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x0c \x01(\t\x12\x12\n\nupdated_by\x18\r \x01(\t\x12\x12\n\nsort_order\x18\x0e \x01(\x05\x12\x15\n\rresource_type\x18\x0f \x01(\t\x12\x39\n\x18resource_type_properties\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x14terraform_properties\x18\x11 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x33\n\x12\x61nsible_properties\x18\x12 \x01(\x0b\x32\x17.google.protobuf.Struct\"9\n\x0fResourceRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\\\n\x11ResourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x8d\x04\n\x0cResourceInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x0f\n\x07img_src\x18\n \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x12\n\nupdated_by\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\r \x01(\t\x12\x12\n\nupdated_at\x18\x0e \x01(\t\x12\x12\n\nsort_order\x18\x0f \x01(\x05\x12\x14\n\x0c\x61nsible_code\x18\x10 \x01(\t\x12\x15\n\rresource_type\x18\x11 \x01(\t\x12\x39\n\x18resource_type_properties\x18\x12 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x14terraform_properties\x18\x13 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x33\n\x12\x61nsible_properties\x18\x14 \x01(\x0b\x32\x17.google.protobuf.Struct\"a\n\rResourcesInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.provisioning.v1.ResourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x96\x07\n\x08Resource\x12\x95\x01\n\x0f\x63reate_resource\x12\x33.spaceone.api.provisioning.v1.CreateResourceRequest\x1a*.spaceone.api.provisioning.v1.ResourceInfo\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/provisioning/v1/resource\x12\xb1\x01\n\rget_resources\x12+.spaceone.api.provisioning.v1.ResourceQuery\x1a+.spaceone.api.provisioning.v1.ResourcesInfo\"F\x82\xd3\xe4\x93\x02@\x12\x1a/provisioning/v1/resourcesZ\"\" /provisioning/v1/resource/search\x12\x9a\x01\n\x0cget_resource\x12-.spaceone.api.provisioning.v1.ResourceRequest\x1a*.spaceone.api.provisioning.v1.ResourceInfo\"/\x82\xd3\xe4\x93\x02)\x12\'/provisioning/v1/resource/{resource_id}\x12\x95\x01\n\x0fupdate_resource\x12\x33.spaceone.api.provisioning.v1.UpdateResourceRequest\x1a*.spaceone.api.provisioning.v1.ResourceInfo\"!\x82\xd3\xe4\x93\x02\x1b\x1a\x19/provisioning/v1/resource\x12\x8e\x01\n\x0f\x64\x65lete_resource\x12-.spaceone.api.provisioning.v1.ResourceRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.*,/provisioning/v1/resource/{resource_request}\x12x\n\x04stat\x12/.spaceone.api.provisioning.v1.ResourceStatQuery\x1a\x17.google.protobuf.Struct\"&\x82\xd3\xe4\x93\x02 \"\x1e/provisioning/v1/resource/statb\x06proto3')



_RESOURCEQUERY = DESCRIPTOR.message_types_by_name['ResourceQuery']
_CREATERESOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateResourceRequest']
_UPDATERESOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateResourceRequest']
_RESOURCEREQUEST = DESCRIPTOR.message_types_by_name['ResourceRequest']
_RESOURCESTATQUERY = DESCRIPTOR.message_types_by_name['ResourceStatQuery']
_RESOURCEINFO = DESCRIPTOR.message_types_by_name['ResourceInfo']
_RESOURCESINFO = DESCRIPTOR.message_types_by_name['ResourcesInfo']
ResourceQuery = _reflection.GeneratedProtocolMessageType('ResourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceQuery)
  })
_sym_db.RegisterMessage(ResourceQuery)

CreateResourceRequest = _reflection.GeneratedProtocolMessageType('CreateResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateResourceRequest)
  })
_sym_db.RegisterMessage(CreateResourceRequest)

UpdateResourceRequest = _reflection.GeneratedProtocolMessageType('UpdateResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateResourceRequest)
  })
_sym_db.RegisterMessage(UpdateResourceRequest)

ResourceRequest = _reflection.GeneratedProtocolMessageType('ResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceRequest)
  })
_sym_db.RegisterMessage(ResourceRequest)

ResourceStatQuery = _reflection.GeneratedProtocolMessageType('ResourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceStatQuery)
  })
_sym_db.RegisterMessage(ResourceStatQuery)

ResourceInfo = _reflection.GeneratedProtocolMessageType('ResourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceInfo)
  })
_sym_db.RegisterMessage(ResourceInfo)

ResourcesInfo = _reflection.GeneratedProtocolMessageType('ResourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourcesInfo)
  })
_sym_db.RegisterMessage(ResourcesInfo)

_RESOURCE = DESCRIPTOR.services_by_name['Resource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCE.methods_by_name['create_resource']._options = None
  _RESOURCE.methods_by_name['create_resource']._serialized_options = b'\202\323\344\223\002\033\"\031/provisioning/v1/resource'
  _RESOURCE.methods_by_name['get_resources']._options = None
  _RESOURCE.methods_by_name['get_resources']._serialized_options = b'\202\323\344\223\002@\022\032/provisioning/v1/resourcesZ\"\" /provisioning/v1/resource/search'
  _RESOURCE.methods_by_name['get_resource']._options = None
  _RESOURCE.methods_by_name['get_resource']._serialized_options = b'\202\323\344\223\002)\022\'/provisioning/v1/resource/{resource_id}'
  _RESOURCE.methods_by_name['update_resource']._options = None
  _RESOURCE.methods_by_name['update_resource']._serialized_options = b'\202\323\344\223\002\033\032\031/provisioning/v1/resource'
  _RESOURCE.methods_by_name['delete_resource']._options = None
  _RESOURCE.methods_by_name['delete_resource']._serialized_options = b'\202\323\344\223\002.*,/provisioning/v1/resource/{resource_request}'
  _RESOURCE.methods_by_name['stat']._options = None
  _RESOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002 \"\036/provisioning/v1/resource/stat'
  _RESOURCEQUERY._serialized_start=201
  _RESOURCEQUERY._serialized_end=460
  _CREATERESOURCEREQUEST._serialized_start=463
  _CREATERESOURCEREQUEST._serialized_end=976
  _UPDATERESOURCEREQUEST._serialized_start=979
  _UPDATERESOURCEREQUEST._serialized_end=1473
  _RESOURCEREQUEST._serialized_start=1475
  _RESOURCEREQUEST._serialized_end=1532
  _RESOURCESTATQUERY._serialized_start=1534
  _RESOURCESTATQUERY._serialized_end=1626
  _RESOURCEINFO._serialized_start=1629
  _RESOURCEINFO._serialized_end=2154
  _RESOURCESINFO._serialized_start=2156
  _RESOURCESINFO._serialized_end=2253
  _RESOURCE._serialized_start=2256
  _RESOURCE._serialized_end=3174
# @@protoc_insertion_point(module_scope)
