# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/stack_temp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-spaceone/api/provisioning/v1/stack_temp.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a spaceone/api/core/v1/query.proto\"\x99\x01\n\x16\x43reateStackTempRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nstack_name\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\"<\n\x10StackTempRequest\x12\x15\n\rstack_temp_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"M\n\x13GetStackTempRequest\x12\x15\n\rstack_temp_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb0\x02\n\x16UpdateStackTempRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x15\n\rstack_temp_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x16\n\x0eterraform_code\x18\x04 \x01(\t\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_at\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12\x1a\n\x12service_account_id\x18\n \x01(\t\x12\x10\n\x08provider\x18\x0b \x01(\t\x12\r\n\x05graph\x18\x0c \x01(\t\x12\x37\n\x06\x65rrors\x18\r \x01(\x0b\x32\'.spaceone.api.provisioning.v1.ErrorInfo\"\xcf\x02\n\rStackTempInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x15\n\rstack_temp_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x16\n\x0eterraform_code\x18\x04 \x01(\t\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_at\x18\x08 \x01(\t\x12\x0e\n\x06status\x18\t \x01(\t\x12\x12\n\nproject_id\x18\n \x01(\t\x12\x1a\n\x12service_account_id\x18\x0b \x01(\t\x12\x10\n\x08provider\x18\x0c \x01(\t\x12\r\n\x05graph\x18\r \x01(\t\x12\x37\n\x06\x65rrors\x18\x0e \x01(\x0b\x32\'.spaceone.api.provisioning.v1.ErrorInfo\"c\n\x0eStackTempsInfo\x12<\n\x07results\x18\x01 \x03(\x0b\x32+.spaceone.api.provisioning.v1.StackTempInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xb2\x01\n\x0eStackTempQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x15\n\rstack_temp_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x12\n\nupdated_by\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\t\"]\n\tErrorInfo\x12\x12\n\nerror_code\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12+\n\nadditional\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct2\xbf\x06\n\tStackTemp\x12\x9b\x01\n\x11\x63reate_stack_temp\x12\x34.spaceone.api.provisioning.v1.CreateStackTempRequest\x1a+.spaceone.api.provisioning.v1.StackTempInfo\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/provisioning/v1/stack_temp\x12\xba\x01\n\x0fget_stack_temps\x12,.spaceone.api.provisioning.v1.StackTempQuery\x1a,.spaceone.api.provisioning.v1.StackTempsInfo\"K\x82\xd3\xe4\x93\x02\x45\x12\x1c/provisioning/v1/stack_tempsZ%\"#/provisioning/v1/stack_temps/search\x12\xa5\x01\n\x0eget_stack_temp\x12\x31.spaceone.api.provisioning.v1.GetStackTempRequest\x1a+.spaceone.api.provisioning.v1.StackTempInfo\"3\x82\xd3\xe4\x93\x02-\x12+/provisioning/v1/stack_temp/{stack_temp_id}\x12\x9b\x01\n\x11update_stack_temp\x12\x34.spaceone.api.provisioning.v1.UpdateStackTempRequest\x1a+.spaceone.api.provisioning.v1.StackTempInfo\"#\x82\xd3\xe4\x93\x02\x1d\x1a\x1b/provisioning/v1/stack_temp\x12\x90\x01\n\x11\x64\x65lete_stack_temp\x12..spaceone.api.provisioning.v1.StackTempRequest\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-*+/provisioning/v1/stack_temp/{stack_temp_id}b\x06proto3')



_CREATESTACKTEMPREQUEST = DESCRIPTOR.message_types_by_name['CreateStackTempRequest']
_STACKTEMPREQUEST = DESCRIPTOR.message_types_by_name['StackTempRequest']
_GETSTACKTEMPREQUEST = DESCRIPTOR.message_types_by_name['GetStackTempRequest']
_UPDATESTACKTEMPREQUEST = DESCRIPTOR.message_types_by_name['UpdateStackTempRequest']
_STACKTEMPINFO = DESCRIPTOR.message_types_by_name['StackTempInfo']
_STACKTEMPSINFO = DESCRIPTOR.message_types_by_name['StackTempsInfo']
_STACKTEMPQUERY = DESCRIPTOR.message_types_by_name['StackTempQuery']
_ERRORINFO = DESCRIPTOR.message_types_by_name['ErrorInfo']
CreateStackTempRequest = _reflection.GeneratedProtocolMessageType('CreateStackTempRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTACKTEMPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateStackTempRequest)
  })
_sym_db.RegisterMessage(CreateStackTempRequest)

StackTempRequest = _reflection.GeneratedProtocolMessageType('StackTempRequest', (_message.Message,), {
  'DESCRIPTOR' : _STACKTEMPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackTempRequest)
  })
_sym_db.RegisterMessage(StackTempRequest)

GetStackTempRequest = _reflection.GeneratedProtocolMessageType('GetStackTempRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTACKTEMPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetStackTempRequest)
  })
_sym_db.RegisterMessage(GetStackTempRequest)

UpdateStackTempRequest = _reflection.GeneratedProtocolMessageType('UpdateStackTempRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTACKTEMPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateStackTempRequest)
  })
_sym_db.RegisterMessage(UpdateStackTempRequest)

StackTempInfo = _reflection.GeneratedProtocolMessageType('StackTempInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKTEMPINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackTempInfo)
  })
_sym_db.RegisterMessage(StackTempInfo)

StackTempsInfo = _reflection.GeneratedProtocolMessageType('StackTempsInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKTEMPSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackTempsInfo)
  })
_sym_db.RegisterMessage(StackTempsInfo)

StackTempQuery = _reflection.GeneratedProtocolMessageType('StackTempQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKTEMPQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackTempQuery)
  })
_sym_db.RegisterMessage(StackTempQuery)

ErrorInfo = _reflection.GeneratedProtocolMessageType('ErrorInfo', (_message.Message,), {
  'DESCRIPTOR' : _ERRORINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ErrorInfo)
  })
_sym_db.RegisterMessage(ErrorInfo)

_STACKTEMP = DESCRIPTOR.services_by_name['StackTemp']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STACKTEMP.methods_by_name['create_stack_temp']._options = None
  _STACKTEMP.methods_by_name['create_stack_temp']._serialized_options = b'\202\323\344\223\002\035\"\033/provisioning/v1/stack_temp'
  _STACKTEMP.methods_by_name['get_stack_temps']._options = None
  _STACKTEMP.methods_by_name['get_stack_temps']._serialized_options = b'\202\323\344\223\002E\022\034/provisioning/v1/stack_tempsZ%\"#/provisioning/v1/stack_temps/search'
  _STACKTEMP.methods_by_name['get_stack_temp']._options = None
  _STACKTEMP.methods_by_name['get_stack_temp']._serialized_options = b'\202\323\344\223\002-\022+/provisioning/v1/stack_temp/{stack_temp_id}'
  _STACKTEMP.methods_by_name['update_stack_temp']._options = None
  _STACKTEMP.methods_by_name['update_stack_temp']._serialized_options = b'\202\323\344\223\002\035\032\033/provisioning/v1/stack_temp'
  _STACKTEMP.methods_by_name['delete_stack_temp']._options = None
  _STACKTEMP.methods_by_name['delete_stack_temp']._serialized_options = b'\202\323\344\223\002-*+/provisioning/v1/stack_temp/{stack_temp_id}'
  _CREATESTACKTEMPREQUEST._serialized_start=203
  _CREATESTACKTEMPREQUEST._serialized_end=356
  _STACKTEMPREQUEST._serialized_start=358
  _STACKTEMPREQUEST._serialized_end=418
  _GETSTACKTEMPREQUEST._serialized_start=420
  _GETSTACKTEMPREQUEST._serialized_end=497
  _UPDATESTACKTEMPREQUEST._serialized_start=500
  _UPDATESTACKTEMPREQUEST._serialized_end=804
  _STACKTEMPINFO._serialized_start=807
  _STACKTEMPINFO._serialized_end=1142
  _STACKTEMPSINFO._serialized_start=1144
  _STACKTEMPSINFO._serialized_end=1243
  _STACKTEMPQUERY._serialized_start=1246
  _STACKTEMPQUERY._serialized_end=1424
  _ERRORINFO._serialized_start=1426
  _ERRORINFO._serialized_end=1519
  _STACKTEMP._serialized_start=1522
  _STACKTEMP._serialized_end=2353
# @@protoc_insertion_point(module_scope)
