# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.provisioning.v1 import catalog_pb2 as spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2


class CatalogStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/create_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CreateCatalogRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
                )
        self.get_catalogs = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/get_catalogs',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogsInfo.FromString,
                )
        self.get_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/get_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.GetCatalogRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
                )
        self.update_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/update_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
                )
        self.delete_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/delete_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.publish_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/publish_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/stat',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.plan_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/plan_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.approval_process = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/approval_process',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
                )


class CatalogServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_catalogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def publish_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def plan_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def approval_process(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CatalogServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.create_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CreateCatalogRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.SerializeToString,
            ),
            'get_catalogs': grpc.unary_unary_rpc_method_handler(
                    servicer.get_catalogs,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogsInfo.SerializeToString,
            ),
            'get_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.get_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.GetCatalogRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.SerializeToString,
            ),
            'update_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.update_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.SerializeToString,
            ),
            'delete_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'publish_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.publish_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'plan_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.plan_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'approval_process': grpc.unary_unary_rpc_method_handler(
                    servicer.approval_process,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.provisioning.v1.Catalog', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Catalog(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/create_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CreateCatalogRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_catalogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/get_catalogs',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogQuery.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/get_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.GetCatalogRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/update_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/delete_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def publish_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/publish_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/stat',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def plan_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/plan_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def approval_process(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/approval_process',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
