# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/savings_azure.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-spaceone/api/inventory/v1/savings_azure.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"T\n\x15SavingsCollectRequest\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"z\n\x15SavingsSummaryRequest\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x12\n\nstart_date\x18\x04 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x05 \x01(\t\"\xab\x01\n\x10GetCoverageQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x1a\n\x12service_account_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x12\n\nstart_date\x18\x05 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x06 \x01(\t2\xe8\x04\n\x0cSavingsAzure\x12\x9c\x01\n\x15\x63reate_recommendation\x12\x30.spaceone.api.inventory.v1.SavingsCollectRequest\x1a\x16.google.protobuf.Empty\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/inventory/v1/savings-azure/create_recommendation\x12\x92\x01\n\x10\x63reate_inventory\x12\x30.spaceone.api.inventory.v1.SavingsCollectRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\x12,/inventory/v1/savings-azure/create_inventory\x12\x8e\x01\n\x0e\x63reate_summary\x12\x30.spaceone.api.inventory.v1.SavingsSummaryRequest\x1a\x16.google.protobuf.Empty\"2\x82\xd3\xe4\x93\x02,\x12*/inventory/v1/savings-azure/create_summary\x12\x92\x01\n\x12get_coverage_ratio\x12+.spaceone.api.inventory.v1.GetCoverageQuery\x1a\x17.google.protobuf.Struct\"6\x82\xd3\xe4\x93\x02\x30\x12./inventory/v1/savings-azure/get_coverage_ratiob\x06proto3')



_SAVINGSCOLLECTREQUEST = DESCRIPTOR.message_types_by_name['SavingsCollectRequest']
_SAVINGSSUMMARYREQUEST = DESCRIPTOR.message_types_by_name['SavingsSummaryRequest']
_GETCOVERAGEQUERY = DESCRIPTOR.message_types_by_name['GetCoverageQuery']
SavingsCollectRequest = _reflection.GeneratedProtocolMessageType('SavingsCollectRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSCOLLECTREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_azure_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsCollectRequest)
  })
_sym_db.RegisterMessage(SavingsCollectRequest)

SavingsSummaryRequest = _reflection.GeneratedProtocolMessageType('SavingsSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSSUMMARYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_azure_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsSummaryRequest)
  })
_sym_db.RegisterMessage(SavingsSummaryRequest)

GetCoverageQuery = _reflection.GeneratedProtocolMessageType('GetCoverageQuery', (_message.Message,), {
  'DESCRIPTOR' : _GETCOVERAGEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_azure_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetCoverageQuery)
  })
_sym_db.RegisterMessage(GetCoverageQuery)

_SAVINGSAZURE = DESCRIPTOR.services_by_name['SavingsAzure']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SAVINGSAZURE.methods_by_name['create_recommendation']._options = None
  _SAVINGSAZURE.methods_by_name['create_recommendation']._serialized_options = b'\202\323\344\223\0023\0221/inventory/v1/savings-azure/create_recommendation'
  _SAVINGSAZURE.methods_by_name['create_inventory']._options = None
  _SAVINGSAZURE.methods_by_name['create_inventory']._serialized_options = b'\202\323\344\223\002.\022,/inventory/v1/savings-azure/create_inventory'
  _SAVINGSAZURE.methods_by_name['create_summary']._options = None
  _SAVINGSAZURE.methods_by_name['create_summary']._serialized_options = b'\202\323\344\223\002,\022*/inventory/v1/savings-azure/create_summary'
  _SAVINGSAZURE.methods_by_name['get_coverage_ratio']._options = None
  _SAVINGSAZURE.methods_by_name['get_coverage_ratio']._serialized_options = b'\202\323\344\223\0020\022./inventory/v1/savings-azure/get_coverage_ratio'
  _SAVINGSCOLLECTREQUEST._serialized_start=199
  _SAVINGSCOLLECTREQUEST._serialized_end=283
  _SAVINGSSUMMARYREQUEST._serialized_start=285
  _SAVINGSSUMMARYREQUEST._serialized_end=407
  _GETCOVERAGEQUERY._serialized_start=410
  _GETCOVERAGEQUERY._serialized_end=581
  _SAVINGSAZURE._serialized_start=584
  _SAVINGSAZURE._serialized_end=1200
# @@protoc_insertion_point(module_scope)
