# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/unused_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.spaceone/api/inventory/v1/unused_service.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"B\n\x1b\x43ollectUnusedServiceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\"G\n\x17GetUnusedServiceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11unused_service_id\x18\x02 \x01(\t\"\x8b\x02\n\x12UnusedServiceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x13\n\x0bresource_id\x18\x06 \x01(\t\x12\x15\n\rresource_name\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x15\n\rinstance_type\x18\t \x01(\t\x12\x17\n\x0funused_resource\x18\n \x01(\t\x12\x13\n\x0bunused_type\x18\x0b \x01(\t\"\xe2\x03\n\x11UnusedServiceInfo\x12\x19\n\x11unused_service_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x13\n\x0bresource_id\x18\x06 \x01(\t\x12\x15\n\rresource_name\x18\x07 \x01(\t\x12\x33\n\x12\x63loud_service_info\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06region\x18\t \x01(\t\x12\x15\n\rinstance_type\x18\n \x01(\t\x12\x17\n\x0funused_resource\x18\x0b \x01(\t\x12%\n\x04\x63ost\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nsetting_id\x18\r \x01(\t\x12%\n\x04\x64\x61ta\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x0f \x01(\t\x12\x12\n\ndeleted_at\x18\x10 \x01(\t\x12\x13\n\x0b\x61nalyzed_at\x18\x11 \x01(\t\x12\x13\n\x0bunused_type\x18\x12 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x13 \x01(\t\"h\n\x12UnusedServicesInfo\x12=\n\x07results\x18\x01 \x03(\x0b\x32,.spaceone.api.inventory.v1.UnusedServiceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"a\n\x16UnusedServiceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xd6\x05\n\rUnusedService\x12\x88\x01\n\x07\x63ollect\x12\x36.spaceone.api.inventory.v1.CollectUnusedServiceRequest\x1a\x17.google.protobuf.Struct\",\x82\xd3\xe4\x93\x02&\"$/inventory/v1/unused-service/collect\x12\x91\x01\n\x03get\x12\x32.spaceone.api.inventory.v1.GetUnusedServiceRequest\x1a,.spaceone.api.inventory.v1.UnusedServiceInfo\"(\x82\xd3\xe4\x93\x02\"\" /inventory/v1/unused-service/get\x12\x90\x01\n\x04list\x12-.spaceone.api.inventory.v1.UnusedServiceQuery\x1a-.spaceone.api.inventory.v1.UnusedServicesInfo\"*\x82\xd3\xe4\x93\x02$\"\"/inventory/v1/unused-services/list\x12~\n\x04stat\x12\x31.spaceone.api.inventory.v1.UnusedServiceStatQuery\x1a\x17.google.protobuf.Struct\"*\x82\xd3\xe4\x93\x02$\"\"/inventory/v1/unused-services/stat\x12\x92\x01\n\x0eget_opt_report\x12\x31.spaceone.api.inventory.v1.UnusedServiceStatQuery\x1a\x17.google.protobuf.Struct\"4\x82\xd3\xe4\x93\x02.\",/inventory/v1/unused-services/get_opt_reportb\x06proto3')



_COLLECTUNUSEDSERVICEREQUEST = DESCRIPTOR.message_types_by_name['CollectUnusedServiceRequest']
_GETUNUSEDSERVICEREQUEST = DESCRIPTOR.message_types_by_name['GetUnusedServiceRequest']
_UNUSEDSERVICEQUERY = DESCRIPTOR.message_types_by_name['UnusedServiceQuery']
_UNUSEDSERVICEINFO = DESCRIPTOR.message_types_by_name['UnusedServiceInfo']
_UNUSEDSERVICESINFO = DESCRIPTOR.message_types_by_name['UnusedServicesInfo']
_UNUSEDSERVICESTATQUERY = DESCRIPTOR.message_types_by_name['UnusedServiceStatQuery']
CollectUnusedServiceRequest = _reflection.GeneratedProtocolMessageType('CollectUnusedServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTUNUSEDSERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectUnusedServiceRequest)
  })
_sym_db.RegisterMessage(CollectUnusedServiceRequest)

GetUnusedServiceRequest = _reflection.GeneratedProtocolMessageType('GetUnusedServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUNUSEDSERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetUnusedServiceRequest)
  })
_sym_db.RegisterMessage(GetUnusedServiceRequest)

UnusedServiceQuery = _reflection.GeneratedProtocolMessageType('UnusedServiceQuery', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceQuery)
  })
_sym_db.RegisterMessage(UnusedServiceQuery)

UnusedServiceInfo = _reflection.GeneratedProtocolMessageType('UnusedServiceInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICEINFO,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceInfo)
  })
_sym_db.RegisterMessage(UnusedServiceInfo)

UnusedServicesInfo = _reflection.GeneratedProtocolMessageType('UnusedServicesInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICESINFO,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServicesInfo)
  })
_sym_db.RegisterMessage(UnusedServicesInfo)

UnusedServiceStatQuery = _reflection.GeneratedProtocolMessageType('UnusedServiceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICESTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceStatQuery)
  })
_sym_db.RegisterMessage(UnusedServiceStatQuery)

_UNUSEDSERVICE = DESCRIPTOR.services_by_name['UnusedService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _UNUSEDSERVICE.methods_by_name['collect']._options = None
  _UNUSEDSERVICE.methods_by_name['collect']._serialized_options = b'\202\323\344\223\002&\"$/inventory/v1/unused-service/collect'
  _UNUSEDSERVICE.methods_by_name['get']._options = None
  _UNUSEDSERVICE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\"\" /inventory/v1/unused-service/get'
  _UNUSEDSERVICE.methods_by_name['list']._options = None
  _UNUSEDSERVICE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002$\"\"/inventory/v1/unused-services/list'
  _UNUSEDSERVICE.methods_by_name['stat']._options = None
  _UNUSEDSERVICE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002$\"\"/inventory/v1/unused-services/stat'
  _UNUSEDSERVICE.methods_by_name['get_opt_report']._options = None
  _UNUSEDSERVICE.methods_by_name['get_opt_report']._serialized_options = b'\202\323\344\223\002.\",/inventory/v1/unused-services/get_opt_report'
  _COLLECTUNUSEDSERVICEREQUEST._serialized_start=200
  _COLLECTUNUSEDSERVICEREQUEST._serialized_end=266
  _GETUNUSEDSERVICEREQUEST._serialized_start=268
  _GETUNUSEDSERVICEREQUEST._serialized_end=339
  _UNUSEDSERVICEQUERY._serialized_start=342
  _UNUSEDSERVICEQUERY._serialized_end=609
  _UNUSEDSERVICEINFO._serialized_start=612
  _UNUSEDSERVICEINFO._serialized_end=1094
  _UNUSEDSERVICESINFO._serialized_start=1096
  _UNUSEDSERVICESINFO._serialized_end=1200
  _UNUSEDSERVICESTATQUERY._serialized_start=1202
  _UNUSEDSERVICESTATQUERY._serialized_end=1299
  _UNUSEDSERVICE._serialized_start=1302
  _UNUSEDSERVICE._serialized_end=2028
# @@protoc_insertion_point(module_scope)
