# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.provisioning.v1 import catalog_group_pb2 as spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2


class CatalogGroupStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create_catalog_group = channel.unary_unary(
                '/spaceone.api.provisioning.v1.CatalogGroup/create_catalog_group',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CreateCatalogGroupRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
                )
        self.update_catalog_group = channel.unary_unary(
                '/spaceone.api.provisioning.v1.CatalogGroup/update_catalog_group',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.UpdateCatalogGroupRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
                )
        self.delete_catalog_group = channel.unary_unary(
                '/spaceone.api.provisioning.v1.CatalogGroup/delete_catalog_group',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get_catalog_group = channel.unary_unary(
                '/spaceone.api.provisioning.v1.CatalogGroup/get_catalog_group',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.GetCatalogGroupRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
                )
        self.get_catalog_groups = channel.unary_unary(
                '/spaceone.api.provisioning.v1.CatalogGroup/get_catalog_groups',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupsInfo.FromString,
                )


class CatalogGroupServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create_catalog_group(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_catalog_group(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_catalog_group(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_catalog_group(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_catalog_groups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CatalogGroupServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create_catalog_group': grpc.unary_unary_rpc_method_handler(
                    servicer.create_catalog_group,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CreateCatalogGroupRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.SerializeToString,
            ),
            'update_catalog_group': grpc.unary_unary_rpc_method_handler(
                    servicer.update_catalog_group,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.UpdateCatalogGroupRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.SerializeToString,
            ),
            'delete_catalog_group': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_catalog_group,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get_catalog_group': grpc.unary_unary_rpc_method_handler(
                    servicer.get_catalog_group,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.GetCatalogGroupRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.SerializeToString,
            ),
            'get_catalog_groups': grpc.unary_unary_rpc_method_handler(
                    servicer.get_catalog_groups,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupsInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.provisioning.v1.CatalogGroup', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CatalogGroup(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create_catalog_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.CatalogGroup/create_catalog_group',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CreateCatalogGroupRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_catalog_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.CatalogGroup/update_catalog_group',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.UpdateCatalogGroupRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_catalog_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.CatalogGroup/delete_catalog_group',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_catalog_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.CatalogGroup/get_catalog_group',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.GetCatalogGroupRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_catalog_groups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.CatalogGroup/get_catalog_groups',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupQuery.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
