# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/plugin/collector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-spaceone/api/inventory/plugin/collector.proto\x12\x1dspaceone.api.inventory.plugin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"7\n\x0bInitRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"g\n\rVerifyRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x91\x01\n\x0e\x43ollectRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xe9\x02\n\x0cResourceInfo\x12@\n\x05state\x18\x01 \x01(\x0e\x32\x31.spaceone.api.inventory.plugin.ResourceInfo.State\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rresource_type\x18\x03 \x01(\t\x12,\n\x0bmatch_rules\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08resource\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07options\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\"l\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0e\n\nINPROGRESS\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\x0b\n\x07\x46\x41ILURE\x10\x05\x12\x0b\n\x07TIMEOUT\x10\x06\x12\x08\n\x04IDLE\x10\x07\"?\n\x13\x43ollectorVerifyInfo\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"7\n\nPluginInfo\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xa9\x02\n\tCollector\x12_\n\x04init\x12*.spaceone.api.inventory.plugin.InitRequest\x1a).spaceone.api.inventory.plugin.PluginInfo\"\x00\x12P\n\x06verify\x12,.spaceone.api.inventory.plugin.VerifyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x07\x63ollect\x12-.spaceone.api.inventory.plugin.CollectRequest\x1a+.spaceone.api.inventory.plugin.ResourceInfo\"\x00\x30\x01\x62\x06proto3')



_INITREQUEST = DESCRIPTOR.message_types_by_name['InitRequest']
_VERIFYREQUEST = DESCRIPTOR.message_types_by_name['VerifyRequest']
_COLLECTREQUEST = DESCRIPTOR.message_types_by_name['CollectRequest']
_RESOURCEINFO = DESCRIPTOR.message_types_by_name['ResourceInfo']
_COLLECTORVERIFYINFO = DESCRIPTOR.message_types_by_name['CollectorVerifyInfo']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_RESOURCEINFO_STATE = _RESOURCEINFO.enum_types_by_name['State']
InitRequest = _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITREQUEST,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.InitRequest)
  })
_sym_db.RegisterMessage(InitRequest)

VerifyRequest = _reflection.GeneratedProtocolMessageType('VerifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYREQUEST,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.VerifyRequest)
  })
_sym_db.RegisterMessage(VerifyRequest)

CollectRequest = _reflection.GeneratedProtocolMessageType('CollectRequest', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTREQUEST,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.CollectRequest)
  })
_sym_db.RegisterMessage(CollectRequest)

ResourceInfo = _reflection.GeneratedProtocolMessageType('ResourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEINFO,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.ResourceInfo)
  })
_sym_db.RegisterMessage(ResourceInfo)

CollectorVerifyInfo = _reflection.GeneratedProtocolMessageType('CollectorVerifyInfo', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORVERIFYINFO,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.CollectorVerifyInfo)
  })
_sym_db.RegisterMessage(CollectorVerifyInfo)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

_COLLECTOR = DESCRIPTOR.services_by_name['Collector']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INITREQUEST._serialized_start=139
  _INITREQUEST._serialized_end=194
  _VERIFYREQUEST._serialized_start=196
  _VERIFYREQUEST._serialized_end=299
  _COLLECTREQUEST._serialized_start=302
  _COLLECTREQUEST._serialized_end=447
  _RESOURCEINFO._serialized_start=450
  _RESOURCEINFO._serialized_end=811
  _RESOURCEINFO_STATE._serialized_start=703
  _RESOURCEINFO_STATE._serialized_end=811
  _COLLECTORVERIFYINFO._serialized_start=813
  _COLLECTORVERIFYINFO._serialized_end=876
  _PLUGININFO._serialized_start=878
  _PLUGININFO._serialized_end=933
  _COLLECTOR._serialized_start=936
  _COLLECTOR._serialized_end=1233
# @@protoc_insertion_point(module_scope)
