# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/price_list/v1/risp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%spaceone/api/price_list/v1/risp.proto\x12\x1aspaceone.api.price_list.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xcf\x02\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x11\n\tsecret_id\x18\x07 \x01(\t\x12H\n\x0cupgrade_mode\x18\x08 \x01(\x0e\x32\x32.spaceone.api.price_list.v1.PluginInfo.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"\xd7\x01\n\x13RegisterRispRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12K\n\trisp_type\x18\x02 \x01(\x0e\x32\x38.spaceone.api.price_list.v1.RegisterRispRequest.RispType\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x11\n\tsecret_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x08RispType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\x97\x01\n\x11UpdateRispRequest\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x08template\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xfe\x01\n\x17UpdateRispPluginRequest\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12U\n\x0cupgrade_mode\x18\x04 \x01(\x0e\x32?.spaceone.api.price_list.v1.UpdateRispPluginRequest.UpgradeMode\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"^\n\x0fSyncRispRequest\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\x18\n\x10no_preload_cache\x18\x03 \x01(\x08\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"1\n\x0bRispRequest\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"B\n\x0eGetRispRequest\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xfc\x01\n\tRispQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07risp_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x41\n\trisp_type\x18\x05 \x01(\x0e\x32..spaceone.api.price_list.v1.RispQuery.RispType\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x08RispType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\xae\x04\n\x08RispInfo\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x39\n\x05state\x18\x03 \x01(\x0e\x32*.spaceone.api.price_list.v1.RispInfo.State\x12@\n\trisp_type\x18\x04 \x01(\x0e\x32-.spaceone.api.price_list.v1.RispInfo.RispType\x12\x10\n\x08provider\x18\x05 \x01(\t\x12;\n\x0bplugin_info\x18\x06 \x01(\x0b\x32&.spaceone.api.price_list.v1.PluginInfo\x12)\n\x08template\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rcost_tag_keys\x18\t \x03(\t\x12!\n\x19\x63ost_additional_info_keys\x18\n \x03(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x1c\n\x14last_synchronized_at\x18\x16 \x01(\t\"2\n\x05State\x12\x0e\n\nSTATE_NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"2\n\x08RispType\x12\r\n\tTYPE_NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"W\n\tRispsInfo\x12\x35\n\x07results\x18\x01 \x03(\x0b\x32$.spaceone.api.price_list.v1.RispInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"X\n\rRispStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x83\x06\n\x04Risp\x12~\n\x08register\x12/.spaceone.api.price_list.v1.RegisterRispRequest\x1a$.spaceone.api.price_list.v1.RispInfo\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/price-list/v1/risp\x12\x84\x01\n\x06update\x12-.spaceone.api.price_list.v1.UpdateRispRequest\x1a$.spaceone.api.price_list.v1.RispInfo\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/price-list/v1/risp/{risp_id}\x12t\n\nderegister\x12\'.spaceone.api.price_list.v1.RispRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/price-list/v1/risp/{risp_id}\x12~\n\x03get\x12*.spaceone.api.price_list.v1.GetRispRequest\x1a$.spaceone.api.price_list.v1.RispInfo\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/price-list/v1/risp/{risp_id}\x12\x8f\x01\n\x04list\x12%.spaceone.api.price_list.v1.RispQuery\x1a%.spaceone.api.price_list.v1.RispsInfo\"9\x82\xd3\xe4\x93\x02\x33\x12\x13/price-list/v1/rispZ\x1c\"\x1a/price-list/v1/risp/search\x12l\n\x04stat\x12).spaceone.api.price_list.v1.RispStatQuery\x1a\x17.google.protobuf.Struct\" \x82\xd3\xe4\x93\x02\x1a\"\x18/price-list/v1/risp/statb\x06proto3')



_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_REGISTERRISPREQUEST = DESCRIPTOR.message_types_by_name['RegisterRispRequest']
_UPDATERISPREQUEST = DESCRIPTOR.message_types_by_name['UpdateRispRequest']
_UPDATERISPPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateRispPluginRequest']
_SYNCRISPREQUEST = DESCRIPTOR.message_types_by_name['SyncRispRequest']
_RISPREQUEST = DESCRIPTOR.message_types_by_name['RispRequest']
_GETRISPREQUEST = DESCRIPTOR.message_types_by_name['GetRispRequest']
_RISPQUERY = DESCRIPTOR.message_types_by_name['RispQuery']
_RISPINFO = DESCRIPTOR.message_types_by_name['RispInfo']
_RISPSINFO = DESCRIPTOR.message_types_by_name['RispsInfo']
_RISPSTATQUERY = DESCRIPTOR.message_types_by_name['RispStatQuery']
_PLUGININFO_UPGRADEMODE = _PLUGININFO.enum_types_by_name['UpgradeMode']
_REGISTERRISPREQUEST_RISPTYPE = _REGISTERRISPREQUEST.enum_types_by_name['RispType']
_UPDATERISPPLUGINREQUEST_UPGRADEMODE = _UPDATERISPPLUGINREQUEST.enum_types_by_name['UpgradeMode']
_RISPQUERY_RISPTYPE = _RISPQUERY.enum_types_by_name['RispType']
_RISPINFO_STATE = _RISPINFO.enum_types_by_name['State']
_RISPINFO_RISPTYPE = _RISPINFO.enum_types_by_name['RispType']
PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

RegisterRispRequest = _reflection.GeneratedProtocolMessageType('RegisterRispRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERRISPREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RegisterRispRequest)
  })
_sym_db.RegisterMessage(RegisterRispRequest)

UpdateRispRequest = _reflection.GeneratedProtocolMessageType('UpdateRispRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERISPREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.UpdateRispRequest)
  })
_sym_db.RegisterMessage(UpdateRispRequest)

UpdateRispPluginRequest = _reflection.GeneratedProtocolMessageType('UpdateRispPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERISPPLUGINREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.UpdateRispPluginRequest)
  })
_sym_db.RegisterMessage(UpdateRispPluginRequest)

SyncRispRequest = _reflection.GeneratedProtocolMessageType('SyncRispRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNCRISPREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.SyncRispRequest)
  })
_sym_db.RegisterMessage(SyncRispRequest)

RispRequest = _reflection.GeneratedProtocolMessageType('RispRequest', (_message.Message,), {
  'DESCRIPTOR' : _RISPREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RispRequest)
  })
_sym_db.RegisterMessage(RispRequest)

GetRispRequest = _reflection.GeneratedProtocolMessageType('GetRispRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRISPREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.GetRispRequest)
  })
_sym_db.RegisterMessage(GetRispRequest)

RispQuery = _reflection.GeneratedProtocolMessageType('RispQuery', (_message.Message,), {
  'DESCRIPTOR' : _RISPQUERY,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RispQuery)
  })
_sym_db.RegisterMessage(RispQuery)

RispInfo = _reflection.GeneratedProtocolMessageType('RispInfo', (_message.Message,), {
  'DESCRIPTOR' : _RISPINFO,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RispInfo)
  })
_sym_db.RegisterMessage(RispInfo)

RispsInfo = _reflection.GeneratedProtocolMessageType('RispsInfo', (_message.Message,), {
  'DESCRIPTOR' : _RISPSINFO,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RispsInfo)
  })
_sym_db.RegisterMessage(RispsInfo)

RispStatQuery = _reflection.GeneratedProtocolMessageType('RispStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RISPSTATQUERY,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RispStatQuery)
  })
_sym_db.RegisterMessage(RispStatQuery)

_RISP = DESCRIPTOR.services_by_name['Risp']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RISP.methods_by_name['register']._options = None
  _RISP.methods_by_name['register']._serialized_options = b'\202\323\344\223\002\025\"\023/price-list/v1/risp'
  _RISP.methods_by_name['update']._options = None
  _RISP.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\037\032\035/price-list/v1/risp/{risp_id}'
  _RISP.methods_by_name['deregister']._options = None
  _RISP.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\002\037*\035/price-list/v1/risp/{risp_id}'
  _RISP.methods_by_name['get']._options = None
  _RISP.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\037\022\035/price-list/v1/risp/{risp_id}'
  _RISP.methods_by_name['list']._options = None
  _RISP.methods_by_name['list']._serialized_options = b'\202\323\344\223\0023\022\023/price-list/v1/rispZ\034\"\032/price-list/v1/risp/search'
  _RISP.methods_by_name['stat']._options = None
  _RISP.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\032\"\030/price-list/v1/risp/stat'
  _PLUGININFO._serialized_start=193
  _PLUGININFO._serialized_end=528
  _PLUGININFO_UPGRADEMODE._serialized_start=483
  _PLUGININFO_UPGRADEMODE._serialized_end=528
  _REGISTERRISPREQUEST._serialized_start=531
  _REGISTERRISPREQUEST._serialized_end=746
  _REGISTERRISPREQUEST_RISPTYPE._serialized_start=701
  _REGISTERRISPREQUEST_RISPTYPE._serialized_end=746
  _UPDATERISPREQUEST._serialized_start=749
  _UPDATERISPREQUEST._serialized_end=900
  _UPDATERISPPLUGINREQUEST._serialized_start=903
  _UPDATERISPPLUGINREQUEST._serialized_end=1157
  _UPDATERISPPLUGINREQUEST_UPGRADEMODE._serialized_start=483
  _UPDATERISPPLUGINREQUEST_UPGRADEMODE._serialized_end=528
  _SYNCRISPREQUEST._serialized_start=1159
  _SYNCRISPREQUEST._serialized_end=1253
  _RISPREQUEST._serialized_start=1255
  _RISPREQUEST._serialized_end=1304
  _GETRISPREQUEST._serialized_start=1306
  _GETRISPREQUEST._serialized_end=1372
  _RISPQUERY._serialized_start=1375
  _RISPQUERY._serialized_end=1627
  _RISPQUERY_RISPTYPE._serialized_start=701
  _RISPQUERY_RISPTYPE._serialized_end=746
  _RISPINFO._serialized_start=1630
  _RISPINFO._serialized_end=2188
  _RISPINFO_STATE._serialized_start=2086
  _RISPINFO_STATE._serialized_end=2136
  _RISPINFO_RISPTYPE._serialized_start=2138
  _RISPINFO_RISPTYPE._serialized_end=2188
  _RISPSINFO._serialized_start=2190
  _RISPSINFO._serialized_end=2277
  _RISPSTATQUERY._serialized_start=2279
  _RISPSTATQUERY._serialized_end=2367
  _RISP._serialized_start=2370
  _RISP._serialized_end=3141
# @@protoc_insertion_point(module_scope)
