# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/config/v1/domain_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*spaceone/api/config/v1/domain_config.proto\x12\x16spaceone.api.config.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x87\x01\n\x16SetDomainConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"6\n\x13\x44omainConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"G\n\x16GetDomainConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"`\n\x11\x44omainConfigQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"\xa9\x01\n\x10\x44omainConfigInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12\x12\n\ncreated_at\x18\x05 \x01(\t\x12\x12\n\nupdated_at\x18\x06 \x01(\t\"c\n\x11\x44omainConfigsInfo\x12\x39\n\x07results\x18\x01 \x03(\x0b\x32(.spaceone.api.config.v1.DomainConfigInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"`\n\x15\x44omainConfigStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xcd\x07\n\x0c\x44omainConfig\x12\x85\x01\n\x06\x63reate\x12..spaceone.api.config.v1.SetDomainConfigRequest\x1a(.spaceone.api.config.v1.DomainConfigInfo\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/config/v1/domain-configs\x12\x8b\x01\n\x06update\x12..spaceone.api.config.v1.SetDomainConfigRequest\x1a(.spaceone.api.config.v1.DomainConfigInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/config/v1/domain-config/{name}\x12\x88\x01\n\x03set\x12..spaceone.api.config.v1.SetDomainConfigRequest\x1a(.spaceone.api.config.v1.DomainConfigInfo\"\'\x82\xd3\xe4\x93\x02!\"\x1f/config/v1/domain-config/{name}\x12v\n\x06\x64\x65lete\x12+.spaceone.api.config.v1.DomainConfigRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!*\x1f/config/v1/domain-config/{name}\x12\x88\x01\n\x03get\x12..spaceone.api.config.v1.GetDomainConfigRequest\x1a(.spaceone.api.config.v1.DomainConfigInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/config/v1/domain-config/{name}\x12\xa1\x01\n\x04list\x12).spaceone.api.config.v1.DomainConfigQuery\x1a).spaceone.api.config.v1.DomainConfigsInfo\"C\x82\xd3\xe4\x93\x02=\x12\x18/config/v1/domain-configZ!\"\x1f/config/v1/domain-config/search\x12u\n\x04stat\x12-.spaceone.api.config.v1.DomainConfigStatQuery\x1a\x17.google.protobuf.Struct\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/config/v1/domain-config/statb\x06proto3')



_SETDOMAINCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetDomainConfigRequest']
_DOMAINCONFIGREQUEST = DESCRIPTOR.message_types_by_name['DomainConfigRequest']
_GETDOMAINCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetDomainConfigRequest']
_DOMAINCONFIGQUERY = DESCRIPTOR.message_types_by_name['DomainConfigQuery']
_DOMAINCONFIGINFO = DESCRIPTOR.message_types_by_name['DomainConfigInfo']
_DOMAINCONFIGSINFO = DESCRIPTOR.message_types_by_name['DomainConfigsInfo']
_DOMAINCONFIGSTATQUERY = DESCRIPTOR.message_types_by_name['DomainConfigStatQuery']
SetDomainConfigRequest = _reflection.GeneratedProtocolMessageType('SetDomainConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDOMAINCONFIGREQUEST,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.SetDomainConfigRequest)
  })
_sym_db.RegisterMessage(SetDomainConfigRequest)

DomainConfigRequest = _reflection.GeneratedProtocolMessageType('DomainConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINCONFIGREQUEST,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.DomainConfigRequest)
  })
_sym_db.RegisterMessage(DomainConfigRequest)

GetDomainConfigRequest = _reflection.GeneratedProtocolMessageType('GetDomainConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDOMAINCONFIGREQUEST,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.GetDomainConfigRequest)
  })
_sym_db.RegisterMessage(GetDomainConfigRequest)

DomainConfigQuery = _reflection.GeneratedProtocolMessageType('DomainConfigQuery', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINCONFIGQUERY,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.DomainConfigQuery)
  })
_sym_db.RegisterMessage(DomainConfigQuery)

DomainConfigInfo = _reflection.GeneratedProtocolMessageType('DomainConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINCONFIGINFO,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.DomainConfigInfo)
  })
_sym_db.RegisterMessage(DomainConfigInfo)

DomainConfigsInfo = _reflection.GeneratedProtocolMessageType('DomainConfigsInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINCONFIGSINFO,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.DomainConfigsInfo)
  })
_sym_db.RegisterMessage(DomainConfigsInfo)

DomainConfigStatQuery = _reflection.GeneratedProtocolMessageType('DomainConfigStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINCONFIGSTATQUERY,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.DomainConfigStatQuery)
  })
_sym_db.RegisterMessage(DomainConfigStatQuery)

_DOMAINCONFIG = DESCRIPTOR.services_by_name['DomainConfig']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAINCONFIG.methods_by_name['create']._options = None
  _DOMAINCONFIG.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\033\"\031/config/v1/domain-configs'
  _DOMAINCONFIG.methods_by_name['update']._options = None
  _DOMAINCONFIG.methods_by_name['update']._serialized_options = b'\202\323\344\223\002!\032\037/config/v1/domain-config/{name}'
  _DOMAINCONFIG.methods_by_name['set']._options = None
  _DOMAINCONFIG.methods_by_name['set']._serialized_options = b'\202\323\344\223\002!\"\037/config/v1/domain-config/{name}'
  _DOMAINCONFIG.methods_by_name['delete']._options = None
  _DOMAINCONFIG.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002!*\037/config/v1/domain-config/{name}'
  _DOMAINCONFIG.methods_by_name['get']._options = None
  _DOMAINCONFIG.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/config/v1/domain-config/{name}'
  _DOMAINCONFIG.methods_by_name['list']._options = None
  _DOMAINCONFIG.methods_by_name['list']._serialized_options = b'\202\323\344\223\002=\022\030/config/v1/domain-configZ!\"\037/config/v1/domain-config/search'
  _DOMAINCONFIG.methods_by_name['stat']._options = None
  _DOMAINCONFIG.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\037\"\035/config/v1/domain-config/stat'
  _SETDOMAINCONFIGREQUEST._serialized_start=194
  _SETDOMAINCONFIGREQUEST._serialized_end=329
  _DOMAINCONFIGREQUEST._serialized_start=331
  _DOMAINCONFIGREQUEST._serialized_end=385
  _GETDOMAINCONFIGREQUEST._serialized_start=387
  _GETDOMAINCONFIGREQUEST._serialized_end=458
  _DOMAINCONFIGQUERY._serialized_start=460
  _DOMAINCONFIGQUERY._serialized_end=556
  _DOMAINCONFIGINFO._serialized_start=559
  _DOMAINCONFIGINFO._serialized_end=728
  _DOMAINCONFIGSINFO._serialized_start=730
  _DOMAINCONFIGSINFO._serialized_end=829
  _DOMAINCONFIGSTATQUERY._serialized_start=831
  _DOMAINCONFIGSTATQUERY._serialized_end=927
  _DOMAINCONFIG._serialized_start=930
  _DOMAINCONFIG._serialized_end=1903
# @@protoc_insertion_point(module_scope)
