# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import savings_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2


class SavingsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get_pl_inventory = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/get_pl_inventory',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlInventoryRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryInfo.FromString,
                )
        self.list_pl_inventory = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/list_pl_inventory',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventorysInfo.FromString,
                )
        self.stat_pl_inventory = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/stat_pl_inventory',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.get_pl_savings_detail = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/get_pl_savings_detail',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSavingsDetailRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailInfo.FromString,
                )
        self.list_pl_savings_detail = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/list_pl_savings_detail',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailsInfo.FromString,
                )
        self.stat_pl_savings_detail = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/stat_pl_savings_detail',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.get_pl_summary = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/get_pl_summary',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSummaryRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryInfo.FromString,
                )
        self.list_pl_summary = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/list_pl_summary',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummariesInfo.FromString,
                )
        self.stat_pl_summary = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/stat_pl_summary',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class SavingsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get_pl_inventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_pl_inventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat_pl_inventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_pl_savings_detail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_pl_savings_detail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat_pl_savings_detail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_pl_summary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_pl_summary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat_pl_summary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SavingsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get_pl_inventory': grpc.unary_unary_rpc_method_handler(
                    servicer.get_pl_inventory,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlInventoryRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryInfo.SerializeToString,
            ),
            'list_pl_inventory': grpc.unary_unary_rpc_method_handler(
                    servicer.list_pl_inventory,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventorysInfo.SerializeToString,
            ),
            'stat_pl_inventory': grpc.unary_unary_rpc_method_handler(
                    servicer.stat_pl_inventory,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'get_pl_savings_detail': grpc.unary_unary_rpc_method_handler(
                    servicer.get_pl_savings_detail,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSavingsDetailRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailInfo.SerializeToString,
            ),
            'list_pl_savings_detail': grpc.unary_unary_rpc_method_handler(
                    servicer.list_pl_savings_detail,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailsInfo.SerializeToString,
            ),
            'stat_pl_savings_detail': grpc.unary_unary_rpc_method_handler(
                    servicer.stat_pl_savings_detail,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'get_pl_summary': grpc.unary_unary_rpc_method_handler(
                    servicer.get_pl_summary,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSummaryRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryInfo.SerializeToString,
            ),
            'list_pl_summary': grpc.unary_unary_rpc_method_handler(
                    servicer.list_pl_summary,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummariesInfo.SerializeToString,
            ),
            'stat_pl_summary': grpc.unary_unary_rpc_method_handler(
                    servicer.stat_pl_summary,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.Savings', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Savings(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get_pl_inventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/get_pl_inventory',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlInventoryRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_pl_inventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/list_pl_inventory',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventorysInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat_pl_inventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/stat_pl_inventory',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_pl_savings_detail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/get_pl_savings_detail',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSavingsDetailRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_pl_savings_detail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/list_pl_savings_detail',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat_pl_savings_detail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/stat_pl_savings_detail',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_pl_summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/get_pl_summary',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSummaryRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_pl_summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/list_pl_summary',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummariesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat_pl_summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/stat_pl_summary',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
